/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 06128
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1991
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\06128-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE cweocc2f  994='(994) DONT KNOW' 995='(995) BAD DATA' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE roccup2f  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE businesf  990='(990) INDUSTRY NOT REPORTED' 995='(995) BAD DATA' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cwebus2f  990='(990) INDUSTRY NOT REPORTED' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE snufrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED SMOKELESS TOBACCO Logically i'
                  91='(91) NEVER USED SMOKELESS TOBACCO' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ALCOHOL Logically imputed'
                  91='(91) NEVER USED ALCOHOL' ;
  VALUE sedrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  83='(83) NEVER USED AMPHETAMINES W/A NEEDLE Logic'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analrec   1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjrec     1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED MARIJUANA Logically imputed'
                  91='(91) NEVER USED MARIJUANA' ;
  VALUE inhrec    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically imputed'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crakrec   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED CRACK Logically imputed'
                  91='(91) NEVER USED CRACK' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocrec    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than year'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED COCAINE Logically imputed'
                  91='(91) NEVER USED COCAINE' ;
  VALUE condlrec  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED COCAINE Logically imputed'
                  83='(83) NEVER USED COCAINE WITH A NEEDLE Logic.i'
                  91='(91) NEVER USED COCAINE'
                  93='(93) NEVER USED COCAINE WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcprec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED PCP Logically imputed' 91='(91) NEVER USED PCP'
                  97='(97) REFUSED' ;
  VALUE hallrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HALLUCINOGENS Logically imput'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HEROIN Logically imputed'
                  91='(91) NEVER USED HEROIN' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hrndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HEROIN Logically imputed'
                  83='(83) NEVER USED HEROIN WITH A NEEDLE Logicall'
                  91='(91) NEVER USED HEROIN' 93='(93) NEVER USED HEROIN WITH A NEEDLE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ANY DRUG FOR NONMDCL RSN Log.'
                  83='(83) NEVER USED A NEEDLE TO TAKE ANY DRUG Log'
                  91='(91) NEVER USED ANY DRUG FOR NONMEDICAL REASO'
                  93='(93) NEER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE icerec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ICE Logically assigned' 91='(91) NEVER USED ICE'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sterrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ANABOLIC STEROIDS Logically i'
                  91='(91) NEVER USED ANABOLIC STEROIDS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcsed    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alctran   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcstm    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcanal   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcmj     1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcinh    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alccoc    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alchal    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcopt    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcnone   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) MULTIPLE RESPONSE'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 99='(99) LEGITIMATE SKIP' ;
  VALUE cigtry    185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED CIGARETTES' 194='(194) DONT KNOW'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE cigage    181='(181) NEVER USED CIGARETTES Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED CIGARETTES' 193='(193) NEVER SMOKED DAILY'
                  194='(194) DONT KNOW' 198='(198) BLANK (NO ANSWER)' ;
  VALUE cigyrs    181='(181) NEVER USED CIGARETTES Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED CIGARETTES' 194='(194) DONT KNOW' 197='(197) REFUSED'
                  198='(198) BLANK (NO ANSWER)'
                  199='(199) LEGITIMATE SKIP (CIGAGE = 193)' ;
  VALUE alctry    181='(181) NEVER USED ALCOHOL Logically assigned'
                  185='(185) BAD DATA Logically assigned' 191='(191) NEVER USED ALCOHOL'
                  194='(194) DONT KNOW' 197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE alcage    181='(181) NEVER USED ALCOHOL Logically assigned'
                  185='(185) BAD DATA Logically assigned' 191='(191) NEVER USED ALCOHOL'
                  193='(193) NEVER USED ALCOHOL MONTHLY OR MORE OFTEN'
                  194='(194) DONT KNOW' 197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE sedage    181='(181) NEVER USED SEDATIVES Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED SEDATIVES' 194='(194) DONT KNOW'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE tranage   181='(181) NEVER USED TRANQUILIZERS Logically assig'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED TRANQUILIZERS' 194='(194) DONT KNOW'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE stimage   181='(181) NEVER USED STIMULANTS Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED STIMULANTS' 198='(198) BLANK (NO ANSWER)' ;
  VALUE analage   181='(181) NEVER USED ANALGESICS Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED ANALGESICS' 194='(194) DONT KNOW'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE mjopp     181='(181) NEVER HAD CHANCE TO TRY MARIJUANA Log. a'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER HAD CHANCE TO TRY MARIJUANA' 194='(194) DONT KNOW'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE mjage     181='(181) NEVER USED MARIJUANA Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED MARIJUANA' 194='(194) DONT KNOW' 197='(197) REFUSED'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE inhage    181='(181) NEVER USED INHALANTS Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED INHALANTS' 194='(194) DONT KNOW'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE cocopp    181='(181) NEVER HAD A CHANCE TO TRY COCAINE Log. a'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER HAD A CHANCE TO TRY COCAINE' 194='(194) DONT KNOW'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE cocage    181='(181) NEVER USED COCAINE Logically assigned'
                  185='(185) BAD DATA Logically assigned' 191='(191) NEVER USED COCAINE'
                  197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE hallopp   181='(181) NEVER HAD A CHANCE TO TRY HALLUCINOGENS'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER HAD A CHANCE TO TRY HALLUCINOGENS'
                  194='(194) DONT KNOW' 197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE hallage   181='(181) NEVER USED HALLUCINOGENS Logically assig'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED HALLUCINOGENS' 194='(194) DONT KNOW'
                  197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE heropp    181='(181) NEVER HAD A CHANCE TO TRY HEROIN Log. as'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER HAD A CHANCE TO TRY HEROIN' 194='(194) DONT KNOW'
                  197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE herage    181='(181) NEVER HAD A CHANCE TO TRY HEROIN Log. as'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER HAD A CHANCE TO TRY HEROIN' 197='(197) REFUSED'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE steropp   181='(181) NEVER USED ANABOLIC STEROIDS Logically a'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED ANABOLIC STEROIDS' 194='(194) DONT KNOW'
                  197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE sterage   181='(181) NEVER USED ANABOLIC STEROIDS Logically a'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED ANABOLIC STEROIDS' 197='(197) REFUSED'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE othtob    1='(1) Daily' 2='(2) Almost daily (3-6 days a week)'
                  3='(3) 1 or 2 days a week'
                  4='(4) Several times a month (25-51 days a year'
                  5='(5) 1 or 2 times a month (12-24 days a year)'
                  6='(6) Every other month or so (6-11 days a yea'
                  7='(7) 3-5 days this past year' 8='(8) 1 or 2 days this past year'
                  81='(81) NEVER USED SMOKELESS TOBACCO Logically a'
                  83='(83) DID NOT USE SMOKELESS TOBACCO PST YR Log'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED SMOKELESS TOBACCO IN LIFETIME'
                  93='(93) DID NOT USE SMOKELESS TOBACCO IN THE PAS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcpat    1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25-51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a ye'
                  6='(6) Every other month or so (6 to 11 days a'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS Log. ass'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (25-51 days a year'
                  5='(5) 1 to 2 times a month (12 to 24 days a ye'
                  6='(6) Every other month or so (6 to 11 days a'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  83='(83) DID NOT USE SEDATIVE PAST 12 MOS Log. as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE ANY SEDATIVE IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (25-51 days a year'
                  5='(5) 1 to 2 times a month (12 to 24 days a ye'
                  6='(6) Every other month or so (6 to 11 days a'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  83='(83) DID NOT USE TRANQUILIZER PAST 12 MOS Log'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE ANY TRANQUILIZER IN THE PAST'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 da'
                  5='(5) 1 to 2 times a month (12 to 24 days a ye'
                  6='(6) Every other month or so (6 to 11 days a'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) DID NOT USE STIMULANT PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 da'
                  5='(5) 1 to 2 times a month (12 to 24 days a ye'
                  6='(6) Every other month or so (6 to 11 days a'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED ANALGESICS Logically assigned'
                  83='(83) DID NOT USE ANALGESIC PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjyrfreq  1='(1) Several times a day' 2='(2) Daily'
                  3='(3) Almost daily (3 to 6 days a week)'
                  4='(4) 1 or 2 days a week'
                  5='(5) Several times a month (about 25 to 51 da'
                  6='(6) 1 to 2 times a month (12 to 24 days a ye'
                  7='(7) Every other month or so (6 to 11 days a'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 da'
                  5='(5) 1 to 2 times a month (12 to 24 days a ye'
                  6='(6) Every other month or so (6 to 11 days a'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 12 MOS Log. as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN THE PAST 12 MONT'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocyrfrq  1='(1) Daily' 2='(2) Almost daily (3 to 6 days a week)'
                  3='(3) 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 da'
                  5='(5) 1 to 2 times a month (12 to 24 days a ye'
                  6='(6) Every other month or so (6 to 11 days a'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 da'
                  5='(5) 1 to 2 times a month (12 to 24 days a y'
                  6='(6) Every other month or so (6 to 11 days a'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  83='(83) DID NOT USE HALLUCINOGEN PAST 12 MOS Log'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGEN IN THE PAST 12'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cig5pk    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE packs     1='(1) One to five cigarettes a day'
                  2='(2) About 1/2 pack a day(6-15 cigarettes)'
                  3='(3) About a pack a day(16-25 cigarettes)'
                  4='(4) About 1 1/2 packs a day(26-35 cigarettes'
                  5='(5) About 2 packs or more a day (over 35 cig'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (CIGAGE = 193)' ;
  VALUE avcig     1='(1) Less than one cigarette a day'
                  2='(2) one to five cigarettes a day'
                  3='(3) About 1/2 pack a day (6-15 cigarettes)'
                  4='(4) About a pack a day (16-25 cigarettes)'
                  5='(5) About 1 1/2 packs a day (26-35 cigarette'
                  6='(6) About 2 packs or more a day (over 35 cig'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cigtime   9981='(9981) NEVER USED CIGARETTES Logically assigned'
                  9985='(9985) BAD DATA Logically assigned'
                  9989='(9989) LEGITIMATE SKIP Logically assigned'
                  9991='(9991) NEVER USED CIGARETTES' 9994='(9994) DONT KNOW'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE alcdays   81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nodr30a   2='(2) USUAL # DRINKS PER DAY PAST 30 DAYS'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dr5day    81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30a   2='(2) MOST # DRINKS ON ONE DAY IN PAST 30 DAYS'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30dy  2='(2) # DAYS DRANK AMOUNT IN A-7 PAST 30 DAYS'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drunkyr   1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25-51 days'
                  5='(5) 1 to 2 times a month (12 to 24 days a ye'
                  6='(6) Every other month or so (6 to 11 days a'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  9='(9) Never got very high or drunk in past 12'
                  81='(81) NEVER USE ALCOHOL Logically assigned'
                  83='(83) DID NOT USED ALCOHOL PAST 12 MOS. Log'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcbeer   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DONT KNOW' 97='(97) REFUSED' ;
  VALUE alcwine   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  97='(97) REFUSED' ;
  VALUE alcliqr   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  97='(97) REFUSED' ;
  VALUE alcvary   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  97='(97) REFUSED' ;
  VALUE noboozyr  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned' ;
  VALUE alcaggr   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcargum  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcabsnt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alchigh   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcjob    1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcmatcd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcrelcd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcfrdcd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alctoss   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcholic  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcdrunk  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcintox  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcrem    1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcquick  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcmorn   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcshook  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcalone  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcbrkpm  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE butisol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE buticaps  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amytal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mebaral   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE placidyl  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE doriden   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE noludar   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nembutal  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE seconal   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tuinal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dalmane   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE restoril  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halcion   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amobarb   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phenobar  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methaq    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE chhyd     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pentob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE secob     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sednosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Sedative use LOGICALLY ASSIGNED'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sednewa   116='(116) Methaqualone (including Sopor, Quaalude)'
                  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  122='(122) Sleep Aid <OTC>' 123='(123) Unisom <OTC>' 129='(129) Reds'
                  131='(131) Haldol' 133='(133) Ryoxine (sic)' 135='(135) Mini Thins'
                  138='(138) Mandrax (sic)' 139='(139) Black widows' 143='(143) Sedoxen (sic)'
                  144='(144) Reynolds (sic)' 201='(201) Valium' 206='(206) Tranxene'
                  209='(209) Xanax' 227='(227) Thorazine' 234='(234) Flexeril, Cyclobenzaprine'
                  240='(240) Lithium Carbonate' 244='(244) sic'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  326='(326) White cross' 327='(327) Black Beauty, Black beauties'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  352='(352) Lemons' 362='(362) Benadryl' 364='(364) Sudafed, Sinutab'
                  401='(401) Darvon' 408='(408) Dilaudid'
                  409='(409) Tylenol with Codeine, Tylenol 3' 411='(411) Talwin'
                  415='(415) Codeine' 417='(417) Morphine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 423='(423) Percocet'
                  425='(425) Advil' 426='(426) Fiorinal, Butalbital, Phrenilin Forte'
                  427='(427) Darvocet' 430='(430) Aspirin, Ecotrin, Empirin <OTC>'
                  435='(435) Tylenol <OTC>'
                  530='(530) Asthma inhaler, Bronchial dilators'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 820='(820) Penicillin' 828='(828) Tetracycline'
                  981='(981) NEVER USED SEDATIVES Logically assigned'
                  991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewb   120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 136='(136) Dimetapp'
                  202='(202) Librium' 339='(339) Amphetamines (speed generically)'
                  364='(364) Sudafed, Sinutab' 407='(407) Demerol' 414='(414) Propoxyphene'
                  417='(417) Morphine' 422='(422) Motrin' 440='(440) Soma' 444='(444) Empirin 3'
                  605='(605) PCP (angel dust, phencyclidine)'
                  991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewc   324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  426='(426) Fiorinal, Butalbital, Phrenilin Forte'
                  991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewd   120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewe   991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE seddknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nosedat   1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY ASSIGNED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED SEDATIVES'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE valium    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE librium   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE limbtrol  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE menrium   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE serax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranxene  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ativan    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE centrax   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE xanax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE paxipam   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE buspar    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE miltown   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE equanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE deprol    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE vistar    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE atarax    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE durrax    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE diazepam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skly      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE meprob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnosp    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Tranquilizer use LOGICALLY ASSIGNED'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnewa    116='(116) Methaqualone (including Sopor, Quaalude)'
                  128='(128) Nervine <OTC>' 138='(138) Mandrax (sic)' 211='(211) Buspar'
                  218='(218) Diazepam' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  229='(229) Librax' 232='(232) Mellaril' 234='(234) Flexeril, Cyclobenzaprine'
                  239='(239) Elavil' 240='(240) Lithium Carbonate' 241='(241) Prozac'
                  245='(245) Tryptophan' 246='(246) Clonopin' 248='(248) Sooper Cool (sic)'
                  249='(249) Asendin' 328='(328) Pink hearts' 415='(415) Codeine' 440='(440) Soma'
                  443='(443) Dolobid' 458='(458) Mepergan Fortis' 459='(459) Ketamine'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 802='(802) THC, Cannabinol'
                  991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewb    991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewc    991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewd    991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewe    991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trdknam   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE notranq   1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY ASSIGNED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trantot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 85='(85) DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dexed     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dexamyl   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE eskat     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE benz      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE biphet    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE desoxyn   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tenuate   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tepanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE didrex    1='(1) Response circled' 2='(2) not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE plegine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE preludin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ionamin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE fastin    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pondimin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE voranil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sanorex   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mazanor   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ritalin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cylert    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE detamp    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methi     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methamp   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE obla      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimnosp  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Stimulant use LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimnewa  124='(124) Yellow jackets' 135='(135) Mini Thins' 209='(209) Xanax'
                  301='(301) Dexedrine' 303='(303) Eskatrol'
                  307='(307) Tenuate, Diethylpropion'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 326='(326) White cross'
                  327='(327) Black Beauty, Black beauties' 328='(328) Pink hearts'
                  329='(329) Speckled eggs, Robins eggs' 331='(331) Whites'
                  332='(332) Ephedrine' 333='(333) 357 Magnum, Magnum 44'
                  334='(334) Cross tops, Crossroads' 335='(335) Dexatrim'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  340='(340) Tiamina 250 (sic)' 344='(344) Bennies' 345='(345) Black Molly'
                  347='(347) Phenylpropanolamine <OTC>' 353='(353) No-Doz <OTC>'
                  354='(354) Vivarin <OTC>' 355='(355) Crystal meth'
                  357='(357) Heart-shaped black pills' 360='(360) Rainbow speed'
                  365='(365) Desecon (sic)' 366='(366) Duromine (sic)'
                  367='(367) Slender Rite (sic)' 370='(370) Mess Tab (sic)'
                  373='(373) Captagon (sic)' 430='(430) Aspirin, Ecotrin, Empirin <OTC>'
                  457='(457) Ts and Blues' 601='(601) LSD (acid,white lightning)'
                  603='(603) Mescaline' 605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 814='(814) Caffeine' 815='(815) Coffee'
                  981='(981) NEVER USED STIMULANTS Logically assigned'
                  991='(991) NEVER USED STIMULANTS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewb  308='(308) Tepanil, Diethylpropion'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  326='(326) White cross' 327='(327) Black Beauty, Black beauties'
                  328='(328) Pink hearts' 329='(329) Speckled eggs, Robins eggs'
                  331='(331) Whites' 333='(333) 357 Magnum, Magnum 44'
                  334='(334) Cross tops, Crossroads' 357='(357) Heart-shaped black pills'
                  805='(805) Cocaine, Coke' 814='(814) Caffeine'
                  991='(991) NEVER USED STIMULANTS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewc  326='(326) White cross' 330='(330) Blue birds, Blue jays'
                  334='(334) Cross tops, Crossroads' 991='(991) NEVER USED STIMULANTS'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewd  991='(991) NEVER USED STIMULANTS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewe  991='(991) NEVER USED STIMULANTS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stmdknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nostims   1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY ASSIGNED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stneedle  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE darvon    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dolene    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sk65a     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wygesic   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE levodro   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE percodan  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE demerol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dilaud    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tylcod    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE phencod   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE talwin    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE talwinnx  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE talacen   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE propoxy   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE codeine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anilerid  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE morphine  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methdon   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stadol    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Analgesic use LOGICALLY ASSIGNED'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analnewa  234='(234) Flexeril, Cyclobenzaprine' 313='(313) Fastin, Phentermine'
                  362='(362) Benadryl' 364='(364) Sudafed, Sinutab'
                  406='(406) Percodan, Oxycodone' 407='(407) Demerol'
                  409='(409) Tylenol with Codeine, Tylenol 3' 415='(415) Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 422='(422) Motrin'
                  423='(423) Percocet' 425='(425) Advil'
                  426='(426) Fiorinal, Butalbital, Phrenilin Forte' 427='(427) Darvocet'
                  430='(430) Aspirin, Ecotrin, Empirin <OTC>' 431='(431) Tylox'
                  434='(434) Vicodin, Hydrocodone, Co-Gesic' 435='(435) Tylenol <OTC>'
                  438='(438) Anaprox, Naprosyn' 439='(439) 222, Canadian 222' 440='(440) Soma'
                  441='(441) Luitab (sic)' 442='(442) Ibuprofen' 445='(445) Norgesic Forte'
                  455='(455) Fiorinal with Codeine' 458='(458) Mepergan Fortis'
                  461='(461) Daopar (sic)' 463='(463) Lisalgil (sic)'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED'
                  981='(981) NEVER USED ANALGESICS Logically assigned'
                  991='(991) NEVER USED ANALGESICS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewb  222='(222) USED TRANQUILIZER, DONT KNOW NAME' 353='(353) No-Doz <OTC>'
                  364='(364) Sudafed, Sinutab' 422='(422) Motrin'
                  426='(426) Fiorinal, Butalbital, Phrenilin Forte'
                  455='(455) Fiorinal with Codeine' 458='(458) Mepergan Fortis'
                  460='(460) Magnopyrol (sic)' 702='(702) Heroin'
                  991='(991) NEVER USED ANALGESICS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewc  991='(991) NEVER USED ANALGESICS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewd  991='(991) NEVER USED ANALGESICS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewe  991='(991) NEVER USED ANALGESICS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE anldknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analnone  1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY ASSIGNED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjtot     1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjday30a  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Logic'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjav30a   81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Logic'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjav30b   81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Logic'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjamt30a  1='(1) 1 to 10 joints in the past 30 days'
                  2='(2) 11 to 20 joints in the past 30 days'
                  3='(3) About 1 ounce in the past 30 days'
                  4='(4) About 2 ounces in the past 30 days'
                  5='(5) 3 to 4 ounces in the past 30 days'
                  6='(6) 5 to 6 ounces in the past 30 days'
                  77='(77) More than 6 ounces in the past 30 days'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Log.'
                  85='(85) BAD DATA Logically-assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjjoint   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS Log. a'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON' ;
  VALUE mjpipe    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS Log. a'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON' ;
  VALUE mjbake    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS Log. a'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON' ;
  VALUE mjchew    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS Log. a'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON' ;
  VALUE mjway     1='(1) Response circled, method not specified'
                  2='(2) Response not circled'
                  3='(3) Response circled, method not specified L'
                  6='(6) Can with holes' 7='(7) One hitter' 8='(8) Boiled with tea'
                  9='(9) Smoky small room (burn in small room lik' 11='(11) Shot gun'
                  12='(12) Chewing/eating' 13='(13) Through an apple made like a pipe'
                  16='(16) Laced' 17='(17) Blunts' 18='(18) Gravities' 19='(19) With cocaine'
                  20='(20) Bleach bottle' 21='(21) Contact' 22='(22) 1 paper'
                  23='(23) As medicine'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS Logic.'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON' ;
  VALUE gas       1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE lgas      1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sppaint   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE glue      1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE solvent   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amylnit   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ether     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nitoxid   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cleflu    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED INRALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gas30a    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Log. a'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE lgas30a   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sppan30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 12 MOS Log. as'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Log. a'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE glue30a   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USED INHALANT PAST 30 DAYS Log.'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE solvn30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 12 MOS Log. as'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE amlnt30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Log. a'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ether30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USED INHALANT PAST 30 DAYS Log.'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nox30a    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 12 MOS Log. as'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE clfl30a   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Log. a'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE in30nosp  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANTS PAST 30 DAYS Log.'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inh30no   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdy30a  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inheff    1='(1) Enough to feel you were going to pass ou'
                  2='(2) Enough so that you staggered or dropped'
                  3='(3) Enough to get high' 4='(4) Enough to feel it a lot'
                  5='(5) Enough to feel it a little'
                  6='(6) Just enough to be able to say I did it,'
                  7='(7) Something else, NOT SPECIFIED'
                  8='(8) Didnt feel it, didnt use much'
                  9='(9) Sniffed out of curiosity once'
                  11='(11) Enough for a head rush'
                  12='(12) Didnt feel it, just like the smell'
                  15='(15) Just enough to say, I tried it, I felt i'
                  16='(16) Enough to get sick' 17='(17) Till I couldnt move'
                  18='(18) Enough smoke' 19='(19) Scared so I stopped'
                  20='(20) Smell of gas at the pump, not just to ge'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhpo     1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnewa   116='(116) Methaqualone (including Sopor, Quaalude)'
                  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 432='(432) Rufen'
                  501='(501) Gasoline or lighter fluids' 503='(503) Other aerosol sprays'
                  504='(504) Shoeshine lqd, glue/toluene; SuperGlue;'
                  506='(506) Amyl nitrite,poppers, lock rm odori'
                  507='(507) Halothane, ether, or other anesthet'
                  508='(508) Nitrous oxide,whippets, dentist gas'
                  509='(509) Correction flds, degreasers, cleaning fl'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens' 512='(512) Incense'
                  514='(514) Carbona (sic)' 515='(515) Vicks' 516='(516) Freon'
                  518='(518) Acetone, Nail polish remover' 519='(519) Helium'
                  522='(522) TV Tuner' 523='(523) Matches' 524='(524) White-Out'
                  526='(526) Nail polish' 527='(527) Phenyl nitrate'
                  528='(528) Whipped-cream can' 529='(529) Moth balls'
                  530='(530) Asthma inhaler, Bronchial dilators' 531='(531) Candy'
                  532='(532) PRW (sic)' 534='(534) Deodorant' 535='(535) Rexo (sic] copies'
                  536='(536) Fire Halt' 537='(537) Boat horn' 539='(539) ScotchGard' 540='(540) PAM'
                  541='(541) Binaca' 542='(542) Spirits of ammonia' 543='(543) Liquid oxygen'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 811='(811) Muscle relaxers'
                  813='(813) Cigarettes, tobacco not specified'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 995='(995) BAD DATA'
                  998='(998) BLANK (No ANSWER)' ;
  VALUE inhnewb   504='(504) Shoeshine lqd, glue/toluene; Super Glue;'
                  509='(509) Correction flds, degreasers, cleaning fl'
                  518='(518) Acetone, Nail polish remover' 524='(524) White-Out'
                  533='(533) Window sealant' 538='(538) Condensed horn'
                  805='(805) Cocaine, Coke'
                  981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewc   981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewd   981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewe   981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30a  503='(503) Other aerosol sprays'
                  504='(504) Shoeshine lqd, glue/toluene; Super Glue;'
                  506='(506) Amyl nitrite,poppers, lock rm odori'
                  509='(509) Correction flds, degreasers, cleaning fl'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens' 514='(514) Carbona (sic)'
                  516='(516) Freon' 519='(519) Helium' 524='(524) White-Out' 526='(526) Nail polish'
                  528='(528) whipped-cream can' 539='(539) ScotchGard' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic'
                  991='(991) NEVER USED INHALANTS' 993='(993) NOT APPLICABLE'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30b  504='(504) Shoeshine lqd, glue/toluene; Super Glue;'
                  526='(526) Nail polish'
                  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic'
                  991='(991) NEVER USED INHALANTS' 993='(993) NOT APPLICABLE'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30c  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30d  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30e  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE coctot    1='(1) 1 or 2 times' 2='(2) 3 to s times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocus30a  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 30 DAYS Logic.a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE crkam30a  981='(981) NEVER USED Logically assigned'
                  983='(983) DID NOT USE CRACK IN PAST 30 DAYS Log.as'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED CRACK'
                  993='(993) DID NOT USE CRACK IN PAST 30 DAYS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE crakbuck  9981='(9981) NEVER USED COCAINE Logically assigned'
                  9983='(9983) DID NOT USE CRACK PAST 30 DAYS Log. assi'
                  9985='(9985) BAD DATA Logically assigned' 9991='(9991) NEVER USED CRACK'
                  9993='(9993) DID NOT USE CRACK IN PAST 30 DAYS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE cocam30a  1='(1) Less than 1/4 gram (about 4 big lines) p'
                  2='(2) About 1/4 gram in the past 30 days'
                  3='(3) About 1/2 gram in the past 30 days'
                  4='(4) About 1 gram in the past 30 days'
                  5='(5) About 2 grams in the past 30 days'
                  6='(6) About 3 grams in the past 30 days' 7='(7) 4 grams'
                  23='(23) 20 grams' 77='(77) More than 3 grams in the past 30 days'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 30 DAYS Log'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocbuck   9981='(9981) NEVER USED COCAINE Logically assigned'
                  9983='(9983) DID NOT USE COCAINE PAST 30 DAYS Log.ass'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED COCAINE'
                  9993='(9993) DID NOT USE COCAINE IN PAST 30 DAYS' 9994='(9994) DONT KNOW'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE cocsniff  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logicall'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 97='(97) REFUSED' ;
  VALUE cocswal   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logicall'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 97='(97) REFUSED' ;
  VALUE cociv     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Cocaine use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 12 MOS Log.a'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 97='(97) REFUSED' ;
  VALUE freebase  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Cocaine use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logicall'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 97='(97) REFUSED' ;
  VALUE cocway    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Cocaine use LOGICALLY ASSIGNED'
                  6='(6) Lasing joints and bongs' 7='(7) On my gums'
                  8='(8) Freeze, put on tongue' 9='(9) Smoked in a cigarette'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MONTHS Logic'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE lsd       1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE peyote    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mesc      1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) LANK (NO ANSWER)' ;
  VALUE psilcy    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcp       1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) PCP use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ecstasy   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Hallucinogen use LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnewa   322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  357='(357) Heart-shaped black pills' 366='(366) Duromine (sic)'
                  434='(434) Vicodin, Hydrocodone, Co-Gesic'
                  501='(501) Gasoline or lighter fluids' 503='(503) Other aerosol sprays'
                  504='(504) Shoeshine lqd, glue/toluene; Super Glue;'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  609='(609) Jimson (sic) weed' 612='(612) Happy stick, Shermstick'
                  614='(614) MDMA' 616='(616) DMT' 617='(617) Moming glory seeds'
                  618='(618) Acid paper' 622='(622) Microdot(s), purple microdot'
                  624='(624) Orange sunshine' 625='(625) Window pane'
                  627='(627) Hawaiian Woodrow seeds'
                  628='(628) Hawaiian Rosebud seed tea' 630='(630) Black Owsley'
                  632='(632) Folifundia (sic)' 633='(633) Mr Natural' 635='(635) Ginseng seeds'
                  703='(703) Opium' 802='(802) THC, Cannabinol'
                  981='(981) NEVER USED HALLUCINOGENS Logically assig'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewb   504='(504) Shoeshine lqd, glue/toluene; Super Glue;'
                  629='(629) Rocket Fuel' 802='(802) THC, Cannabinol' 803='(803) Marijuana'
                  981='(981) NEVER USED HALLUCINOGENS Logically assig'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewc   981='(981) NEVER USED HALLUCINOGENS Logically assig'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewd   981='(981) NEVER USED HALLUCINOGENS Logically assig'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewe   981='(981) NEVER USED HALLUCINOGENS Logically assig'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE haldknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halltot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hal30use  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  83='(83) DID NOT USE HALLUCINOGENS PST 30 DAYS Lo'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 30'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hertot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE her30use  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) DID NOT USE HEROIN PAST 30 DAYS Logic.as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 30 DAYS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herneedl  1='(1) Yes, have used heroin with a needle'
                  2='(2) No, have used heroin, but not with a ne'
                  3='(3) Yes, have used heroin with a needle LOG'
                  4='(4) No, have used heroin, without needle LOG'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  91='(91) NEVER USED HEROIN' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdcig     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log.as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdalc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdsed     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log.as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdtran    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdstm     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdanal    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdmj      1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdinh     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdcoc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdhall    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdher     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdothop   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdnone    1='(1) Response circled' 2='(2) Response not circled'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdcig    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdalc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdsed    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdtran   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdstm    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdanal   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdmj     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdinh    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdcoc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdhall   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdher    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdothop  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in p'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdnone   1='(1) Response circled' 2='(2) Response not circled'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONT'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effcig    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effalc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effsed    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE efftran   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effstm    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effanal   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effmj     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effinh    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effcoc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effhall   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effher    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effothop  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for s'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effnone   1='(1) Response circled' 2='(2) Response not circled'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaycig   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayalc   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaysed   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaytran  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaystm   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayanal  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaymj    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayinh   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaycoc   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayhall  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayher   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayoth   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaynone  1='(1) Response circled' 2='(2) Response not circled'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depcig    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depalc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depsed    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE deptran   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depstm    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depanal   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depmj     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depinh    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS.Log as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depcoc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dephall   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depher    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depothop  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug u'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depnone   1='(1) Response circled' 2='(2) Response not circled'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wscig     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsalc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wssed     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wstran    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsstm     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsanal    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsmj      1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsinh     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wscoc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wshall    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsher     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsothop   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsnone    1='(1) Response circled' 2='(2) Response not circled'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS Log. a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndllif  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED A NEEDLE TO TAKE A DRUG Log.'
                  91='(91) NEVER USED A NEEDLE TO TAKE A DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlsed  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. ass'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Log. as'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndltra  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY LISTED DRUGS Logically as'
                  83='(83) NEVER USED ANY DRUGS LIST ABOVE Log. ass'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlstm  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled Logically imputed'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. ass'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Log. as'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlanl  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. ass'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Log. as'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlmj   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. ass'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Log. as'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlinh  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. ass'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Log. as'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlcoc  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. ass'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Log. as'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlhal  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. ass'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Log. as'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlher  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. ass'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Log. as'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 95='(95) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlopt  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. ass'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Log. as'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlnon  2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. ass'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Log. as'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlshr  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER SHARED A NEEDLE Logically assigned'
                  91='(91) NEVER SHARED A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drugtest  1='(1) Yes' 2='(2) No' 3='(3) Did not have a job during past 12 months'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE testpos   1='(1) Yes' 2='(2) No' 3='(3) Did not receive test in past 12 months'
                  4='(4) Did not have a job during past 12 months' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE icelife   1='(1) Yes' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED ICE Logically assigned' 91='(91) NEVER USED ICE'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stertot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED ANABOLIC STEROIDS Logically a'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED ANABOLIC STEROIDS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE booked    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nobookyr  185='(185) BAD DATA Logically assigned' 194='(194) DONT KNOW'
                  197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE bklarcny  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkburgl   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkagaslt  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bksmaslt  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) EM DATA Logically assigned' 94='(94) DONT KNOW' 97='(97) REFUSED' ;
  VALUE bkmvthft  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkrob     1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkrape    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkmurder  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkarson   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkdrvinf  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkdrunk   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkdrug    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkpros    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkvandal  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE bkothoff  1='(1) Larceny or theft' 3='(3) Aggravated assault'
                  4='(4) Other assault, such as simple assault or'
                  5='(5) Motor vehicle theft' 10='(10) Driving under the influence'
                  11='(11) Drunkenness or other liquor law violatio'
                  12='(12) Possession or sale of drugs'
                  14='(14) Oth proprty offns:- fraud, poss stln goo'
                  15='(15) Other offenses, NOT SPECIFIED' 16='(16) Weapons offenses'
                  17='(17) Other offenses against persons'
                  18='(18) Violation of court order, parole, probat'
                  19='(19) Public order offenses' 20='(20) Juvenile status offenses'
                  22='(22) Traffic violations' 85='(85) BAD DATA Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE notbked   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE probaton  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE parole    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE strsteal  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE othsteal  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE damage    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE carsteal  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE forcemon  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE breakin   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE phyfight  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hurtbad   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) EFUSED'
                  98='(98) LANK (NO ANSWER)' ;
  VALUE gunmoney  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drunkdrv  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE solddrug  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE othdoing  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE spnewa    0='(0) None (code used only for question SP-9)' 129='(129) Reds'
                  140='(140) Seldane' 322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  328='(328) Pink Hearts' 332='(332) Ephedrine'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 360='(360) Rainbow speed'
                  368='(368) Peanut Butter Crank' 415='(415) Codeine'
                  430='(430) Aspirin, Ecotrin, Empirin <OTC>'
                  454='(454) Novocain, Procaine' 455='(455) Fiorinal with Codeine'
                  459='(459) Ketamine' 501='(501) Gasoline or lighter fluids'
                  506='(506) Amyl nitrite,poppers, lock rm odoriz'
                  514='(514) Carbona (sic)' 601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC'
                  622='(622) Microdot(s), purple microdot' 626='(626) Jet Fuel'
                  703='(703) Opium' 803='(803) Marijuana' 804='(804) Hashish'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  823='(823) Blast (KJ) [sic)' 824='(824) Steroids' 829='(829) Robitussin DM'
                  831='(831) Honey Oil' 832='(832) Primo'
                  985='(985) BAD DATA Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewb    0='(0) None (code used only for question SP-9)'
                  322='(322) Methamphetamine (speed or ice or cr' 326='(326) White cross'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC' 703='(703) Opium' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewc    0='(0) None (code used only for question SP-9)' 348='(348) Crystal'
                  601='(601) LSD (acid,white lightning)' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewd    0='(0) None (code used only for question SP-9)'
                  605='(605) PCP (angel dust, phencyclidine)' 807='(807) Alcohol'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewe    0='(0) None (code used only for question SP-9)' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE as13none  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' ;
  VALUE drdeprss  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depdrg1a  111='(111) Dalmane' 113='(113) Halcion'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  122='(122) Sleep Aid <OTC>' 201='(201) Valium' 207='(207) Ativan'
                  208='(208) Centrax' 209='(209) Xanax' 211='(211) Buspar'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  406='(406) Percodan, Oxycodone'
                  409='(409) Tylenol with Codeine, Tylenol 3' 415='(415) Codeine'
                  423='(423) Percocet' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)' 603='(603) Mescaline'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  830='(830) Mad Bull' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg2a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 209='(209) Xanax'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  407='(407) Demerol' 415='(415) Codeine' 418='(418) Methadone'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)' 606='(606) Ecstasy (MDMA), X-TC'
                  702='(702) Heroin' 803='(803) Marijuana' 804='(804) Hashish'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg3a  322='(322) Methamphetamine (,speed or ice or c'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid,white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg4a  355='(355) Crystal meth' 601='(601) LSD (acid,white lightning)'
                  803='(803) Marijuana' 807='(807) Alcohol' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg5a  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drargum   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE argdrg1a  118='(118) Pentobarbital, Pentothal, Sodium Pentoth' 201='(201) Valium'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  327='(327) Black Beauty, Black beauties'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  406='(406) Percodan, Oxycodone'
                  409='(409) Tylenol with Codeine, Tylenol 3' 415='(415) Codeine'
                  423='(423) Percocet' 502='(502) Spray paints'
                  506='(506) Amyl nitrite,poppers, lock rm odoriz'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  830='(830) Mad Bull' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg2a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 301='(301) Dexedrine'
                  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 407='(407) Demerol'
                  415='(415) Codeine'
                  504='(504) Shoeshine lqd, glue/toluene; Super Glue;'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  609='(609) Jimson (sic) weed' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  900='(900) Non-Drug reason given for Drug Problem'
                  985='(985) BAD DATA Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg3a  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid,white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg4a  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  355='(355) Crystal meth' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg5a  702='(702) Heroin' 814='(814) Caffeine' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE dralone   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alndrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  207='(207) Ativan' 211='(211) Buspar'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or cr' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  406='(406) Percodan, Oxycodone' 415='(415) Codeine' 423='(423) Percocet'
                  502='(502) Spray paints' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)' 603='(603) Mescaline'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  830='(830) Mad Bull' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg2a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 407='(407) Demerol'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg3a  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  818='(818) Nicotine' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg4a  322='(322) Methamphetamine (speed or ice or cr' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg5a  702='(702) Heroin' 814='(814) Caffeine' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE dranx     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE anxdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  202='(202) Librium' 207='(207) Ativan' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 301='(301) Dexedrine'
                  313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  326='(326) White cross' 328='(328) Pink hearts' 332='(332) Ephedrine'
                  335='(335) Dexatrim' 336='(336) Diet pills'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  357='(357) Heart-shaped black pills' 358='(358) 20/20'
                  360='(360) Rainbow speed' 364='(364) Sudafed, Sinutab'
                  406='(406) Percodan, Oxycodone' 407='(407) Demerol'
                  409='(409) Tylenol with Codeine, Tylenol 3'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 435='(435) Tylenol <OTC>'
                  501='(501) Gasoline or lighter fluids'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)' 606='(606) Ecstasy (MDMA), X-TC'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  609='(609) Jimson [sic) weed' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  815='(815) Coffee' 816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  818='(818) Nicotine' 829='(829) Robitussin DM'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg2a  209='(209) Xanax' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  326='(326) White cross' 333='(333) 357 Magnum, Magnum 44'
                  339='(339) Amphetamines (speed generically)' 407='(407) Demerol'
                  415='(415) Codeine' 506='(506) Amyl nitrite,poppers, lock rm odoriz'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC' 702='(702) Heroin' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg3a  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)' 606='(606) Ecstasy (MDMA), X-TC'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg4a  322='(322) Methamphetamine (speed or ice or cr'
                  601='(601) LSD (acid, white lightning)' 603='(603) Mescaline'
                  604='(604) Psilocybin (mushrooms)' 803='(803) Marijuana' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg5a  702='(702) Heroin' 703='(703) Opium' 814='(814) Caffeine' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drhealth  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  123='(123) Unisom <OTC>' 201='(201) Valium'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or cr'
                  333='(333) 357 Magnum, Magnum 44'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 409='(409) Tylenol with Codeine, Tylenol 3'
                  504='(504) Shoeshine lqd, glue/toluene; Super Glue;'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  818='(818) Nicotine' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg2a  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid,white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg3a  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg4a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  322='(322) Methamphetamine (speed or ice or cr'
                  601='(601) LSD (acid,white lightning)' 803='(803) Marijuana'
                  807='(807) Alcohol' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg5a  814='(814) Caffeine' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drnthink  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ntkdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 142='(142) Belladona'
                  203='(203) Limbitrol' 209='(209) Xanax' 228='(228) Amitriptyline'
                  241='(241) Prozac' 313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  360='(360) Rainbow speed' 401='(401) Darvon' 406='(406) Percodan, Oxycodone'
                  409='(409) Tylenol with Codeine, Tylenol 3' 415='(415) Codeine'
                  422='(422) Motrin' 423='(423) Percocet' 462='(462) Norflex'
                  502='(502) Spray paints'
                  504='(504) Shoeshine lqd, glue/toluene; Super Glue;'
                  508='(508) Nitrous oxide,whippets, dentist gas'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC' 609='(609) Jimson [sic) weed'
                  702='(702) Heroin' 704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 808='(808) All of the ones Ive tried' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  830='(830) Mad Bull' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg2a  201='(201) Valium' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  247='(247) Sinequan' 322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)' 360='(360) Rainbow speed'
                  407='(407) Demerol' 502='(502) Spray paints'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg3a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg4a  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  802='(802) THC, Cannabinol' 803='(803) Marijuana' 807='(807) Alcohol'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg5a  503='(503) Other aerosol sprays'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drupset   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE upsdrg1a  118='(118) Pentobarbital, Pentothal, Sodium Pentoth'
                  203='(203) Limbitrol' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 301='(301) Dexedrine'
                  322='(322) methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  360='(360) Rainbow speed' 406='(406) Percodan, Oxycodone' 415='(415) Codeine'
                  601='(601) LSD (acid,white lightning)' 603='(603) Mescaline'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  818='(818) Nicotine' 830='(830) Mad Bull'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg2a  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  407='(407) Demerol' 502='(502) Spray paints'
                  601='(601) LSD (acid,white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg3a  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  506='(506) Amyl nitrite,poppers, lock rm odoriz'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg4a  503='(503) Other aerosol sprays' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg5a  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drlswork  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE lswdrg1a  111='(111) Dalmane' 142='(142) Belladona' 211='(211) Buspar'
                  322='(322) Methamphetamine (speed or ice or cr' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 360='(360) Rainbow speed'
                  409='(409) Tylenol with Codeine, Tylenol 3' 415='(415) Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 422='(422) Motrin'
                  423='(423) Percocet' 435='(435) Tylenol <OTC>'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  609='(609) Jimson [sic) weed' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  812='(812) Cigars' 813='(813) Cigarettes, tobacco not specified'
                  814='(814) Caffeine' 815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  818='(818) Nicotine' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg2a  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 360='(360) Rainbow speed'
                  524='(524) White-Out' 601='(601) LSD (acid,white lightning)'
                  702='(702) Heroin' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg3a  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  503='(503) Other aerosol sprays'
                  601='(601) LSD (acid, white lightning)'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  818='(818) Nicotine' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg4a  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 803='(803) Marijuana'
                  807='(807) Alcohol' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg5a  601='(601) LSD (acid, white lightning)' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drsuspic  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE sspdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 207='(207) Ativan'
                  211='(211) Buspar' 322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  360='(360) Rainbow speed' 371='(371) Cogentin' 415='(415) Codeine'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)' 603='(603) Mescaline'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  609='(609) Jimson [sic) weed' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  812='(812) Cigars' 813='(813) Cigarettes, tobacco not specified'
                  814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  818='(818) Nicotine' 830='(830) Mad Bull'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg2a  131='(131) Haldol' 247='(247) Sinequan'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 609='(609) sic'
                  702='(702) Heroin' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (No ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg3a  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  601='(601) LSD (acid,white lightning)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 818='(818) Nicotine'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg4a  807='(807) Alcohol' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg5a  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drcope    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cpedrg1a  201='(201) Valium' 207='(207) Ativan' 211='(211) Buspar'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or cr' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 360='(360) Rainbow speed'
                  406='(406) Percodan, oxycodone'
                  409='(409) Tylenol with Codeine, Tylenol 3' 415='(415) Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 423='(423) Percocet'
                  502='(502) Spray paints' 601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 609='(609) sic'
                  702='(702) Heroin' 704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg2a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)' 407='(407) Demerol'
                  502='(502) Spray paints' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg3a  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 229='(229) Librax'
                  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  360='(360) Rainbow speed' 701='(701) OTHER Opiates, NOT SPECIFIED'
                  702='(702) Heroin' 802='(802) THC, Cannabinol' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg4a  209='(209) Xanax' 605='(605) PCP (angel dust, phencyclidine)'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg5a  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE dremgmed  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE emdrg1a   201='(201) Valium' 322='(322) Methamphetamine (speed or ice or cr'
                  335='(335) Dexatrim' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 615='(615) Homemade drugs'
                  702='(702) Heroin' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg2a   339='(339) Amphetamines (speed generically)'
                  430='(430) Aspirin, Ecotrin, Empirin <OTC>'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 809='(809) Pills'
                  813='(813) Cigarettes, tobacco not specified'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg3a   601='(601) LSD (acid,white lightning)' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg4a   994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg5a   994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE empdrug   1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cighelp   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drnkhelp  1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmthelp  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtemrg  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmthosp  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtdoc   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmttrmt  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtmhc   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtshg   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtsop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtsp    4='(4) AA or NA' 5='(5) Residential placement'
                  9='(9) Within myself (self-treatment)' 10='(10) Church'
                  11='(11) The street' 12='(12) Friends' 13='(13) Court facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rskpkcig  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rsktrymj  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrypcp  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkpcpreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rktryher  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkherreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great Risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrycoc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcococc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcocreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcrkocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkansocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkansreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rk2drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rk5drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rskbinge  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rskdifmj  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdiflsd  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifpcp  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifcoc  1='(1) Probably imposible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifher  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pden      1='(1) Segment in a MSA with 1 million or more'
                  2='(2) Segment in a MSA with fewer than 1 milli'
                  3='(3) Segment not in a MSA' ;
  VALUE pden2fff  1='(1) Segment in a MSA with 1 million or more'
                  2='(2) Segment in a MSA w/ between 250000 to 99'
                  3='(3) Segment in an MSA with fewer than 250,00'
                  4='(4) Segment not in a MSA and not in a rural'
                  5='(5) Segment not in a MSA and in a rural area' ;
  VALUE popden    1='(1) Segment in a SMSA with 1 million or more'
                  2='(2) Segment in a SMSA with fewer than 1 mill'
                  3='(3) Segment not in a SMSA' ;
  VALUE popden2f  1='(1) Segment in a SMSA with 1 million or more'
                  2='(2) Segment in a SMSA w/betw persons'
                  3='(3) Segment in a SMSA with fewer than 250000'
                  4='(4) Segment not in a SMSA and not in a rural'
                  5='(5) Segment not in a SMSA and in a rural are' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE division  1='(1) New England' 2='(2) Middle Atlantic' 3='(3) East North Central'
                  4='(4) West North Central' 5='(5) South Atlantic'
                  6='(6) East South Central' 7='(7) West South Central' 8='(8) Mountain'
                  9='(9) Pacific' ;
  VALUE chicago   1='(1) Low SES - CHICAGO' 2='(2) Not Low SES - CHICAGO'
                  9='(9) Not in CHICAGO' ;
  VALUE denver    1='(1) Low SES - DENVER' 2='(2) Not Low SES - DENVER'
                  9='(9) Not in DENVER' ;
  VALUE dc        1='(1) Low SES - DC' 2='(2) Not low SES - DC' 9='(9) NOT IN DC' ;
  VALUE la        1='(1) Low SES - LA' 2='(2) Not Low SES - LA' 9='(9) Not in LA' ;
  VALUE miami     1='(1) Low SES - MIAMI' 2='(2) Not Low SES - MIAMI'
                  9='(9) Not in MIAMI' ;
  VALUE newyork   1='(1) Low SES - NEW YORK' 2='(2) Not Low SES - NEW YORK'
                  9='(9) Not in NEW YORK' ;
  VALUE irrace    1='(1) American Indian or Alaskan Native'
                  2='(2) Asian or Pacific Islander' 3='(3) Black' 4='(4) White' ;
  VALUE iirace    1='(1) Race from questionnaire'
                  2='(2) Race from interviewer observation' 3='(3) Race from roster'
                  4='(4) Race statis imputed using race -Other on'
                  5='(5) Race statistically imputed, no infor fro' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE iisex     1='(1) Sex from questionnaire' 2='(2) Sex from roster'
                  3='(3) Sex statistically imputed' ;
  VALUE iiage     1='(1) Age from birthdate' 2='(2) Age from cover of questionnaire'
                  3='(3) Age from roster'
                  4='(4) Age statistically imputed using age gr f' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Nonhispanic' ;
  VALUE iihoind   1='(1) Hispanicity derived from questionnaire'
                  2='(2) Hispanicity derived from roster' ;
  VALUE irmarit   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or Separated'
                  4='(4) Never Married' 99='(99) LEGITIMATE SKIP' ;
  VALUE iimarit   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irpinsur  1='(1) Yes, respondent does have private health'
                  2='(2) No, respondent does not have private hea' ;
  VALUE iipinsur  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irworkst  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have job but out: illness/leave/furlough'
                  4='(4) Unemployed or laid off and looking for w'
                  5='(5) Unemployed and not looking for work'
                  6='(6) Full-time homemaker only' 7='(7) In school only' 8='(8) Retired'
                  9='(9) Disabled, not able to work' 10='(10) Other, in labor force'
                  11='(11) Other, not in labor force' ;
  VALUE iiworkst  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhsgrad  1='(1) Yes, graduated from high school'
                  2='(2) No, did not graduate from high school' ;
  VALUE ireduc    0='(0) No schooling' 1='(1) First grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) One year of college'
                  14='(14) Two years of college' 15='(15) Three years of college'
                  16='(16) Four years of college'
                  17='(17) Graduate/professional school' ;
  VALUE iieduc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iihsgrad  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iihogrp   1='(1) Hispanic-origin Group taken from questio'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE educcatf  1='(1) Less than high school (IREDUC 0-11 and'
                  2='(2) High school graduate (IREDUC 12 and IRA'
                  3='(3) Some college (IREDUC 13-15 and IRAGE=>1'
                  4='(4) College graduate (IREDUC 16-17 and IRAG'
                  5='(5) 12-17 year olds (IRAGE 12-17)' ;
  VALUE empstatf  1='(1) Full-time (IRWORKST 1,3 and IRAGE =>18)'
                  2='(2) Part-time (IRWORKST 2 and IRAGE => 18)'
                  3='(3) Unemployed (IRWORKST 4,5,10 and IRAGE=>'
                  4='(4) Other (IRWORKST 6-9,11 and IRAGE =>18)'
                  5='(5) 12-17 year olds (IRAGE 12-17)' ;
  VALUE irstmrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 9='(9) Never used stimulants' ;
  VALUE irotbrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 9='(9) Never used smokeless tobacco' ;
  VALUE irtrnrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 9='(9) Never used tranquilizers' ;
  VALUE irsedrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 9='(9) Never used sedatives' ;
  VALUE irmjrc    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago' 9='(9) Never used marijuana' ;
  VALUE irmjfq    1='(1) Used several times per day in past year'
                  2='(2) Used daily in past year'
                  3='(3) Used almost daily in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used several times per month in past yea'
                  6='(6) Used 1-2 times per month in past year'
                  7='(7) Used every other month in past year'
                  8='(8) Used 3-5 times in past year'
                  9='(9) Used 1-2 times in past year'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iimjfq    1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irotbfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past ye' ;
  VALUE iiotbfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsedfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past ye' ;
  VALUE iisedfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irstmfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past ye' ;
  VALUE iistmfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irtrnfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past ye' ;
  VALUE iitrnfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 9='(9) Never used hallucinogens' ;
  VALUE ircocrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago' 9='(9) Never used cocaine' ;
  VALUE irinhrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago' 9='(9) Never used inhalants' ;
  VALUE iranlrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or mare years ago' 9='(9) Never used analgesics' ;
  VALUE iralcrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 9='(9) Never used alcohol' ;
  VALUE iralcfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past ye' ;
  VALUE iialcfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iranlfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past ye' ;
  VALUE iianlfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircocfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times per month in past yea'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past ye' ;
  VALUE iicocfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past ye' ;
  VALUE iihalfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinhfq   1='(1) Use daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past ye' ;
  VALUE iiinhfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irpcprc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 9='(9) Never used PCP' ;
  VALUE iipcprc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircrkrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago' 9='(9) Never used crack' ;
  VALUE iicrkrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irstrrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 9='(9) Never used anabolic steroids' ;
  VALUE iistrrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iricerc   1='(1) Within the past year (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago' 9='(9) Never used ice' ;
  VALUE iiicerc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iiinhrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iiotbrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irherrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iihalrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iitrnrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iianlrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iistmrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iisedrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iicocrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iimjrc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iialcrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ndl90rec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE V' ;
  VALUE halflag   0='(0) Never used (IRHALRC 9)' 1='(1) Ever used (IRHALRC 1-5)' ;
  VALUE halyr     0='(0) Did not use in the past year (IRHALRC ='
                  1='(1) Used within the past year (IRHALRC 1-3)' ;
  VALUE halmon    0='(0) Did not use in the past month (IRHAL = 2'
                  1='(1) Used within the past month (IRHALRC 1)' ;
  VALUE pcpflag   0='(0) Never' 1='(1) Ever used (IRPCPRC 1,5)' ;
  VALUE pcpyr     0='(0) Did not use in the past year (IRPCPRC ='
                  1='(1) Used within the past year (IRPCPRC 1-3)' ;
  VALUE pcpmon    0='(0) Did not use in the past month (IRPCPRC ='
                  1='(1) Used within the past month (IRPCPRC 1)' ;
  VALUE stmflag   0='(0) Never used (IRSTMRC 9)' 1='(1) Ever used (IRSTMRC 1-5)' ;
  VALUE stmyr     0='(0) Did not use in the past year (IRSTMRC ='
                  1='(1) Used within the past year (IRSTMRC 1-3)' ;
  VALUE stmmon    0='(0) Did not use in the past month (IRSTMRC ='
                  1='(1) Used within the past month (IRSTMRC 1)' ;
  VALUE sedflag   0='(0) Never used (IRSEDRC 9)' 1='(1) Ever used (IRSEDRC 1-5)' ;
  VALUE sedyr     0='(0) Did not use in the past year (IRSEDRC 4'
                  1='(1) Used within the past year (IRSEDRC 1-3)' ;
  VALUE sedmon    0='(0) Did not use in the past month (IRSEDRC 2'
                  1='(1) Used within the past month (IRSEDRC 1)' ;
  VALUE trqflag   0='(0) Never used (IRTRNRC 9)' 1='(1) Ever used (IRTRNRC 1-5)' ;
  VALUE trqyr     0='(0) Did not use in the past year (IRTRNRC ='
                  1='(1) Used within the past year (IRTRNRC 1-3)' ;
  VALUE trqmon    0='(0) Did not use in the past month (IRTRNRC ='
                  1='(1) Used within the past month (IRTRNRC 1)' ;
  VALUE anlflag   0='(0) Never used (IRANLRC 9)' 1='(1) Ever used (IRANLRC 1-5)' ;
  VALUE anlyr     0='(0) Did not use in the past year (IRANLRC ='
                  1='(1) Used within the past year (IRANLRC 1-3)' ;
  VALUE anlmon    0='(0) Did not use in the past month (IRANLRC ='
                  1='(1) Used within the past month (IRANLRC 1)' ;
  VALUE alcflag   0='(0) Never used (IRALCRC 9)' 1='(1) Ever used (IRALCRC 1-5)' ;
  VALUE alcyr     0='(0) Did not use in the past year (IRALCRC ='
                  1='(1) Used within the past year (IRALCRC 1-3)' ;
  VALUE alcmon    0='(0) Did not use in the past month (IRALCRC ='
                  1='(1) Used within the past month (IRALCRC 1)' ;
  VALUE cigflag   0='(0) Never used (IRCIGRC 9)' 1='(1) Ever used (IRCIGRC 1-5)' ;
  VALUE cigyr     0='(0) Did not use in the past year (IRCIGRC ='
                  1='(1) Used within the past year (IRCIGRC 1-3)' ;
  VALUE cigmon    0='(0) Did not use in the past month (IRCIGRC ='
                  1='(1) Used within the past month (IRCIGRC 1)' ;
  VALUE smkflag   0='(0) Never used (IROTBRC 9)' 1='(1) Ever used (IROTBRC 1-5)' ;
  VALUE smkyr     0='(0) Did not use in the past year (IROTBRC ='
                  1='(1) Used within the past year (IROTBRC 1-3)' ;
  VALUE smkmon    0='(0) Did not use in the past month (IROTBRC ='
                  1='(1) Used within the past month (IROTBRC 1)' ;
  VALUE herflag   0='(0) Never used (IRHERRC 9)' 1='(1) Ever used (IRHERRC 1-5)' ;
  VALUE heryr     0='(0) Did not use in the past year (IRHERRC ='
                  1='(1) Used within the past year (IRHERRC 1-3)' ;
  VALUE hermon    0='(0) Did not use in the past month (IRHERRC ='
                  1='(1) Used within the past month (IRHERRC 1)' ;
  VALUE strflag   0='(0) Never used (IRSTRRC 9)' 1='(1) Ever used (IRSTRRC 1-5)' ;
  VALUE stryr     0='(0) Did not use in the past year (IRSTRRC ='
                  1='(1) Used within the past year (IRSTRRC 1-3)' ;
  VALUE strmon    0='(0) Did not use in the past month (IRSTRRC ='
                  1='(1) Used within the past month (IRSTRRC 1)' ;
  VALUE mrjflag   0='(0) Never used (IRMJRC 9)' 1='(1) Ever used (IRMJRC 1-6)' ;
  VALUE mrjyr     0='(0) Did not use in the past year (IRMJRC 5-6'
                  1='(1) Used within the past year (IRMJRC 1-4)' ;
  VALUE mrjmon    0='(0) Did not use in the past month (IRMJRC 3-'
                  1='(1) Used within the past month (IRMJRC 1-2)' ;
  VALUE cocflag   0='(0) Never used (IRCOCRC 9)' 1='(1) Ever used (IRCOCRC 1-6)' ;
  VALUE cocyr     0='(0) Did not use in the past year (IRCOCRC ='
                  1='(1) Used within the past year (IRCOCRC 1-4)' ;
  VALUE cocmon    0='(0) Did not use in the past month (IRCOCRC ='
                  1='(1) Used within the past month (IRCOCRC = 1-' ;
  VALUE crkflag   0='(0) Never used (IRCRKRC 9)' 1='(1) Ever used (IRCRKRC 1-6)' ;
  VALUE crkyr     0='(0) Did not use in the past year (IRCRKCR ='
                  1='(1) Used within the past year (IRCRKRC 1-4)' ;
  VALUE crkmon    0='(0) Did not use in the past month (IRCRKRC ='
                  1='(1) Used within the past month (IRCRKRC = 1-' ;
  VALUE inhflag   0='(0) Never used (IRINHRC 9)' 1='(1) Ever used (IRINHRC 1-6)' ;
  VALUE inhyr     0='(0) Did not use in the past year (IRINHRC 5-'
                  1='(1) Used within the past year (IRINHRC 1-4)' ;
  VALUE inhmon    0='(0) Did not use in the past month (IRINHRC 3'
                  1='(1) Used within the past month (IRINHRC = 1-' ;
  VALUE nedflagf  0='(0) Never used (NDL90REC=91,98)'
                  1='(1) Ever used (NDL90REC=1-9)' ;
  VALUE nedyr3ff  0='(0) Never used (NDL90REC=4-6,9,91,98)'
                  1='(1) Ever used (NDL90REC=1-3,8)' ;
  VALUE cocyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRCOCFQ 1' ;
  VALUE cocmonf   0='(0) Did not use monthly/more past year (IRCO'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE cocwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRC' ;
  VALUE cococcf   0='(0) Used monthly/more or none in pst yr (IRC'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE cocdlyf   0='(0) Did not use daily/almost daily pst yr (I'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE alcyrf    0='(0) Never used or not used in past year (IRA'
                  1='(1) Any use within the past year (IRALCFQ=1-' ;
  VALUE alcmonf   0='(0) Did not use monthly/more past year (IRAL'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE alcwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more in past year (IRALCF' ;
  VALUE alcoccf   0='(0) Used monthly/more or none in pst yr (IRA'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE alcdlyf   0='(0) Did not use daily/almost daily pst yr (I'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE anlyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRANLFQ=1-' ;
  VALUE anlmonf   0='(0) Did not use monthly/more past year (IRAN'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE anlwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRA' ;
  VALUE anloccf   0='(0) Used monthly/more or none in pst yr (IRA'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE anldlyf   0='(0) Did not use daily/almost daily pst yr (I'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE halyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRHALFQ= 1' ;
  VALUE halmonf   0='(0) Did not use monthly/more past year (IRHA'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE halwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRH' ;
  VALUE haloccf   0='(0) Used monthly/more or none in pst yr (IRH'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE haldlyf   0='(0) Did not use daily/almost daily pst yr (I'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE inhyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRINHFQ=1-' ;
  VALUE inhmonf   0='(0) Did not use monthly/more past year (IRIN'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE inhwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRI' ;
  VALUE inhoccf   0='(0) Used monthly/more or none in pst yr (IRI'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE inhdlyf   0='(0) Did not use daily/almost daily pst yr (I'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE sedyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRSEDFQ=1-' ;
  VALUE sedmonf   0='(0) Did not use monthly/more past year (IRSE'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE sedwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRS' ;
  VALUE sedoccf   0='(0) Used monthly/more or none in pst yr (IRS'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE seddlyf   0='(0) Did not use daily/almost daily pst yr (I'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE smkyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IROTBFQ=1-' ;
  VALUE smkmonf   0='(0) Did not use monthly/more past year (IROT'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE smkwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRO' ;
  VALUE smkoccf   0='(0) Used monthly/more or none in pst yr (IRO'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE smkdlyf   0='(0) Did not use daily/almost daily pst yr (I'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE stmyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRSTMFQ=1-' ;
  VALUE stmmonf   0='(0) Did not use monthly/more past year (IRST'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE stmwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year(IRST' ;
  VALUE stmoccf   0='(0) Used monthly/more or none in pst yr(IRST'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE stmdlyf   0='(0) Did not use daily/almost daily pst yr (I'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE trqyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any Use within the past year (IRTRNFQ=1-' ;
  VALUE trqmonf   0='(0) Did not use monthly/more past year (IRTR'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE trqwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRT' ;
  VALUE trqoccf   0='(0) Used monthly/more or none in pst yr (IRT'
                  1='(1) Used past year but legs than monthly (IR' ;
  VALUE trqdlyf   0='(0) Did not use daily/almost daily pst yr (I'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE mrjyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRMJFQ=1-9' ;
  VALUE mrjmonf   0='(0) Did not use monthly/more past year (IRMJ'
                  1='(1) Used monthly or more in past year (IRMJF' ;
  VALUE mrjwkf    0='(0) Did not use weekly/more past year (IRMJF'
                  1='(1) Used weekly or more in past year (IRMJFQ' ;
  VALUE mrjoccf   0='(0) Used monthly/more or none in pst yr (IRM'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE mrjdlyf   0='(0) Did not use daily/almost daily pst yr (I'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE psyflagf  0='(0) Never used (ALL SOURCE VARIABLES 9)'
                  1='(1) Ever used (ANY SOURCE VARIABLE < 9)' ;
  VALUE psyyr2ff  0='(0) Did not use within past year (ALL SOURCE'
                  1='(1) Used in past year (ANY SOURCE VARIABLE <' ;
  VALUE psymon2f  0='(0) Did not use in past month (ALL SOURCE VA'
                  1='(1) Used in past month (ANY SOURCE VARIABLE' ;
  VALUE sumflag   0='(0) Never used (ALL SOURCE VARIABLES 0)'
                  1='(1) Ever used (ANY SOURCE VARIABLE 1)' ;
  VALUE sumyr     0='(0) Did not use in past year (ALL SOURCE VAR'
                  1='(1) Used in past year (ANY SOURCE VARIABLE 1' ;
  VALUE summon    0='(0) Did not use in past month (ALL SOURCE VA'
                  1='(1) Used in past month (ANY SOURCE VARIABLE' ;
  VALUE mjoflag   0='(0) Never used MJ/has used both MJ & anoth'
                  1='(1) Marijuana is only (illicit) drug ever us' ;
  VALUE mjoyr2ff  0='(0) MJ not used past yr/Used MJ & othr dru'
                  1='(1) Marijuana is only (illicit) drug in pas' ;
  VALUE mjomon2f  0='(0) MJ not used past mnth/Used MJ & othr d'
                  1='(1) Marijuana only (illicit) drug in past mo' ;
  VALUE iemflag   0='(0) Never used drug/used only marijuana'
                  1='(1) Illicit drug except for marijuana are ev' ;
  VALUE iemyr     0='(0) Never used drug/used only marijuana past'
                  1='(1) Illicit drug except for marijuana used p' ;
  VALUE iemmon    0='(0) Never used drug/used only marijuana past'
                  1='(1) Illicit drug except for marijuana used p' ;
  VALUE catage    1='(1) 12-17 years (IRAGE 12-17)' 2='(2) 18-25 years (IRAGE 18-25)'
                  3='(3) 26-34 years (IRAGE 26-34)' 4='(4) 35+ years (IRAGE > 34)' ;
  VALUE race      1='(1) White (IRRACE = 4 and IRHOIND 2)'
                  2='(2) Black (IRRACE = 3 and IRHOIND 2)'
                  3='(3) Hispanic (IRHOIND 1)'
                  4='(4) Other (IRRACE = 1-2 and IRHOIND 2)' ;
  VALUE ircigrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE catag2ff  1='(1) 12-17 years (CATAGE 1)' 2='(2) 18-25 years (CATAGE 2)'
                  3='(3) 26+ years (CATAGE 3-4)' ;
  VALUE as3read   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as4read   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as5read   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as7read   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc1f  1='(1) QUESTION 1 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc2f  2='(2) QUESTION 2 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc3f  3='(3) QUESTION 3 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc4f  4='(4) QUESTION 4 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc5f  5='(5) BLANK (NO ANSWER)' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc6f  6='(6) QUESTION 5 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc7f  7='(7) QUESTION 7 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc8f  8='(8) QUESTION 8 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc9f  9='(9) QUESTION 9 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc0f  10='(10) ALL QUESTIONS WERE CLEAR' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhansy   1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as9read   1='(1) wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as10read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE as11read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE as12read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE as13read  1='(1) wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE as15read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE highbp    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE bpmed     1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE walkpain  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE timepain  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE upshor    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE asthma    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trpsych   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE heart     1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE flu       1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE allerg    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hospyr    1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE soreyr    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE runnyyr   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE coughyr   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phlegmyr  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE healthyr  1='(1) Excellent' 2='(2) Very good' 3='(3) Good' 4='(4) Fair' 5='(5) Poor'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE marital   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or separated'
                  4='(4) Has never married' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE nomarr    85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE workstat  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have job but out: illness/ leave/ furlou'
                  4='(4) Unemployed or laid off and looking for w'
                  5='(5) Unemployed and not looking for work'
                  6='(6) Full-time homemaker only' 7='(7) In school only' 8='(8) Retired'
                  9='(9) Disabled, not able to work'
                  10='(10) Something else (NOT SPECIFIED)'
                  11='(11) Unable to work - taking care of ill rela'
                  12='(12) About to start work'
                  13='(13) Contracts for work (eg Musician)' 14='(14) Welfare (AFDC)'
                  15='(15) Out of work - Termination - Injury'
                  16='(16) Just got out of school'
                  17='(17) Just returned to the United States'
                  18='(18) Drop out of school' 20='(20) Family business/no pay'
                  21='(21) Volunteer' 22='(22) Babysitting' 23='(23) Free-lance writer'
                  24='(24) Internship with/without pay'
                  25='(25) Student full-time/part-time-self employe'
                  26='(26) In training with or without pay' 27='(27) Pregnant'
                  28='(28) Part-time school/part-time work'
                  29='(29) Full-time student and or homemaker'
                  30='(30) Disabled/looking for work/full- and/or p'
                  32='(32) Did not work/never worked' 33='(33) On leave of absence'
                  34='(34) Veterans pension' 35='(35) In school and looking for work'
                  36='(36) Laid off & applying for disability'
                  37='(37) Paper route/odd jobs' 38='(38) Waiting to join the military'
                  39='(39) Part-time jobs' 40='(40) Retired'
                  41='(41) Job injury, workers compensation'
                  42='(42) In school, working part-time' 43='(43) Working two jobs'
                  44='(44) In school, but working during break/ sum'
                  45='(45) Expelled from school/waiting to go to co'
                  46='(46) College paid by State Industrial'
                  47='(47) Woodworking-own business' 48='(48) Self-employed'
                  50='(50) Seasonal work' 51='(51) Refuge' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE paymo     85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  91='(91) NEVER WORKED FOR PAY' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE payyr     185='(185) BAD DATA Logically assigned'
                  189='(189) LEGITIMATE SKIP Logically assigned'
                  191='(191) NEVER WORKED FOR PAY' 194='(194) DONT KNOW' 195='(195) BAD DATA'
                  197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' 199='(199) LEGITIMATE SKIP' ;
  VALUE sector    1='(1) Manufacturing' 2='(2) Wholesale trade' 3='(3) Retail trade, or'
                  4='(4) Something else? (SPECIFY)'
                  5='(5) AGRICULTURE/FORESTRY/FISHERIES' 6='(6) MINING'
                  7='(7) CONSTRUCTION' 8='(8) TRANSPORTATION' 9='(9) COMMUNICATIONS'
                  10='(10) UTILITIES/SANITARY SERVICES'
                  11='(11) FINANCE/INSURANCE/REAL ESTATE'
                  12='(12) BUSINESS/REPAIR SERVICES' 13='(13) PERSONAL SERVICES'
                  14='(14) ENTERTAINMENT/RECREATION SERVICES'
                  15='(15) PROFESSIONAL AND RELATED SERVICES'
                  16='(16) PUBLIC ADMINISTRATION' 17='(17) BAD DATA'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE no5job    89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE workdays  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE workblah  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cwe       1='(1) Respondent' 2='(2) Someone else (NOT SPECIFIED)'
                  3='(3) Income Contributed Equally' 4='(4) No one'
                  11='(11) Head of Household, Employer' 12='(12) Spouse'
                  13='(13) Live-in partner, fiancee' 14='(14) Mother' 15='(15) Father'
                  16='(16) Daughter' 17='(17) Son' 18='(18) Sister' 19='(19) Brother'
                  20='(20) Grandmother' 21='(21) Grandfather'
                  22='(22) Other female blood relative'
                  23='(23) Other male blood relative' 24='(24) Mother-in-law'
                  25='(25) Father-in-law' 26='(26) Other female in-laws'
                  27='(27) Other male in-laws' 28='(28) Close female friend'
                  29='(29) Close male friend'
                  30='(30) Other female acquaintance, roommate'
                  31='(31) Other male acquaintance, roommate' 32='(32) Step-mother'
                  33='(33) Step-father' 35='(35) Step-daughter'
                  39='(39) Other step relative,male'
                  40='(40) Friend (sex unspecified),boarder' 41='(41) Parents'
                  42='(42) Grandparents' 43='(43) Guardian (sex unspecified)'
                  44='(44) Foster mother, female guardian'
                  45='(45) Foster father, male guardian'
                  47='(47) Home care worker or health care aide'
                  50='(50) Multiple people listed'
                  51='(51) Relative, sex not specified'
                  52='(52) Roomate, sex not specified'
                  53='(53) Neighbor, sex not specified'
                  54='(54) Foster parent, sex not specified'
                  56='(56) Unspecified relationship' 59='(59) Adult children/children'
                  60='(60) Foster grandchild/foster child' 61='(61) Siblings'
                  62='(62) Co-worker' 67='(67) In-laws,sex not specified'
                  69='(69) Companion = Code 40' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE fullpart  1='(1) Full-time' 2='(2) Part-time'
                  3='(3) Chief source of income does not work'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cwesectr  1='(1) Manufacturing' 2='(2) Wholesale trade' 3='(3) Retail trade, or'
                  4='(4) Something else? (SPECIFY)'
                  5='(5) AGRICULTURE/FORESTRY/FISHERIES' 6='(6) MINING'
                  7='(7) CONSTRUCTION' 8='(8) TRANSPORTATION' 9='(9) COMMUNICATIONS'
                  10='(10) UTILITIES/SANITARY SERVICES'
                  11='(11) FINANCE/INSURANCE/REAL ESTATE'
                  12='(12) BUSINESS/REPAIR SERVICES' 13='(13) PERSONAL SERVICES'
                  14='(14) ENTERTAINMENT/RECREATION SERVICES'
                  15='(15) PROFESSIONAL AND RELATED SERVICES'
                  16='(16) PUBLIC ADMINISTRATION' 17='(17) BAD DATA'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMTE SKIP' ;
  VALUE educ      0='(0) No schooling' 1='(1) First Grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh Grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) One year college'
                  14='(14) 2 years college' 15='(15) 3 years college'
                  16='(16) 4 years college' 17='(17) Graduate/professional school'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gradhs    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE diploma   1='(1) High school diploma' 2='(2) GED certificate'
                  3='(3) Neither of the above'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE enrolld   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE schplans  1='(1) Has plans to enroll in a school in futur'
                  2='(2) Has completed all schooling'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE student   1='(1) A full-time student' 2='(2) A part-time student'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE schdays   89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skipped   89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE accid     1='(1) Yes' 2='(2) No' 3='(3) Did not drive in past 12 months'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE movdaway  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 85='(85) BAD DATA Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dorm      85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE milbase   85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE hosp      85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE othgph    85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE othgphsp  1='(1) Own home' 2='(2) Married'
                  3='(3) Moved to another home, not specified' 4='(4) Apartment'
                  5='(5) Own apartment' 6='(6) Trailer' 7='(7) Foster home'
                  8='(8) Nursing home' 9='(9) Died' 10='(10) Lives out of state/city'
                  11='(11) Staying with a friend' 12='(12) Job corp' 13='(13) Townhouse'
                  14='(14) Overseas/out of country'
                  15='(15) Lives with his mother/relatives'
                  16='(16) Relative traveling out of country'
                  17='(17) With other children' 18='(18) Group housing in college'
                  19='(19) Runaway' 20='(20) Hotel' 85='(85) BAD DATA Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE service   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE milstat   2='(2) In a Reserves component'
                  3='(3) Separated/retired from Reserves or activ'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE telno     94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE moves     94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE eap       1='(1) AM' 2='(2) PM' 97='(97) REFUSED' 98='(98) BLANK(NO ANSWER)' ;
  VALUE undint    1='(1) No difficulty-no language or reading pr'
                  2='(2) Just a little difficulty-almost no lang/'
                  3='(3) Fair amount of difficulty-some lang prob'
                  4='(4) Difficulty-lang prob' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE coopint   1='(1) Very cooperative' 2='(2) Fairly cooperative'
                  3='(3) Not very cooperative' 4='(4) Openly hostile' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE privacy   1='(1) Completely private-no one present/able t'
                  3='(3) Minor distractions'
                  5='(5) Person(s) in room or listening 1/3 of th'
                  7='(7) Serious interruptions more than half the'
                  9='(9) Constant presence of other person(s)'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ppres     1='(1) Response circled' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE spres     2='(2) Response Circled' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE parpres   3='(3) Response Circled' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE oarpres   4='(4) Response Circled' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE oapres    5='(5) Response Circled' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE cpres     6='(6) Response Circled' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE opresnsp  7='(7) Response circled' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE opresspa  11='(11) Head of household, employer' 12='(12) Spouse'
                  13='(13) Live-in partner, fiancee' 14='(14) Mother' 15='(15) Father'
                  16='(16) Daughter' 17='(17) Son' 18='(18) Sister' 19='(19) Brother'
                  20='(20) Grandmother' 21='(21) Grandfather'
                  22='(22) Other female blood relative'
                  23='(23) Other male blood relative' 26='(26) Other female in-laws'
                  27='(27) Other male in-laws' 28='(28) Close female friend'
                  29='(29) Close male friend'
                  30='(30) Other female acquaintance, roommate' 32='(32) Step-mother'
                  33='(33) Step-father' 40='(40) Friend (sex unspecified), boarder'
                  41='(41) Parents' 42='(42) Grandparents'
                  43='(43) Guardian (sex unspecified)'
                  44='(44) Foster mother, female guardian'
                  46='(46) Governess, nanny or live-in babysitter'
                  47='(47) Home care worker or health care aide'
                  48='(48) Housekeeper or maid' 50='(50) Multiple people listed'
                  51='(51) Relative, sex not specified'
                  52='(52) Roommate, sex not specified'
                  53='(53) Neighbor, sex not specified' 55='(55) Escort'
                  56='(56) Unspecified relationship'
                  58='(58) Foreign exchange student/student'
                  59='(59) Adult children/children'
                  60='(60) Foster grandchild/foster child' 61='(61) Siblings'
                  62='(62) Co-worker' 63='(63) Visitor' 64='(64) Students'
                  66='(66) Child (specified or not specified)' 71='(71) Male child'
                  72='(72) Customers' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE whomarkd  1='(1) Respondent marked ALL the Answer Sheet r'
                  2='(2) Interviewer marked All the Answer Sheet'
                  3='(3) Combination of respondent and F.I .....' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE miles     99985='(99985) BAD DATA Logically assigned'
                  99989='(99989) LEGITIMATE SKIP Logically assigned'
                  99991='(99991) HAS NEVER DRIVEN A MOTOR VEHICLE' 99994='(99994) DONT KNOW'
                  99995='(99995) BAD DATA' 99997='(99997) REFUSED' 99998='(99998) BLANK (NO ANSWER)'
                  99999='(99999) LEGITIMATE SKIP' ;
  VALUE mother    0='(0) No (i.e., Legitimate skip or response no' 1='(1) Yes'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE father    0='(0) No (i.e., Legitimate skip or response no' 1='(1) Yes'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stepmom   0='(0) No (i.e., Legitimate skip or response no' 1='(1) Yes'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stepdad   0='(0) No (i.e., Legitimate skip or response no' 1='(1) Yes'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE spouse    0='(0) No (i.e., Legitimate skip or response no' 1='(1) Yes'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inlaw     0='(0) No (i.e., Legitimate skip or response no'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) RELATION INDICATED, NO COUNT RECORDED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ownchild  0='(0) No (i.e., Legitimate skip or response no'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) RELATION INDICATED, NO COUNT RECORDED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stepchld  0='(0) No (i.e., Legitimate skip or response no'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) RELATION INDICATED, NO COUNT RECORDED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE brosis    0='(0) No (i.e., Legitimate skip or response no'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) RELATION INDICATED, NO COUNT RECORDED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othrel    0='(0) No (i.e., Legitimate skip or response no'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) RELATION INDICATED, NO COUNT RECORDED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE friends   0='(0) No (i.e., Legitimate skip or response no'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) RELATION INDICATED, NO COUNT RECORDED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othernon  0='(0) No (i.e., Legitimate skip or response no'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) RELATION INDICATED, NO COUNT RECORDED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE totpeop   94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nochild   89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (IRAGE<15)' ;
  VALUE cigrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED CIGARETTES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE bap       1='(1) AM' 2='(2) PM' 98='(98) BLANK (NO ANSWER)' ;
  VALUE langver   1='(1) English' 2='(2) Spanish' 98='(98) BLANK (NO ANSWER)' ;
  VALUE urbare    1='(1) Yes' 2='(2) No' 3='(3) Not in any of the 6 metropolitan areas' ;
  VALUE cencty    1='(1) Yes' 2='(2) No' 3='(3) Not in any of the 6 metropolitan areas' ;
  VALUE gqtyp     1='(1) Dormitory' 2='(2) Other Group Quarters'
                  3='(3) Not Group Quarters' ;
  VALUE irhogrpf  1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  5='(5) Central American' 6='(6) South American' 7='(7) Carribean'
                  99='(99) LEGITIMATE SKIP Respondent is not hispan' ;
  VALUE iihogrpf  1='(1) Hispanic-Origin Group taken from questio'
                  3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP Respondent is not hispan' ;
  VALUE famskip   0='(0) Respondent has other family members in h'
                  1='(1) Respondent didnt have other family in h' ;
  VALUE work      1='(1) Worked only for an employer' 2='(2) Was self-employed only'
                  3='(3) Self-employed and working for an employe'
                  4='(4) Did not work during the month'
                  5='(5) Did work during the month, logically ass'
                  6='(6) Did not work during the month LOGICALLY' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wag1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE soc1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ssi1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wel1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE int1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE chd1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE oth1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wag2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE soc2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ssi2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wel2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE int2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE chd2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE oth2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE food      1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE awag1fff  999985='(999985) BAD DATA Logically assigned'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE asoc1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DONT KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE assi1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DONT KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE awel1fff  999985='(999985) BAD DATA Logically assigned'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE aint1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DONT KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE achd1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DONT KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE aoth1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DONT KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE awag2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DONT KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE asoc2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DONT KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE assi2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DONT KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE awel2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE aint2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DONT KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE achd2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DONT KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE aoth2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DONT KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE afood     999985='(999985) BAD DATA Logically assigned' 999994='(999994) DONT KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE irwag1ff  1='(1) Yes' 2='(2) No' ;
  VALUE irsoc1ff  1='(1) Yes' 2='(2) No' ;
  VALUE irssi1ff  1='(1) Yes' 2='(2) No' ;
  VALUE irwel1ff  1='(1) Yes' 2='(2) No' ;
  VALUE irint1ff  1='(1) Yes' 2='(2) No' ;
  VALUE irchd1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iroth1ff  1='(1) Yes' 2='(2) No' ;
  VALUE irwag2ff  1='(1) Yes' 2='(2) No' ;
  VALUE irsoc2ff  1='(1) Yes' 2='(2) No' ;
  VALUE irssi2ff  1='(1) Yes' 2='(2) No' ;
  VALUE irwel2ff  1='(1) Yes' 2='(2) No' ;
  VALUE irint2ff  1='(1) Yes' 2='(2) No' ;
  VALUE irchd2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iroth2ff  1='(1) Yes' 2='(2) No' ;
  VALUE irfood    1='(1) Yes' 2='(2) No' ;
  VALUE irawag1f  0='(0) zero income received' ;
  VALUE irasoc1f  0='(0) zero income received' ;
  VALUE irassi1f  0='(0) Zero income received' ;
  VALUE irawel1f  0='(0) Zero income received' ;
  VALUE iraint1f  0='(0) Zero income received' ;
  VALUE irachd1f  0='(0) Zero income received' ;
  VALUE iraoth1f  0='(0) Zero income received' ;
  VALUE irawag2f  0='(0) Zero income received' ;
  VALUE irasoc2f  0='(0) zero income received' ;
  VALUE irassi2f  0='(0) Zero income received' ;
  VALUE irawel2f  0='(0) Zero income received' ;
  VALUE iraint2f  0='(0) Zero income received' ;
  VALUE irachd2f  0='(0) Zero income received' ;
  VALUE iraoth2f  0='(0) Zero income received' ;
  VALUE irafood   0='(0) Zero income received' ;
  VALUE iiwag1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iisoc1ff  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iissi1ff  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iiwel1ff  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iiint1ff  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iichd1ff  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iioth1ff  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iiwag2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iisoc2ff  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE iissi2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiwel2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiint2ff  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE iichd2ff  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE iioth2ff  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE iifood    1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iiawag1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiasoc1f  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE iiassi1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiawel1f  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE iiaint1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiachd1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiaoth1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiawag2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiasoc2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiassi2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiawel2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiaint2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiachd2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiaoth2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iiafood   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE job       1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hours     985='(985) BAD DATA Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE weeks     94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pub1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE afdc1fff  1='(1) Income from AFDC/ADC' 2='(2) Income from Other'
                  3='(3) Income from Both' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pub2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE afdc2fff  1='(1) Income from AFDC/ADC' 2='(2) Income from Other'
                  3='(3) Income from Both'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fstamp    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE peopfd    85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE welfare   1='(1) Yes, respondent or another fam member on'
                  2='(2) No, there was no one in the family on we' ;
  VALUE twofam    0='(0) 1 was sampled or 2 unrelated people were'
                  1='(1) Respondent is 1 of 2 related people samp' ;
  VALUE indinc    0='(0) No personal earnings' ;
  VALUE iiindinc  1='(1) All personal income sources from questio'
                  3='(3) At least 1 of sources were stat or logic' ;
  VALUE totinc    0='(0) No family income' ;
  VALUE iitotinc  1='(1) All income sources from questionnaire'
                  3='(3) At least 1 of sources were stat or logic' ;
  VALUE indcat    1='(1) $0' 2='(2) $1-$4,999' 3='(3) $5,000-$6,999' 4='(4) $7,000-$8,999'
                  5='(5) $9,000-$11,999' 6='(6) $12,000-$14,999' 7='(7) $15,000-$19,999'
                  8='(8) $20,000-$24,999' 9='(9) $25,000-$29,999'
                  10='(10) $30,000-$39,999' 11='(11) $40,000-$49,999'
                  12='(12) $50,000-$74,999' 13='(13) $75,000 +' ;
  VALUE totcat    1='(1) $0' 2='(2) $1-$4,999' 3='(3) $5,000-$6,999' 4='(4) $7,000-$8,999'
                  5='(5) $9,000-$11,999' 6='(6) $12,000-$14,999' 7='(7) $15,000-$19,999'
                  8='(8) $20,000-$24,999' 9='(9) $25,000-$29,999'
                  10='(10) $30,000-$39,999' 11='(11) $40,000-$49,999'
                  12='(12) $50,000-$74,999' 13='(13) $75,000 +' ;
  VALUE perinc    1='(1) $0-$8,999' 2='(2) $9,000-$19,999' 3='(3) $20,000-$39,999'
                  4='(4) $40,000-$74,999' 5='(5) $75,000 +' ;
  VALUE faminc    1='(1) $0-$8,999' 2='(2) $9,000-$19,999' 3='(3) $20,000-$39,999'
                  4='(4) $40,000-$74,999' 5='(5) $75,000 +' ;
  VALUE perinc2f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000 +' ;
  VALUE faminc2f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000 +' ;
  VALUE faminc3f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000 +' 8='(8) 12-17 Years Old' ;
  VALUE perinc3f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000 +' 8='(8) 12-17 Years Old' ;
  VALUE prvhltin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE plyflagc  1='(1) 0 drugs' 2='(2) 1 drug' 3='(3) 2 drugs' 4='(4) 3+ drugs' ;
  VALUE plyyrc    1='(1) 0 drugs' 2='(2) 1 drug' 3='(3) 2 drugs' 4='(4) 3+ drugs' ;
  VALUE plymonc   1='(1) 0 drugs' 2='(2) 1 drug' 3='(3) 2 drugs' 4='(4) 3+ drugs' ;
  VALUE wpstat    1='(1) Females w/at least 1 under age 2 (either'
                  2='(2) Females w/all children age 2 or older'
                  3='(3) Females w/no children'
                  4='(4) Females w/missing information about chil' 5='(5) Males' ;
  VALUE ownoconc  1='(1) Greater than or equal to 50'
                  2='(2) Greater than or equal to 10, but less th'
                  3='(3) Less than 10' ;
  VALUE nhbhconc  1='(1) Greater than or equal to 50'
                  2='(2) Greater than or equal to 10, but less th'
                  3='(3) Less than 10' ;
  VALUE nhbpconc  1='(1) Greater than or equal to 50'
                  2='(2) Greater than or equal to 10, but less th'
                  3='(3) Less than 10' ;
  VALUE hsppconc  1='(1) Greater than or equal to 50'
                  2='(2) Greater than or equal to 10, but less th'
                  3='(3) Less than 10' ;
  VALUE hsphconc  1='(1) Greater than or equal to 50'
                  2='(2) Greater than or equal to 10, but less th'
                  3='(3) Less than 10' ;
  VALUE metro     1='(1) Chicago Metropolitan area' 2='(2) Denver Metropolitan area'
                  3='(3) Los Angeles Metropolitan area'
                  4='(4) Miami Metropolitan area' 5='(5) New York Metropolitan area'
                  6='(6) Washington, D.C. Metropolitan area ....'
                  9='(9) Not in any of the 6 Metropolitan areas' ;
  VALUE proxable  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE proxyrel  1='(1) Respondents spouse/live-in partner'
                  2='(2) Respondents father' 3='(3) Respondents mother'
                  4='(4) Respondents brother' 5='(5) Respondents sister'
                  6='(6) Other family member, relation not specif' 12='(12) Spouse'
                  13='(13) Live-in partner, fiancee' 14='(14) Mother' 15='(15) Father'
                  16='(16) Daughter' 17='(17) Son' 18='(18) Sister' 19='(19) Brother'
                  20='(20) Grandmother' 21='(21) Grandfather'
                  22='(22) Other female blood relative'
                  23='(23) Other male blood relative' 26='(26) Other female in-laws'
                  27='(27) Other male in-laws' 29='(29) Close male friend'
                  32='(32) Step-mother' 33='(33) Step-father'
                  40='(40) Friend (sex unspecified), boarder' 42='(42) Grandparents'
                  43='(43) Guardian (sex unspecified)'
                  44='(44) Foster mother, female guardian'
                  45='(45) Foster father, male guardian'
                  50='(50) Multiple people listed'
                  51='(51) Relative, sex not specified'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE proxhome  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE proxjoin  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE medicare  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE medicaid  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE champus   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ownhltin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE grphltin  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltinalc  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltindrg  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltinmnt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE whoanshi  1='(1) Sample member' 2='(2) Proxy'
                  11='(11) Head of the Household, Employer' 12='(12) Spouse'
                  13='(13) Live-in partner, fiancee' 14='(14) Mother' 15='(15) Father'
                  16='(16) Daughter' 17='(17) Son' 18='(18) Sister' 19='(19) Brother'
                  20='(20) Grandmother' 21='(21) Grandfather'
                  22='(22) Other female blood relative'
                  23='(23) Other male blood relative' 26='(26) Other female in-laws'
                  27='(27) Other male in-laws' 28='(28) Close female friend'
                  29='(29) Close male friend'
                  30='(30) Other female acquaintance, roommate' 32='(32) Step-mother'
                  33='(33) Step-father' 40='(40) Friend (sex unspecified), boarder'
                  41='(41) Parents' 42='(42) Grandparents'
                  44='(44) Guardian (sex unspecified)' 50='(50) Multiple people listed'
                  51='(51) Relative, sex not specified'
                  52='(52) Roommate, sex not specified'
                  53='(53) Neighbor, sex not specified'
                  54='(54) Foster parent, sex not specified'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE whoansin  1='(1) Sample member' 2='(2) Pro'
                  11='(11) Head of the Household, Employer' 12='(12) Spouse'
                  13='(13) Live-in partner, fiancee' 14='(14) Mother' 15='(15) Father'
                  16='(16) Daughter' 17='(17) Son' 18='(18) Sister' 19='(19) Brother'
                  20='(20) Grandmother' 21='(21) Grandfather'
                  22='(22) Other female blood relative'
                  23='(23) Other male blood relative' 24='(24) Mother-in-law'
                  26='(26) Other female in-laws' 27='(27) Other male in-laws'
                  28='(28) Close female friend' 29='(29) Close male friend'
                  30='(30) Other female acquaintance, roommate'
                  31='(31) Other male acquaintance, roommate' 32='(32) Step-mother'
                  33='(33) Step-father' 39='(39) Other step relative, male'
                  40='(40) Friend (sex unspecified), boarder' 41='(41) Parents'
                  42='(42) Grandparents' 44='(44) Foster mother, female guardian'
                  50='(50) Multiple people listed'
                  51='(51) Relative, sex not specified'
                  52='(52) Roommate, sex not specified'
                  54='(54) Foster Parent, sex not specified'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE needlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE V' ;
  VALUE irinsur   1='(1) Yes, respondent does have health insuran'
                  2='(2) No, respondent does not have health insu' ;
  VALUE iiinsur   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE herrec9f  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HEROIN Logically imputed'
                  91='(91) NEVER USED HEROIN' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE irherc9f  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 9='(9) Never used heroin' ;
  VALUE iiherc9f  1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iralcagg  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcarg  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcabs  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralchig  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcjob  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcmat  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcrel  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcfrd  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralctos  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralchol  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcdru  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcint  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcrem  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcqui  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcmor  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcsho  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcalo  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE iralcbrk  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ 1)' ;
  VALUE irnobooz  1='(1) No use of alcohol in the past year'
                  2='(2) Used alcohol in the past year' ;
  VALUE anyalc    0='(0) No' 1='(1) Yes' ;
  VALUE threalc   0='(0) No' 1='(1) Yes' ;
  VALUE drunkyrf  0='(0) Unknown (DRUNKYR 85,96,97,98)'
                  1='(1) Drunk more than twice a month (DRUNKYR ='
                  2='(2) Drunk twice a month or less (DRUNKYR 5-'
                  3='(3) Never drunk in past year (DRUNKYR 9)' ;
  VALUE trmthlpf  0='(0) No (TRMTHELP=2)' 1='(1) Yes (TRMTHELP=1)' ;
  VALUE drnkhlpf  0='(0) No (DRNKHELP=2)' 1='(1) Yes (DRNKHELP=1)' ;
  VALUE dralhelp  0='(0) No (see note above)' 1='(1) Yes (TRMTHLP2=1 or DRNKHLP2=1)' ;
  VALUE iceflag   0='(0) Never used (IRICERC 9)' 1='(1) Ever used (IRICERC 1-6)' ;
  VALUE iceyr     0='(0) Did not use in past year (IRICERC=5-6,9)'
                  1='(1) Used within the past year (IRICERC=1-4)' ;
  VALUE icemon    0='(0) Did not use in the past month (IRICERC='
                  1='(1) Used within the past month (IRICERC=1-2)' ;
  VALUE mjtot2ff  1='(1) Never used marijuana (MJTOT 81,91)'
                  2='(2) 1-2 times (MJTOT 1)' 3='(3) 3-10 times (MJTOT 2,3)'
                  4='(4) 11-99 times (MJTOT 4,5)'
                  5='(5) 100 or more times (MJTOT 6,7)'
                  6='(6) Unknown (MJTOT 85,94,97,98)' ;
  VALUE coctot2f  1='(1) Never used cocaine (COCTOT 81,91)'
                  2='(2) 1-2 times (COCTOT 1)' 3='(3) 3-10 times (COCTOT 2,3)'
                  4='(4) 11-99 times (COCTOT 4,5)'
                  5='(5) 100 or more times (COCTOT 6,7)'
                  6='(6) Unknown (COCTOT 85,97,98)' ;
  VALUE mjtot3ff  1='(1) 1-2 times (MJTOT2 2)' 2='(2) 3-10 times (MJTOT2 3)'
                  3='(3) 11-99 times (MJTOT2 4)' 4='(4) 100 or more times (MJTOT2 5)'
                  5='(5) Never used marijuana (MJTOT2 1)' ;
  VALUE coctot3f  0='(0) Unknown (COCTOT2=6)' 1='(1) 1-2 times (COCTOT2 2)'
                  2='(2) 3-10 times (COCTOT2 3)' 3='(3) 11-99 times (COCTOT2 4)'
                  4='(4) 100 or more times (COCTOT2 5)'
                  5='(5) Never used cocaine (COCTOT2 1)' ;
  VALUE mjdy30af  1='(1) None/never used marijuana (MJDAY30A 0,8'
                  2='(2) 1-2 days (MJDAY30A 1-2)' 3='(3) 3-4 days (MJDAY30A 3-4)'
                  4='(4) 5-19 days (MJDAY30A 5-19)'
                  5='(5) 20-30 days (MJDAY30A 20-30)'
                  6='(6) Unknown (MJDAY30A 85,94,95,98)' ;
  VALUE alcdaysf  0='(0) Unknown (ALCDAYS=85,94,95,97,98)'
                  1='(1) None or never used alcohol (ALCDAYS 0,81'
                  2='(2) 1-2 days (ALCDAYS 1-2)' 3='(3) 3-4 days (ALCDAYS 3-4)'
                  4='(4) 5-19 days (ALCDAYS 5-19)' 5='(5) 20-30 days (ALCDAYS 20-31)' ;
  VALUE mrjmon2f  1='(1) Did not use in past month (MRJMON 0)'
                  2='(2) Used within the past month (MRJMON 1)' ;
  VALUE alcmon2f  1='(1) Did not use in the past month (ALCMON 0)'
                  2='(2) Used within the past month (ALCMON 1)' ;
  VALUE cigmon2f  1='(1) Did not use in past month (CIGMON 0)'
                  2='(2) Used within past month (CIGMON 1)' ;
  VALUE lsd2ffff  0='(0) Never used hallucinogens (LSD 2,81,91,9'
                  1='(1) Ever used LSD (LSD 1)' ;
  VALUE peyote2f  0='(0) Never used hallucinogens (PEYOTE 2,81,9'
                  1='(1) Ever used Peyote (PEYOTE 1)' ;
  VALUE mesc2fff  0='(0) Never used hallucinogens (MESC 2,81,91,9'
                  1='(1) Ever used Mescaline (MESC 1)' ;
  VALUE psilcy2f  0='(0) Never used hallucinogens (PSILCY 2,81,9'
                  1='(1) Ever used Psilocybin (PSILCY 1)' ;
  VALUE ecstasyf  0='(0) Never used hallucinogens (ECSTASY=2,81,9'
                  1='(1) Ever used Ecstasy (ECSTASY=1)' ;
  VALUE gas2ffff  0='(0) Never inhaled (GAS 2,81,91,98)'
                  1='(1) Ever inhaled (GAS 1,3)' ;
  VALUE lgas2fff  0='(0) Never inhaled (LGAS=2,81,91,98)'
                  1='(1) Ever inhaled (LGAS=1,3)' ;
  VALUE sppaintf  0='(0) Never inhaled (SPPAINT 2,81,91,98)'
                  1='(1) Ever inhaled (SPPAINT 1,3)' ;
  VALUE aeros2ff  0='(0) Never inhaled (AEROS 2,81,91,98)'
                  1='(1) Ever inhaled (AEROS 1,3)' ;
  VALUE glue2fff  0='(0) Never inhaled (GLUE 2,81,91,98)'
                  1='(1) Ever inhaled (GLUE 1,3)' ;
  VALUE solventf  0='(0) Never inhaled (SOLVENT 2,81,91,98)'
                  1='(1) Ever inhaled (SOLVENT 1,3)' ;
  VALUE amylnitf  0='(0) Never inhaled (AMYLNIT 2,81,91,98)'
                  1='(1) Ever inhaled (AMYLNIT 1,3)' ;
  VALUE ether2ff  0='(0) Never inhaled (ETHER 2,81,91,98)'
                  1='(1) Ever inhaled (ETHER 1,3)' ;
  VALUE nitoxidf  0='(0) Never inhaled (NITOXID 2,81,91,98)'
                  1='(1) Ever inhaled (NITOXID 1,3)' ;
  VALUE cleflu2f  0='(0) Never inhaled (CLEFLU 2,81,91,98)'
                  1='(1) Ever inhaled (CLEFLU 1,3)' ;
  VALUE cocsni0f  0='(0) Never/no use pst 12 mos (COCSNIFF=2,81,8'
                  1='(1) Sniffed/snorted in past 12 months (COCSN' ;
  VALUE freebasf  0='(0) Never/no use pst 12 mos (FREEBASE=2,81,8'
                  1='(1) Freebased in past 12 months (FREEBASE =' ;
  VALUE cocswalf  0='(0) Never/no use pst 12 mos (COCSWAL=2,81,83'
                  1='(1) Swallowed/drank in past 12 months (COCSW' ;
  VALUE cociv2ff  0='(0) Never/no use past 12 mos (COCIV=2,81,83,'
                  1='(1) Injected in the past 12 months (COCIV =' ;
  VALUE mjdy300f  1='(1) 1-2 days (MJDAY30A2 2)' 2='(2) 3-4 days (MJDAY30A2 3)'
                  3='(3) 5-19 days (MJDAY30A2 4)' 4='(4) 20-30 days (MJDAY30A2 5)'
                  5='(5) None or never used marijuana (MJDAY30A21' ;
  VALUE alcday0f  0='(0) Unknown (ALCDAYS2 .)'
                  1='(1) None or never used alcohol (ALCDAYS2 1)'
                  2='(2) 1-4 days (ALCDAYS2 2-3)' 3='(3) 5-19 days (ALCDAYS2 4)'
                  4='(4) 20-30 days (ALCDAYS2 5)' ;
  VALUE drinkerf  0='(0) Never/no ALC use (ALCMON=0 and DR5DAY=0,'
                  1='(1) Alcohol use (ALCMON 1 and DR5DAY = 0-30' ;
  VALUE hvydrk2f  0='(0) Never/no heavy use (DR5DAY=0-4,81,91,93)'
                  1='(1) Heavy alcohol use (DR5DAY 5-30)' ;
  VALUE avcig2ff  0='(0) Unknown (AVCIG'
                  1='(1) None/never smoked cigarettes (AVCIG=81,8'
                  2='(2) Currently smoke < a pack per day (AV = 1'
                  3='(3) Currently smoke a pack or more per day (' 94='(94) 97,98)' ;
  VALUE racesex   0='(0) Other males and females (SEX=1 or 2 and'
                  1='(1) White male (SEX = 1 and RACE 1)'
                  2='(2) Black male (SEX = 1 and RACE 2)'
                  3='(3) Hispanic male (SEX 1 and RACE 3)'
                  4='(4) White female (SEX 2 and RACE 1)'
                  5='(5) Black female (SEX 2 and RACE 2)'
                  6='(6) Hispanic female (SEX = 2 and RACE 3)' ;
  VALUE notmarj   0='(0) No (ALL SOURCE VARIABLES 0)'
                  1='(1) Yes (ANY SOURCE VARIABLES 1)' ;
  VALUE racesexf  1='(1) White male (SEX=1 and RACE=1)'
                  2='(2) Black male (SEX=1 and RACE=2)'
                  3='(3) Hispanic male (SEX=1 and RACE=3)'
                  4='(4) Other male (SEX=1 and RACE=4)'
                  5='(5) White female (SEX=2 and RACE=1)'
                  6='(6) Black female (SEX=2 and RACE=2)'
                  7='(7) Hispanic female (SEX=2 and RACE=3)'
                  8='(8) Other female (SEX=2 and RACE=4)' ;
  VALUE alconlyl  0='(0) No' 1='(1) Yes (ALCFLAG=1 AND SUMFLAG=0)' ;
  VALUE alconlyy  0='(0) No' 1='(1) Yes (ALCYR=1 AND SUMYR=0)' ;
  VALUE alconlym  0='(0) No' 1='(1) Yes (ALCMON=1 AND SUMMON=0)' ;
  VALUE illonlyl  0='(0) No' 1='(1) Yes (SUMFLAG=1 AND ALCFLAG=0)' ;
  VALUE illonlyy  0='(0) No' 1='(1) Yes (SUMYR=1 AND ALCYR=0)' ;
  VALUE illonlym  0='(0) No' 1='(1) Yes (SUMMON=1 AND ALCMON=0)' ;
  VALUE mrjonlyl  0='(0) No' 1='(1) Yes (MJOFLAG=1 AND ALCFLAG=0)' ;
  VALUE mrjonlyy  0='(0) No' 1='(1) Yes (MJOYR2=1,AND ALCYR=O)' ;
  VALUE mrjonlym  0='(0) No' 1='(1) Yes (MJOMON2=1 AND ALCMON=O)' ;
  VALUE psyonlyl  0='(0) No' 1='(1) Yes (PSYFLAG2=1 AND ALL OTHER SOURCE VAR' ;
  VALUE psyonlyy  0='(0) No' 1='(1) Yes (PSYYR2=1 AND ALL OTHER SOURCE VARS=' ;
  VALUE psyonlym  0='(0) No' 1='(1) Yes (PSYMON2=1 AND ALL OTHER SOURCE VARS' ;
  VALUE othonlyl  0='(0) No' 1='(1) Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR S' ;
  VALUE othonlyy  0='(0) No' 1='(1) Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR S' ;
  VALUE othonlym  0='(0) No' 1='(1) Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR S' ;
  VALUE alcilll   0='(0) No' 1='(1) Yes (ALCFLAG=1 AND SUMFLAG=1)' ;
  VALUE alcilly   0='(0) No' 1='(1) Yes (ALCYR=1 AND SUMYR=1)' ;
  VALUE alcillm   0='(0) No' 1='(1) Yes (ALCMON=1 AND SUMMON=1)' ;
  VALUE alcmrjl   0='(0) No' 1='(1) Yes (ALCFLAG, MRJFLAG=1 AND ALL OTHER SO' ;
  VALUE alcmrjy   0='(0) No' 1='(1) Yes (ALCYR AND MRJYR=1 AND ALL OTHER SOU' ;
  VALUE alcmrjm   0='(0) No' 1='(1) Yes (ALCMON & MRJMON=1 AND ALL OTHER S' ;
  VALUE alcpsyl   0='(0) No' 1='(1) Yes (ALCFLAG, PSYFLAG2=1 & ALL OTHER S' ;
  VALUE alcpsyy   0='(0) No' 1='(1) Yes (ALCYR & PSYYR2=1 AND ALL OTHER SO' ;
  VALUE alcpsym   0='(0) No' 1='(1) Yes (ALCMON & PSYMON2=1 & ALL OTHER' ;
  VALUE alcothl   0='(0) No' 1='(1) Yes (ALCFLAG=1 & NEXT 2 VAR=0 & ANY' ;
  VALUE alcothy   0='(0) No' 1='(1) Yes (ALCYR=1 & NEXT 2 VAR=0 & ANY OT' ;
  VALUE alcothm   0='(0) No' 1='(1) Yes (ALCMON=1 & NEXT 2 VAR=0 & ANY O' ;
  VALUE sub1lif   0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub2lif   0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub3lif   0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
  VALUE sub1yr    0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub2yr    0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub3yr    0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
  VALUE sub1mon   0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub2mon   0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub3mon   0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
  VALUE irdep     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 1)' ;
  VALUE irarg     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 1)' ;
  VALUE iraln     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 1)' ;
  VALUE iranx     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 1)' ;
  VALUE irhlt     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 1)' ;
  VALUE irntk     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 1)' ;
  VALUE irups     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 1)' ;
  VALUE irlsw     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 1)' ;
  VALUE irssp     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 1)' ;
  VALUE ircpe     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 1)' ;
  VALUE iremg     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 1)' ;
  VALUE irdep1ff  111='(111) Dalmane' 113='(113) Halcion'
                  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  122='(122) Sleep Aid <OTC>' 201='(201) Valium' 207='(207) Ativan'
                  208='(208) Centrax' 209='(209) Xanax' 211='(211) Buspar'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,uppers' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  406='(406) Percodan, Oxycodone'
                  409='(409) Tylenol with Codeine, Tylenol 3' 415='(415) Codeine'
                  423='(423) Percocet' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)' 603='(603) Mescaline'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  830='(830) Mad Bull' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep2ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 209='(209) Xanax'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  407='(407) Demerol' 415='(415) Codeine' 418='(418) Methadone'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)' 606='(606) Ecstasy (MDMA), X-TC'
                  702='(702) Heroin' 803='(803) Marijuana' 804='(804) Hashish'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep3ff  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid,white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep4ff  355='(355) Crystal meth' 601='(601) LSD (acid,white lightning)'
                  803='(803) Marijuana' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irdep5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg1ff  118='(118) Pentobarbital, Pentothal, Sodium Pentoth' 201='(201) Valium'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  327='(327) Black Beauty, Black beauties'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  406='(406) Percodan, Oxycodone'
                  409='(409) Tylenol with Codeine, Tylenol 3' 415='(415) Codeine'
                  423='(423) Percocet' 502='(502) Spray paints'
                  506='(506) Amyl nitrite,poppers, lock rm odoriz'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  830='(830) Mad Bull' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg2ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 301='(301) Dexedrine'
                  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 407='(407) Demerol'
                  415='(415) Codeine'
                  504='(504) Shoeshine lqd, glue/toluene; Super Glue;'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 609='(609) sic'
                  702='(702) Heroin' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg3ff  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid,white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg4ff  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  355='(355) Crystal meth' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 814='(814) Caffeine' 999='(999) LEGITIMATE SKIP' ;
  VALUE irarg5ff  702='(702) Heroin' 999='(999) LEGITIMATE SKIP' ;
  VALUE iraln1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  207='(207) Ativan' 211='(211) Buspar'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or cr' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  406='(406) Percodan, Oxycodone' 415='(415) Codeine' 423='(423) Percocet'
                  502='(502) Spray paints' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)' 603='(603) Mescaline'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  830='(830) Mad Bull' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln2ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 407='(407) Demerol'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln3ff  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln4ff  322='(322) Methamphetamine (speed or ice or cr' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 814='(814) Caffeine'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln5ff  702='(702) Heroin' 999='(999) LEGITIMATE SKIP' ;
  VALUE iranx1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  202='(202) Librium' 207='(207) Ativan' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 301='(301) Dexedrine'
                  313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  326='(326) White cross' 328='(328) Pink hearts' 332='(332) Ephedrine'
                  335='(335) Dexatrim' 336='(336) Diet pills'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  357='(357) Heart-shaped black pills' 358='(358) 20/20'
                  360='(360) Rainbow speed' 364='(364) Sudafed, Sinutab'
                  406='(406) Percodan, Oxycodone' 407='(407) Demerol'
                  409='(409) Tylenol with Codeine, Tylenol 3'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 435='(435) Tylenol <OTC>'
                  501='(501) Gasoline or lighter fluids'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)' 606='(606) Ecstasy (MDMA), X-TC'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  609='(609) Jimson (sic) weed' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  815='(815) Coffee' 816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  818='(818) Nicotine' 829='(829) Robitussin DM' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx2ff  209='(209) Xanax' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  326='(326) White cross' 333='(333) 357 Magnum, Magnum 44'
                  339='(339) Amphetamines (speed generically)' 407='(407) Demerol'
                  415='(415) Codeine' 506='(506) Amyl nitrite,poppers, lock rm odoriz'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecastasy (MDMA), X-TC' 702='(702) Heroin' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  818='(818) Nicotine' 999='(999) LEGITIMATE SKIP' ;
  VALUE iranx3ff  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)' 606='(606) Ecstasy (MDMA), X-TC'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx4ff  322='(322) Methamphetamine (speed or ice or cr'
                  601='(601) LSD (acid,white lightning)' 603='(603) Mescaline'
                  604='(604) Psilocybin (mushrooms)' 803='(803) Marijuana' 806='(806) Crack'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx5ff  702='(702) Heroin' 703='(703) Opium' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  123='(123) Unisom <OTC>' 201='(201) Valium'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or cr'
                  333='(333) 357 Magnum, Magnum 44'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 409='(409) Tylenol with Codeine, Tylenol 3'
                  504='(504) Shoeshine lqd, glue/toluene; Super Glue;'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  818='(818) Nicotine' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt2ff  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid,white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  818='(818) Nicotine' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt3ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt4ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  322='(322) Methamphetamine (speed or ice or cr'
                  601='(601) LSD (acid,white lightning)' 803='(803) Marijuana'
                  814='(814) Caffeine' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 142='(142) Belladona'
                  203='(203) Limbitrol' 209='(209) Xanax' 228='(228) Amitriptyline'
                  241='(241) Prozac' 313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  360='(360) Rainbow speed' 401='(401) Darvon' 406='(406) Percodan, Oxycodone'
                  409='(409) Tylenol with Codeine, Tylenol 3' 415='(415) Codeine'
                  422='(422) Motrin' 423='(423) Percocet' 462='(462) Norflex'
                  502='(502) Spray paints'
                  504='(504) Shoeshine lqd, glue/toluene; Super Glue;'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC' 609='(609) sic' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  830='(830) Mad Bull' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk2ff  201='(201) Valium' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  247='(247) Sinequan' 322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)' 360='(360) Rainbow speed'
                  407='(407) Demerol' 502='(502) Spray paints'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk3ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk4ff  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  802='(802) THC, Cannabinol' 803='(803) Marijuana' 999='(999) LEGITIMATE SKIP' ;
  VALUE irntk5ff  503='(503) Other aerosol sprays'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irups1ff  118='(118) Pentobarbital, Pentothal, Sodium Pentoth'
                  203='(203) Limbitrol' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 301='(301) Dexedrine'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  360='(360) Rainbow speed' 406='(406) Percodan, Oxycodone' 415='(415) Codeine'
                  601='(601) LSD (acid,white lightning)' 603='(603) Mescaline'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  818='(818) Nicotine' 830='(830) Mad Bull' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irups2ff  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  407='(407) Demerol' 502='(502) Spray paints'
                  601='(601) LSD (acid,white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  818='(818) Nicotine' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups3ff  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  506='(506) Amyl nitrite,poppers, lock rm odoriz'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irups4ff  503='(503) Other aerosol sprays' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw1ff  111='(111) Dalmane' 142='(142) Belladona' 211='(211) Buspar'
                  322='(322) Methamphetamine (speed or ice or cr' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 360='(360) Rainbow speed'
                  409='(409) Tylenol with Codeine, Tylenol 3' 415='(415) Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 422='(422) Motrin'
                  423='(423) Percocet' 435='(435) Tylenol <OTC>'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  609='(609) Jimson [sic) weed' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  812='(812) Cigars' 813='(813) Cigarettes, tobacco not specified'
                  814='(814) Caffeine' 815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  818='(818) Nicotine' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw2ff  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 360='(360) Rainbow speed'
                  524='(524) White-Out' 601='(601) LSD (acid,white lightning)'
                  702='(702) Heroin' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  818='(818) Nicotine' 999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw3ff  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  503='(503) Other aerosol sprays' 601='(601) LSD (acid,white lightning)'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw4ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 803='(803) Marijuana'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw5ff  601='(601) LSD (acid,white lightning)' 999='(999) LEGITIMATE SKIP' ;
  VALUE irssp1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 207='(207) Ativan'
                  211='(211) Buspar' 322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  360='(360) Rainbow speed' 371='(371) Cogentin' 415='(415) Codeine'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)' 603='(603) Mescaline'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  609='(609) Jimson (sic) weed' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  812='(812) Cigars' 813='(813) Cigarettes, tobacco not specified'
                  814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  818='(818) Nicotine' 830='(830) Mad Bull' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp2ff  131='(131) Haldol' 247='(247) Sinequan'
                  322='(322) Methamphetamine (speed or ice or cr'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid,white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 609='(609) sic'
                  702='(702) Heroin' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp3ff  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  601='(601) LSD (acid,white lightning)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp4ff  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irssp5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe1ff  201='(201) Valium' 207='(207) Ativan' 211='(211) Buspar'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or cr' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 360='(360) Rainbow speed'
                  406='(406) Percodan, Oxycodone'
                  409='(409) Tylenol with Codeine, Tylenol 3' 415='(415) Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 423='(423) Percocet'
                  502='(502) Spray paints' 601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  609='(609) Jimson [sic) weed' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  812='(812) Cigars' 813='(813) Cigarettes, tobacco not specified'
                  814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe2ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  324='(324) OTHER Stimulant, NOT SPECIFIED,Uppers'
                  339='(339) Amphetamines (speed generically)' 407='(407) Demerol'
                  502='(502) Spray paints' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  818='(818) Nicotine' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe3ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 229='(229) Librax'
                  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  360='(360) Rainbow speed' 701='(701) OTHER Opiates, NOT SPECIFIED'
                  702='(702) Heroin' 802='(802) THC, Cannabinol' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe4ff  209='(209) Xanax' 605='(605) PCP (angel dust, phencyclidine)'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe5ff  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg1ff  201='(201) Valium' 322='(322) Methamphetamine (speed or ice or cr'
                  335='(335) Dexatrim' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid,white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 615='(615) Homemade drugs'
                  702='(702) Heroin' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified' 818='(818) Nicotine'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE iremg2ff  339='(339) Amphetamines (speed generically)'
                  430='(430) Aspirin, Ecotrin, Empirin <OTC>'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 809='(809) Pills' 999='(999) LEGITIMATE SKIP' ;
  VALUE iremg3ff  601='(601) LSD (acid,white lightning)' 999='(999) LEGITIMATE SKIP' ;
  VALUE iremg4ff  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE iras13ff  1='(1) Never used any of the substances listed'
                  2='(2) Used one or more of the listed substance' ;
  VALUE anyprob   0='(0) No' 1='(1) Yes' ;
  VALUE twoprob   0='(0) No' 1='(1) Yes' ;
  VALUE threprob  0='(0) No' 1='(1) Yes' ;
  VALUE depcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE depalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE depmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE depcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE argcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE argalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE argmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE argcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE alncig2f  0='(0) No' 1='(1) Yes' ;
  VALUE alnalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE alnmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE alncoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE hltcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE hltalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE hltmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE hltcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE upscig2f  0='(0) No' 1='(1) Yes' ;
  VALUE upsalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE upsmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE upscoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpecig2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpealc2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpemrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpecoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE emcig2ff  0='(0) No' 1='(1) Yes' ;
  VALUE emalc2ff  0='(0) No' 1='(1) Yes' ;
  VALUE emmrj2ff  0='(0) No' 1='(1) Yes' ;
  VALUE emcoc2ff  0='(0) No' 1='(1) Yes' ;
  VALUE prb1cig   0='(0) No' 1='(1) Yes' ;
  VALUE prb1alc   0='(0) No' 1='(1) Yes' ;
  VALUE prb1mrj   0='(0) No' 1='(1) Yes' ;
  VALUE prb1coc   0='(0) No' 1='(1) Yes' ;
  VALUE prb2cig   0='(0) No' 1='(1) Yes' ;
  VALUE prb2alc   0='(0) No' 1='(1) Yes' ;
  VALUE prb2mrj   0='(0) No' 1='(1) Yes' ;
  VALUE prb2coc   0='(0) No' 1='(1) Yes' ;
  VALUE prb3cig   0='(0) No' 1='(1) Yes' ;
  VALUE prb3alc   0='(0) No' 1='(1) Yes' ;
  VALUE prb3mrj   0='(0) No' 1='(1) Yes' ;
  VALUE prb3coc   0='(0) No' 1='(1) Yes' ;
  VALUE ircdcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in p'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in p'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in p'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in p'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for s'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for s'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for s'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for s'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past y'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past y'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past y'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past y'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug u'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug u'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug u'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug u'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwscig   1='(1) Yes' 2='(2) No' 13='(13) Did not have withdrawal symptoms in the'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwsalc   1='(1) Yes' 2='(2) No' 13='(13) Did not have withdrawal symptoms in the'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwsmj    1='(1) Yes' 2='(2) No' 13='(13) Did not have withdrawal symptoms in the'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwscoc   1='(1) Yes' 2='(2) No' 13='(13) Did not have withdrawal symptoms in the'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE avcig3ff  0='(0) None/never/< pack a day (AVCIG=1-3,81,89'
                  1='(1) Currently smoke a pack or more per day (' ;
  VALUE alcprobs  0='(0) No' 1='(1) Yes' ;
  VALUE mjprobs   0='(0) No' 1='(1) Yes' ;
  VALUE cocprobs  0='(0) No' 1='(1) Yes' ;
  VALUE cigprobs  0='(0) No' 1='(1) Yes' ;
  VALUE qc06ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE qc09ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED SMOKELESS TOBACCO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE al02ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE se04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tr04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE st04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 98='(98) BLANK (NO ANSWER)' ;
  VALUE st07ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago'
                  91='(91) NEVER USED ANY AMPHETAMINE WITH A NEEDLE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE an04ffff  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mj04ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE in04ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED INHALANTS'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cc04ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED COCAINE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cc10ffff  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago' 91='(91) NEVER USED COCAINE'
                  93='(93) NEVER USED COCAINE WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cc11ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 mon'
                  3='(3) 1 or more months ago but less than 6 mon'
                  4='(4) 6 or more months ago but less than 1 yea'
                  5='(5) 1 or more years ago but less than 3 year'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED CRACK' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ls05ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED HALLUCINOGENS'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ls08ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED PCP'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE he04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED HEROIN'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE he07ffff  1='(1) within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago' 91='(91) NEVER USED HEROIN'
                  93='(93) NEVER USED HEROIN WITH A NEEDLE (HERNEED'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dr08ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago'
                  91='(91) NEVER USED ANY DRUG FOR NONMEDICAL REASO'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sp04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago but less than 10 yea'
                  6='(6) 10 or more years ago'
                  91='(91) Never used the smokable form of amphetam'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sp08ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 mo'
                  3='(3) 6 or more months ago but less than 1 yea'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED STEROIDS IN LIFE'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othdospf  1='(1) Shoplifting (SP15a)' 2='(2) Other larceny or theft (SP15b)'
                  3='(3) Property damage (incl vandalism)(SP15c)'
                  4='(4) Motor vehicle theft (SP15d)' 5='(5) Robbery (SP15e, i)'
                  6='(6) Breaking and entering, burglary (SP15f)'
                  7='(7) Hitting someone or physically fighting'
                  8='(8) Hurting someone enough to need medical a'
                  9='(9) Other assault, battery'
                  10='(10) Driving under influence of alcohol/drugs'
                  11='(11) Selling illegal drugs (SP15k)'
                  12='(12) Drug offense (except sales) involving ma'
                  13='(13) Other drug-related offense'
                  14='(14) Drunkeness or other liquor law violation'
                  15='(15) Forcible rape'
                  16='(16) Murder, homicide or nonnegligent manslau'
                  17='(17) Other offenses against persons' 18='(18) Arson'
                  19='(19) Nondestructive property offenses, e.g. f'
                  20='(20) Prostitution or commercialized sex'
                  21='(21) Weapons offenses'
                  22='(22) Violation of court order, parole, probat'
                  23='(23) Public order offenses' 24='(24) Juvenile status offenses'
                  25='(25) Immigration law violation' 26='(26) Traffic violations'
                  27='(27) Other offenses, NOT SPECIFIED'
                  85='(85) BAD DATA (i.e., cannot be classified).' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othdos0f  1='(1) Shoplifting (SP15a)' 2='(2) Other larceny or theft (SP15b)'
                  3='(3) Property damage (incl vandalism) (SP15c)'
                  5='(5) Robbery (SP15e, i)'
                  7='(7) Hitting someone or physically fighting ('
                  10='(10) Driving under influence of alcohol/drugs'
                  11='(11) Selling illegal drugs (SP15k)'
                  12='(12) Drug offense (except sales) involving ma'
                  13='(13) Other drug-related offenses'
                  14='(14) Drunkeness or other liquor law violation'
                  16='(16) Murder, homicide or nonnegligent manslau'
                  19='(19) Nondestructive property offenses, such a'
                  21='(21) Weapons offenses' 23='(23) Public order offenses'
                  24='(24) Juvenile status offenses'
                  25='(25) Immigration law violation' 26='(26) Traffic violations'
                  85='(85) BAD DATA (i.e., cannot be classified).' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocway2f  0='(0) Never/no use pst 12 mos (COCWAY=2,3,81,8'
                  1='(1) Used other ways past 12 months (COCWAY=1' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=2620;
INPUT
        CASEID 2616-2620        CHAGE1 1                CHAGE2 2
        CHAGE3 3                CHAGE4 4                CHAGE5 5
        CHAGE6 6                CHAGE7 7                CHAGE8 8
        CHAGE9 9-10             CHAGE10 11-12           CWEOCC2 13-15
        ROCCUP2 16-18           BUSINES2 19-21          CWEBUS2 22-24
        SNUFREC 25-26           ALCREC 27-28            SEDREC 29-30
        TRANREC 31-32           STIMREC 33-34           STNDLREC 35-36
        ANALREC 37-38           MJREC 39-40             INHREC 41-42
        CRAKREC 43-44           COCREC 45-46            CONDLREC 47-48
        PCPREC 49-50            HALLREC 51-52           HERREC 53-54
        HRNDLREC 55-56          GNNDLREC 57-58          ICEREC 59-60
        STERREC 61-62           ALCSED 63-64            ALCTRAN 65-66
        ALCSTM 67-68            ALCANAL 69-70           ALCMJ 71-72
        ALCINH 73-74            ALCCOC 75-76            ALCHAL 77-78
        ALCOPT 79-80            ALCNONE 81-82           CIGTRY 83-85
        CIGAGE 86-88            CIGYRS 89-91            ALCTRY 92-94
        ALCAGE 95-97            SEDAGE 98-100           TRANAGE 101-103
        STIMAGE 104-106         ANALAGE 107-109         MJOPP 110-112
        MJAGE 113-115           INHAGE 116-118          COCOPP 119-121
        COCAGE 122-124          HALLOPP 125-127         HALLAGE 128-130
        HEROPP 131-133          HERAGE 134-136          STEROPP 137-139
        STERAGE 140-142         OTHTOB 143-144          ALCPAT 145-146
        SEDYRFRQ 147-148        TRNYRFRQ 149-150        STMYRFRQ 151-152
        ANLYRFRQ 153-154        MJYRFREQ 155-156        INHYRFRQ 157-158
        COCYRFRQ 159-160        HALYRFRQ 161-162        CIG5PK 163-164
        PACKS 165-166           AVCIG 167-168           CIGTIME 169-172
        ALCDAYS 173-174         NODR30A 175-176         DR5DAY 177-178
        MODR30A 179-180         MODR30DY 181-182        DRUNKYR 183-184
        ALCBEER 185-186         ALCWINE 187-188         ALCLIQR 189-190
        ALCVARY 191-192         NOBOOZYR 193-194        ALCAGGR 195-196
        ALCARGUM 197-198        ALCABSNT 199-200        ALCHIGH 201-202
        ALCJOB 203-204          ALCMATCD 205-206        ALCRELCD 207-208
        ALCFRDCD 209-210        ALCTOSS 211-212         ALCHOLIC 213-214
        ALCDRUNK 215-216        ALCINTOX 217-218        ALCREM 219-220
        ALCQUICK 221-222        ALCMORN 223-224         ALCSHOOK 225-226
        ALCALONE 227-228        ALCBRKPM 229-230        BUTISOL 231-232
        BUTICAPS 233-234        AMYTAL 235-236          MEBARAL 237-238
        PLACIDYL 239-240        DORIDEN 241-242         NOLUDAR 243-244
        NEMBUTAL 245-246        SECONAL 247-248         TUINAL 249-250
        DALMANE 251-252         RESTORIL 253-254        HALCION 255-256
        AMOBARB 257-258         PHENOBAR 259-260        METHAQ 261-262
        CHHYD 263-264           PENTOB 265-266          SECOB 267-268
        SEDNOSP 269-270         SEDNEWA 271-273         SEDNEWB 274-276
        SEDNEWC 277-279         SEDNEWD 280-282         SEDNEWE 283-285
        SEDDKNAM 286-287        NOSEDAT 288-289         SEDTOT 290-291
        VALIUM 292-293          LIBRIUM 294-295         LIMBTROL 296-297
        MENRIUM 298-299         SERAX 300-301           TRANXENE 302-303
        ATIVAN 304-305          CENTRAX 306-307         XANAX 308-309
        PAXIPAM 310-311         BUSPAR 312-313          MILTOWN 314-315
        EQUANIL 316-317         DEPROL 318-319          VISTAR 320-321
        ATARAX 322-323          DURRAX 324-325          DIAZEPAM 326-327
        SKLY 328-329            MEPROB 330-331          TRNOSP 332-333
        TRNEWA 334-336          TRNEWB 337-339          TRNEWC 340-342
        TRNEWD 343-345          TRNEWE 346-348          TRDKNAM 349-350
        NOTRANQ 351-352         TRANTOT 353-354         DEXED 355-356
        DEXAMYL 357-358         ESKAT 359-360           BENZ 361-362
        BIPHET 363-364          DESOXYN 365-366         TENUATE 367-368
        TEPANIL 369-370         DIDREX 371-372          PLEGINE 373-374
        PRELUDIN 375-376        IONAMIN 377-378         FASTIN 379-380
        PONDIMIN 381-382        VORANIL 383-384         SANOREX 385-386
        MAZANOR 387-388         RITALIN 389-390         CYLERT 391-392
        DETAMP 393-394          METHI 395-396           METHAMP 397-398
        OBLA 399-400            STIMNOSP 401-402        STIMNEWA 403-405
        STIMNEWB 406-408        STIMNEWC 409-411        STIMNEWD 412-414
        STIMNEWE 415-417        STMDKNAM 418-419        NOSTIMS 420-421
        STIMTOT 422-423         STNEEDLE 424-425        DARVON 426-427
        DOLENE 428-429          SK65A 430-431           WYGESIC 432-433
        LEVODRO 434-435         PERCODAN 436-437        DEMEROL 438-439
        DILAUD 440-441          TYLCOD 442-443          PHENCOD 444-445
        TALWIN 446-447          TALWINNX 448-449        TALACEN 450-451
        PROPOXY 452-453         CODEINE 454-455         ANILERID 456-457
        MORPHINE 458-459        METHDON 460-461         STADOL 462-463
        ANLNOSP 464-465         ANALNEWA 466-468        ANALNEWB 469-471
        ANALNEWC 472-474        ANALNEWD 475-477        ANALNEWE 478-480
        ANLDKNAM 481-482        ANALNONE 483-484        ANALTOT 485-486
        MJTOT 487-488           MJDAY30A 489-490        MJAV30A 491-492
        MJAV30B 493-494         MJAMT30A 495-496        MJJOINT 497-498
        MJPIPE 499-500          MJBAKE 501-502          MJCHEW 503-504
        MJWAY 505-506           GAS 507-508             LGAS 509-510
        SPPAINT 511-512         AEROS 513-514           GLUE 515-516
        SOLVENT 517-518         AMYLNIT 519-520         ETHER 521-522
        NITOXID 523-524         CLEFLU 525-526          INHNOSP 527-528
        INHDKNAM 529-530        INHTOT 531-532          GAS30A 533-534
        LGAS30A 535-536         SPPAN30A 537-538        AEROS30A 539-540
        GLUE30A 541-542         SOLVN30A 543-544        AMLNT30A 545-546
        ETHER30A 547-548        NOX30A 549-550          CLFL30A 551-552
        IN30NOSP 553-554        INH30NO 555-556         INHDY30A 557-558
        INHEFF 559-560          INHPO 561-562           INHNEWA 563-565
        INHNEWB 566-568         INHNEWC 569-571         INHNEWD 572-574
        INHNEWE 575-577         INNEW30A 578-580        INNEW30B 581-583
        INNEW30C 584-586        INNEW30D 587-589        INNEW30E 590-592
        COCTOT 593-594          COCUS30A 595-596        CRKAM30A 597-599
        CRAKBUCK 600-603        COCAM30A 604-605        COCBUCK 606-609
        COCSNIFF 610-611        COCSWAL 612-613         COCIV 614-615
        FREEBASE 616-617        COCWAY 618-619          LSD 620-621
        PEYOTE 622-623          MESC 624-625            PSILCY 626-627
        PCP 628-629             ECSTASY 630-631         HALNOSP 632-633
        HALNEWA 634-636         HALNEWB 637-639         HALNEWC 640-642
        HALNEWD 643-645         HALNEWE 646-648         HALDKNAM 649-650
        HALLTOT 651-652         HAL30USE 653-654        HERTOT 655-656
        HER30USE 657-658        HERNEEDL 659-660        CDCIG 661-662
        CDALC 663-664           CDSED 665-666           CDTRAN 667-668
        CDSTM 669-670           CDANAL 671-672          CDMJ 673-674
        CDINH 675-676           CDCOC 677-678           CDHALL 679-680
        CDHER 681-682           CDOTHOP 683-684         CDNONE 685-686
        UCDCIG 687-688          UCDALC 689-690          UCDSED 691-692
        UCDTRAN 693-694         UCDSTM 695-696          UCDANAL 697-698
        UCDMJ 699-700           UCDINH 701-702          UCDCOC 703-704
        UCDHALL 705-706         UCDHER 707-708          UCDOTHOP 709-710
        UCDNONE 711-712         EFFCIG 713-714          EFFALC 715-716
        EFFSED 717-718          EFFTRAN 719-720         EFFSTM 721-722
        EFFANAL 723-724         EFFMJ 725-726           EFFINH 727-728
        EFFCOC 729-730          EFFHALL 731-732         EFFHER 733-734
        EFFOTHOP 735-736        EFFNONE 737-738         UDAYCIG 739-740
        UDAYALC 741-742         UDAYSED 743-744         UDAYTRAN 745-746
        UDAYSTM 747-748         UDAYANAL 749-750        UDAYMJ 751-752
        UDAYINH 753-754         UDAYCOC 755-756         UDAYHALL 757-758
        UDAYHER 759-760         UDAYOTH 761-762         UDAYNONE 763-764
        DEPCIG 765-766          DEPALC 767-768          DEPSED 769-770
        DEPTRAN 771-772         DEPSTM 773-774          DEPANAL 775-776
        DEPMJ 777-778           DEPINH 779-780          DEPCOC 781-782
        DEPHALL 783-784         DEPHER 785-786          DEPOTHOP 787-788
        DEPNONE 789-790         WSCIG 791-792           WSALC 793-794
        WSSED 795-796           WSTRAN 797-798          WSSTM 799-800
        WSANAL 801-802          WSMJ 803-804            WSINH 805-806
        WSCOC 807-808           WSHALL 809-810          WSHER 811-812
        WSOTHOP 813-814         WSNONE 815-816          GNNDLLIF 817-818
        GNNDLSED 819-820        GNNDLTRA 821-822        GNNDLSTM 823-824
        GNNDLANL 825-826        GNNDLMJ 827-828         GNNDLINH 829-830
        GNNDLCOC 831-832        GNNDLHAL 833-834        GNNDLHER 835-836
        GNNDLOPT 837-838        GNNDLNON 839-840        GNNDLSHR 841-842
        DRUGTEST 843-844        TESTPOS 845-846         ICELIFE 847-848
        STERTOT 849-850         BOOKED 851-852          NOBOOKYR 853-855
        BKLARCNY 856-857        BKBURGL 858-859         BKAGASLT 860-861
        BKSMASLT 862-863        BKMVTHFT 864-865        BKROB 866-867
        BKRAPE 868-869          BKMURDER 870-871        BKARSON 872-873
        BKDRVINF 874-875        BKDRUNK 876-877         BKDRUG 878-879
        BKPROS 880-881          BKVANDAL 882-883        BKOTHOFF 884-885
        NOTBKED 886-887         PROBATON 888-889        PAROLE 890-891
        STRSTEAL 892-893        OTHSTEAL 894-895        DAMAGE 896-897
        CARSTEAL 898-899        FORCEMON 900-901        BREAKIN 902-903
        PHYFIGHT 904-905        HURTBAD 906-907         GUNMONEY 908-909
        DRUNKDRV 910-911        SOLDDRUG 912-913        OTHDOING 914-915
        SPNEWA 916-918          SPNEWB 919-921          SPNEWC 922-924
        SPNEWD 925-927          SPNEWE 928-930          AS13NONE 931-932
        DRDEPRSS 933-934        DEPDRG1A 935-937        DEPDRG2A 938-940
        DEPDRG3A 941-943        DEPDRG4A 944-946        DEPDRG5A 947-949
        DRARGUM 950-951         ARGDRG1A 952-954        ARGDRG2A 955-957
        ARGDRG3A 958-960        ARGDRG4A 961-963        ARGDRG5A 964-966
        DRALONE 967-968         ALNDRG1A 969-971        ALNDRG2A 972-974
        ALNDRG3A 975-977        ALNDRG4A 978-980        ALNDRG5A 981-983
        DRANX 984-985           ANXDRG1A 986-988        ANXDRG2A 989-991
        ANXDRG3A 992-994        ANXDRG4A 995-997        ANXDRG5A 998-1000
        DRHEALTH 1001-1002      HLTDRG1A 1003-1005      HLTDRG2A 1006-1008
        HLTDRG3A 1009-1011      HLTDRG4A 1012-1014      HLTDRG5A 1015-1017
        DRNTHINK 1018-1019      NTKDRG1A 1020-1022      NTKDRG2A 1023-1025
        NTKDRG3A 1026-1028      NTKDRG4A 1029-1031      NTKDRG5A 1032-1034
        DRUPSET 1035-1036       UPSDRG1A 1037-1039      UPSDRG2A 1040-1042
        UPSDRG3A 1043-1045      UPSDRG4A 1046-1048      UPSDRG5A 1049-1051
        DRLSWORK 1052-1053      LSWDRG1A 1054-1056      LSWDRG2A 1057-1059
        LSWDRG3A 1060-1062      LSWDRG4A 1063-1065      LSWDRG5A 1066-1068
        DRSUSPIC 1069-1070      SSPDRG1A 1071-1073      SSPDRG2A 1074-1076
        SSPDRG3A 1077-1079      SSPDRG4A 1080-1082      SSPDRG5A 1083-1085
        DRCOPE 1086-1087        CPEDRG1A 1088-1090      CPEDRG2A 1091-1093
        CPEDRG3A 1094-1096      CPEDRG4A 1097-1099      CPEDRG5A 1100-1102
        DREMGMED 1103-1104      EMDRG1A 1105-1107       EMDRG2A 1108-1110
        EMDRG3A 1111-1113       EMDRG4A 1114-1116       EMDRG5A 1117-1119
        EMPDRUG 1120-1121       CIGHELP 1122-1123       DRNKHELP 1124-1125
        TRMTHELP 1126-1127      TRMTEMRG 1128-1129      TRMTHOSP 1130-1131
        TRMTDOC 1132-1133       TRMTTRMT 1134-1135      TRMTMHC 1136-1137
        TRMTSHG 1138-1139       TRMTSOP 1140-1141       TRMTSP 1142-1143
        RSKPKCIG 1144-1145      RSKTRYMJ 1146-1147      RSKMJOCC 1148-1149
        RSKMJREG 1150-1151      RKTRYPCP 1152-1153      RKPCPREG 1154-1155
        RKTRYHER 1156-1157      RKHERREG 1158-1159      RKTRYCOC 1160-1161
        RKCOCOCC 1162-1163      RKCOCREG 1164-1165      RKCRKOCC 1166-1167
        RKANSOCC 1168-1169      RKANSREG 1170-1171      RK2DRINK 1172-1173
        RK5DRINK 1174-1175      RSKBINGE 1176-1177      RSKDIFMJ 1178-1179
        RKDIFLSD 1180-1181      RKDIFPCP 1182-1183      RKDIFCOC 1184-1185
        RKDIFHER 1186-1187      RESPID 1188-1193        PDEN 1194
        PDEN2 1195              POPDEN 1196             POPDEN2 1197
        REGION 1198             OVESTR 1199-1202        OVEREP 1203
        DIVISION 1204           CHICAGO 1205            DENVER 1206
        DC 1207                 LA 1208                 MIAMI 1209
        NEWYORK 1210            IRAGE 1211-1213         IRRACE 1214
        IIRACE 1215             IRSEX 1216              IISEX 1217
        EIBDATE 1218            IIAGE 1219              IRHOIND 1220
        IIHOIND 1221            IRMARIT 1222-1223       IIMARIT 1224
        IRPINSUR 1225           IIPINSUR 1226           IRWORKST 1227-1228
        IIWORKST 1229           IRHSGRAD 1230           IREDUC 1231-1232
        IIEDUC 1233             IIHSGRAD 1234           IRHOGRP 1235-1236
        IIHOGRP 1237            EDUCCAT2 1238           EMPSTAT2 1239
        IRSTMRC 1240            IROTBRC 1241            IRTRNRC 1242
        IRSEDRC 1243            IRMJRC 1244             IRMJFQ 1245-1246
        IIMJFQ 1247             IROTBFQ 1248            IIOTBFQ 1249
        IRSEDFQ 1250            IISEDFQ 1251            IRSTMFQ 1252
        IISTMFQ 1253            IRTRNFQ 1254            IITRNFQ 1255
        IRHALRC 1256            IRCOCRC 1257            IRINHRC 1258
        IRANLRC 1259            IRALCRC 1260            IRALCFQ 1261
        IIALCFQ 1262            IRANLFQ 1263            IIANLFQ 1264
        IRCOCFQ 1265            IICOCFQ 1266            IRHALFQ 1267
        IIHALFQ 1268            IRINHFQ 1269            IIINHFQ 1270
        IRPCPRC 1271            IIPCPRC 1272            IRCRKRC 1273
        IICRKRC 1274            IRSTRRC 1275            IISTRRC 1276
        IRICERC 1277            IIICERC 1278            IIINHRC 1279
        IIOTBRC 1280            IRHERRC 1281            IIHERRC 1282
        IIHALRC 1283            IITRNRC 1284            IIANLRC 1285
        IISTMRC 1286            IISEDRC 1287            IICOCRC 1288
        IIMJRC 1289             IIALCRC 1290            NDL90REC 1291-1292
        HALFLAG 1293            HALYR 1294              HALMON 1295
        PCPFLAG 1296            PCPYR 1297              PCPMON 1298
        STMFLAG 1299            STMYR 1300              STMMON 1301
        SEDFLAG 1302            SEDYR 1303              SEDMON 1304
        TRQFLAG 1305            TRQYR 1306              TRQMON 1307
        ANLFLAG 1308            ANLYR 1309              ANLMON 1310
        ALCFLAG 1311            ALCYR 1312              ALCMON 1313
        CIGFLAG 1314            CIGYR 1315              CIGMON 1316
        SMKFLAG 1317            SMKYR 1318              SMKMON 1319
        HERFLAG 1320            HERYR 1321              HERMON 1322
        STRFLAG 1323            STRYR 1324              STRMON 1325
        MRJFLAG 1326            MRJYR 1327              MRJMON 1328
        COCFLAG 1329            COCYR 1330              COCMON 1331
        CRKFLAG 1332            CRKYR 1333              CRKMON 1334
        INHFLAG 1335            INHYR 1336              INHMON 1337
        NEDFLAG3 1338           NEDYR3 1339             COCYRF 1340
        COCMONF 1341            COCWKF 1342             COCOCCF 1343
        COCDLYF 1344            ALCYRF 1345             ALCMONF 1346
        ALCWKF 1347             ALCOCCF 1348            ALCDLYF 1349
        ANLYRF 1350             ANLMONF 1351            ANLWKF 1352
        ANLOCCF 1353            ANLDLYF 1354            HALYRF 1355
        HALMONF 1356            HALWKF 1357             HALOCCF 1358
        HALDLYF 1359            INHYRF 1360             INHMONF 1361
        INHWKF 1362             INHOCCF 1363            INHDLYF 1364
        SEDYRF 1365             SEDMONF 1366            SEDWKF 1367
        SEDOCCF 1368            SEDDLYF 1369            SMKYRF 1370
        SMKMONF 1371            SMKWKF 1372             SMKOCCF 1373
        SMKDLYF 1374            STMYRF 1375             STMMONF 1376
        STMWKF 1377             STMOCCF 1378            STMDLYF 1379
        TRQYRF 1380             TRQMONF 1381            TRQWKF 1382
        TRQOCCF 1383            TRQDLYF 1384            MRJYRF 1385
        MRJMONF 1386            MRJWKF 1387             MRJOCCF 1388
        MRJDLYF 1389            PSYFLAG2 1390           PSYYR2 1391
        PSYMON2 1392            SUMFLAG 1393            SUMYR 1394
        SUMMON 1395             MJOFLAG 1396            MJOYR2 1397
        MJOMON2 1398            IEMFLAG 1399            IEMYR 1400
        IEMMON 1401             CATAGE 1402             RACE 1403
        IRCIGRC 1404            IICIGRC 1405            CATAG2 1406
        AS3READ 1407-1408       AS4READ 1409-1410       AS5READ 1411-1412
        AS7READ 1413-1414       INHQNC1 1415-1416       INHQNC2 1417-1418
        INHQNC3 1419-1420       INHQNC4 1421-1422       INHQNC5 1423-1424
        INHQNC6 1425-1426       INHQNC7 1427-1428       INHQNC8 1429-1430
        INHQNC9 1431-1432       INHQNC10 1433-1434      INHANSY 1435-1436
        AS9READ 1437-1438       AS10READ 1439-1440      AS11READ 1441-1442
        AS12READ 1443-1444      AS13READ 1445-1446      AS15READ 1447-1448
        HIGHBP 1449-1450        BPMED 1451-1452         WALKPAIN 1453-1454
        TIMEPAIN 1455-1456      UPSHOR 1457-1458        ASTHMA 1459-1460
        TRPSYCH 1461-1462       HEART 1463-1464         FLU 1465-1466
        ALLERG 1467-1468        HOSPYR 1469-1470        SOREYR 1471-1472
        RUNNYYR 1473-1474       COUGHYR 1475-1476       PHLEGMYR 1477-1478
        HEALTHYR 1479-1480      MARITAL 1481-1482       NOMARR 1483-1484
        WORKSTAT 1485-1486      PAYMO 1487-1488         PAYYR 1489-1491
        SECTOR 1492-1493        NO5JOB 1494-1495        WORKDAYS 1496-1497
        WORKBLAH 1498-1499      CWE 1500-1501           FULLPART 1502-1503
        CWESECTR 1504-1505      EDUC 1506-1507          GRADHS 1508-1509
        DIPLOMA 1510-1511       ENROLLD 1512-1513       SCHPLANS 1514-1515
        STUDENT 1516-1517       SCHDAYS 1518-1519       SKIPPED 1520-1521
        ACCID 1522-1523         MOVDAWAY 1524-1525      DORM 1526-1527
        MILBASE 1528-1529       HOSP 1530-1531          OTHGPH 1532-1533
        OTHGPHSP 1534-1535      SERVICE 1536-1537       MILSTAT 1538-1539
        TELNO 1540-1541         MOVES 1542-1543         EAP 1544-1545
        UNDINT 1546-1547        COOPINT 1548-1549       PRIVACY 1550-1551
        PPRES 1552-1553         SPRES 1554-1555         PARPRES 1556-1557
        OARPRES 1558-1559       OAPRES 1560-1561        CPRES 1562-1563
        OPRESNSP 1564-1565      OPRESSPA 1566-1567      WHOMARKD 1568-1569
        MILES 1570-1574         ETIME 1575-1578         MOTHER 1579-1580
        FATHER 1581-1582        STEPMOM 1583-1584       STEPDAD 1585-1586
        SPOUSE 1587-1588        INLAW 1589-1590         OWNCHILD 1591-1592
        STEPCHLD 1593-1594      BROSIS 1595-1596        OTHREL 1597-1598
        FRIENDS 1599-1600       OTHERNON 1601-1602      TOTPEOP 1603-1604
        NOCHILD 1605-1606       CIGREC 1607-1608        BTIME 1609-1612
        BAP 1613-1614           LANGVER 1615-1616       ENCPSU 1617-1619
        ENCSEG 1620-1623        ENCCASE 1624-1628       ANALWTC 1629-1644 .14
        ANALWT 1645-1660 .14    ANALWT2 1661-1676 .14   WPNAC 1677-1691 .14
        WO 1692-1707 .14        A1 1708-1723 .14        A2 1724-1739 .14
        A3 1740-1755 .14        A4 1756-1771 .14        W4 1772-1786 .14
        A5 1787-1802 .14        A6 1803-1818 .14        URBARE 1819
        CENCTY 1820             GQTYP 1821              IRHOGRP2 1822-1823
        IIHOGRP2 1824           FAMSKIP 1825            WORK 1826-1827
        WAG1 1828-1829          SOC1 1830-1831          SSI1 1832-1833
        WEL1 1834-1835          INT1 1836-1837          CHD1 1838-1839
        OTH1 1840-1841          WAG2 1842-1843          SOC2 1844-1845
        SSI2 1846-1847          WEL2 1848-1849          INT2 1850-1851
        CHD2 1852-1853          OTH2 1854-1855          FOOD 1856-1857
        AWAG1 1858-1863         ASOC1 1864-1869         ASSI1 1870-1875
        AWEL1 1876-1881         AINT1 1882-1887         ACHD1 1888-1893
        AOTH1 1894-1899         AWAG2 1900-1905         ASOC2 1906-1911
        ASSI2 1912-1917         AWEL2 1918-1923         AINT2 1924-1929
        ACHD2 1930-1935         AOTH2 1936-1941         AFOOD 1942-1947
        IRWAG1 1948             IRSOC1 1949             IRSSI1 1950
        IRWEL1 1951             IRINT1 1952             IRCHD1 1953
        IROTH1 1954             IRWAG2 1955             IRSOC2 1956
        IRSSI2 1957             IRWEL2 1958             IRINT2 1959
        IRCHD2 1960             IROTH2 1961             IRFOOD 1962
        IRAWAG1 1963-1967       IRASOC1 1968-1971       IRASSI1 1972-1975
        IRAWEL1 1976-1979       IRAINT1 1980-1983       IRACHD1 1984-1987
        IRAOTH1 1988-1991       IRAWAG2 1992-1996       IRASOC2 1997-2000
        IRASSI2 2001-2004       IRAWEL2 2005-2008       IRAINT2 2009-2012
        IRACHD2 2013-2016       IRAOTH2 2017-2021       IRAFOOD 2022-2024
        IIWAG1 2025             IISOC1 2026             IISSI1 2027
        IIWEL1 2028             IIINT1 2029             IICHD1 2030
        IIOTH1 2031             IIWAG2 2032             IISOC2 2033
        IISSI2 2034             IIWEL2 2035             IIINT2 2036
        IICHD2 2037             IIOTH2 2038             IIFOOD 2039
        IIAWAG1 2040            IIASOC1 2041            IIASSI1 2042
        IIAWEL1 2043            IIAINT1 2044            IIACHD1 2045
        IIAOTH1 2046            IIAWAG2 2047            IIASOC2 2048
        IIASSI2 2049            IIAWEL2 2050            IIAINT2 2051
        IIACHD2 2052            IIAOTH2 2053            IIAFOOD 2054
        JOB 2055-2056           HOURS 2057-2059         WEEKS 2060-2061
        PUB1 2062-2063          AFDC1 2064-2065         PUB2 2066-2067
        AFDC2 2068-2069         FSTAMP 2070-2071        PEOPFD 2072-2073
        WELFARE 2074            TWOFAM 2075             INDINC 2076-2081
        IIINDINC 2082           TOTINC 2083-2088        IITOTINC 2089
        INDCAT 2090-2091        TOTCAT 2092-2093        PERINC 2094
        FAMINC 2095             PERINC2 2096            FAMINC2 2097
        FAMINC3 2098            PERINC3 2099            PRVHLTIN 2100-2101
        PLYFLAGC 2102           PLYYRC 2103             PLYMONC 2104
        WPSTAT 2105             OWNOCONC 2106           NHBHCONC 2107
        NHBPCONC 2108           HSPPCONC 2109           HSPHCONC 2110
        METRO 2111              PROXABLE 2112-2113      PROXYREL 2114-2115
        PROXHOME 2116-2117      PROXJOIN 2118-2119      MEDICARE 2120-2121
        MEDICAID 2122-2123      CHAMPUS 2124-2125       OWNHLTIN 2126-2127
        GRPHLTIN 2128-2129      HLTINALC 2130-2131      HLTINDRG 2132-2133
        HLTINMNT 2134-2135      WHOANSHI 2136-2137      WHOANSIN 2138-2139
        NEEDLREC 2140-2141      IRINSUR 2142            IIINSUR 2143
        HERREC92 2144-2145      IRHERC92 2146           IIHERC92 2147
        VESTR 2148-2151         VEREP 2152              BIRMON 2153-2154
        BIRYEAR 2155-2158       IRALCAGG 2159-2160      IRALCARG 2161-2162
        IRALCABS 2163-2164      IRALCHIG 2165-2166      IRALCJOB 2167-2168
        IRALCMAT 2169-2170      IRALCREL 2171-2172      IRALCFRD 2173-2174
        IRALCTOS 2175-2176      IRALCHOL 2177-2178      IRALCDRU 2179-2180
        IRALCINT 2181-2182      IRALCREM 2183-2184      IRALCQUI 2185-2186
        IRALCMOR 2187-2188      IRALCSHO 2189-2190      IRALCALO 2191-2192
        IRALCBRK 2193-2194      IRNOBOOZ 2195           ANYALC 2196
        THREALC 2197            DRUNKYR2 2198           TRMTHLP2 2199
        DRNKHLP2 2200           DRALHELP 2201           ICEFLAG 2202
        ICEYR 2203              ICEMON 2204             MJTOT2 2205
        COCTOT2 2206            MJTOT3 2207             COCTOT3 2208
        MJDY30A2 2209           ALCDAYS2 2210           MRJMON2 2211
        ALCMON2 2212            CIGMON2 2213            LSD2 2214
        PEYOTE2 2215            MESC2 2216              PSILCY2 2217
        ECSTASY2 2218           GAS2 2219               LGAS2 2220
        SPPAINT2 2221           AEROS2 2222             GLUE2 2223
        SOLVENT2 2224           AMYLNIT2 2225           ETHER2 2226
        NITOXID2 2227           CLEFLU2 2228            COCSNIF2 2229
        FREEBAS2 2230           COCSWAL2 2231           COCIV2 2232
        MJDY30A3 2233           ALCDAYS3 2234           DRINKER2 2235
        HVYDRK2 2236            AVCIG2 2237             RACESEX 2238
        NOTMARJ 2239            RACESEX2 2240           ALCONLYL 2241
        ALCONLYY 2242           ALCONLYM 2243           ILLONLYL 2244
        ILLONLYY 2245           ILLONLYM 2246           MRJONLYL 2247
        MRJONLYY 2248           MRJONLYM 2249           PSYONLYL 2250
        PSYONLYY 2251           PSYONLYM 2252           OTHONLYL 2253
        OTHONLYY 2254           OTHONLYM 2255           ALCILLL 2256
        ALCILLY 2257            ALCILLM 2258            ALCMRJL 2259
        ALCMRJY 2260            ALCMRJM 2261            ALCPSYL 2262
        ALCPSYY 2263            ALCPSYM 2264            ALCOTHL 2265
        ALCOTHY 2266            ALCOTHM 2267            SUB1LIF 2268
        SUB2LIF 2269            SUB3LIF 2270            SUB1YR 2271
        SUB2YR 2272             SUB3YR 2273             SUB1MON 2274
        SUB2MON 2275            SUB3MON 2276            IRDEP 2277-2278
        IRARG 2279-2280         IRALN 2281-2282         IRANX 2283-2284
        IRHLT 2285-2286         IRNTK 2287-2288         IRUPS 2289-2290
        IRLSW 2291-2292         IRSSP 2293-2294         IRCPE 2295-2296
        IREMG 2297-2298         IRDEP1 2299-2301        IRDEP2 2302-2304
        IRDEP3 2305-2307        IRDEP4 2308-2310        IRDEP5 2311-2313
        IRARG1 2314-2316        IRARG2 2317-2319        IRARG3 2320-2322
        IRARG4 2323-2325        IRARG5 2326-2328        IRALN1 2329-2331
        IRALN2 2332-2334        IRALN3 2335-2337        IRALN4 2338-2340
        IRALN5 2341-2343        IRANX1 2344-2346        IRANX2 2347-2349
        IRANX3 2350-2352        IRANX4 2353-2355        IRANX5 2356-2358
        IRHLT1 2359-2361        IRHLT2 2362-2364        IRHLT3 2365-2367
        IRHLT4 2368-2370        IRHLT5 2371-2373        IRNTK1 2374-2376
        IRNTK2 2377-2379        IRNTK3 2380-2382        IRNTK4 2383-2385
        IRNTK5 2386-2388        IRUPS1 2389-2391        IRUPS2 2392-2394
        IRUPS3 2395-2397        IRUPS4 2398-2400        IRUPS5 2401-2403
        IRLSW1 2404-2406        IRLSW2 2407-2409        IRLSW3 2410-2412
        IRLSW4 2413-2415        IRLSW5 2416-2418        IRSSP1 2419-2421
        IRSSP2 2422-2424        IRSSP3 2425-2427        IRSSP4 2428-2430
        IRSSP5 2431-2433        IRCPE1 2434-2436        IRCPE2 2437-2439
        IRCPE3 2440-2442        IRCPE4 2443-2445        IRCPE5 2446-2448
        IREMG1 2449-2451        IREMG2 2452-2454        IREMG3 2455-2457
        IREMG4 2458-2460        IREMG5 2461-2463        IRAS13 2464
        ANYPROB 2465            TWOPROB 2466            THREPROB 2467
        DEPCIG2 2468            DEPALC2 2469            DEPMRJ2 2470
        DEPCOC2 2471            ARGCIG2 2472            ARGALC2 2473
        ARGMRJ2 2474            ARGCOC2 2475            ALNCIG2 2476
        ALNALC2 2477            ALNMRJ2 2478            ALNCOC2 2479
        ANXCIG2 2480            ANXALC2 2481            ANXMRJ2 2482
        ANXCOC2 2483            HLTCIG2 2484            HLTALC2 2485
        HLTMRJ2 2486            HLTCOC2 2487            NTKCIG2 2488
        NTKALC2 2489            NTKMRJ2 2490            NTKCOC2 2491
        UPSCIG2 2492            UPSALC2 2493            UPSMRJ2 2494
        UPSCOC2 2495            LSWCIG2 2496            LSWALC2 2497
        LSWMRJ2 2498            LSWCOC2 2499            SSPCIG2 2500
        SSPALC2 2501            SSPMRJ2 2502            SSPCOC2 2503
        CPECIG2 2504            CPEALC2 2505            CPEMRJ2 2506
        CPECOC2 2507            EMCIG2 2508             EMALC2 2509
        EMMRJ2 2510             EMCOC2 2511             PRB1CIG 2512
        PRB1ALC 2513            PRB1MRJ 2514            PRB1COC 2515
        PRB2CIG 2516            PRB2ALC 2517            PRB2MRJ 2518
        PRB2COC 2519            PRB3CIG 2520            PRB3ALC 2521
        PRB3MRJ 2522            PRB3COC 2523            IRCDCIG 2524-2525
        IRCDALC 2526-2527       IRCDMJ 2528-2529        IRCDCOC 2530-2531
        IREFCIG 2532-2533       IREFALC 2534-2535       IREFMJ 2536-2537
        IREFCOC 2538-2539       IRUDCIG 2540-2541       IRUDALC 2542-2543
        IRUDMJ 2544-2545        IRUDCOC 2546-2547       IRDPCIG 2548-2549
        IRDPALC 2550-2551       IRDPMJ 2552-2553        IRDPCOC 2554-2555
        IRWSCIG 2556-2557       IRWSALC 2558-2559       IRWSMJ 2560-2561
        IRWSCOC 2562-2563       AVCIG3 2564             ALCPROBS 2565
        MJPROBS 2566            COCPROBS 2567           CIGPROBS 2568
        INTMONTH 2569-2570      QC06 2571-2572          QC09 2573-2574
        AL02 2575-2576          SE04 2577-2578          TR04 2579-2580
        ST04 2581-2582          ST07 2583-2584          AN04 2585-2586
        MJ04 2587-2588          IN04 2589-2590          CC04 2591-2592
        CC10 2593-2594          CC11 2595-2596          LS05 2597-2598
        LS08 2599-2600          HE04 2601-2602          HE07 2603-2604
        DR08 2605-2606          SP04 2607-2608          SP08 2609-2610
        OTHDOSP1 2611-2612      OTHDOSP2 2613-2614      COCWAY2 2615
        ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   CHAGE1  = 'NUMBER OF CHILDREN AGES 0 TO 2'
   CHAGE2  = 'NUMBER OF CHILDREN AGES 3 TO 5'
   CHAGE3  = 'NUMBER OF CHILDREN AGES 6 TO 8'
   CHAGE4  = 'NUMBER OF CHILDREN AGES 9 TO 11'
   CHAGE5  = 'NUMBER OF CHILDREN AGES 12 TO 14'
   CHAGE6  = 'NUMBER OF CHILDREN AGES 15 TO 17'
   CHAGE7  = 'NUMBER OF CHILDREN AGES 18 TO 24'
   CHAGE8  = 'NUMBER OF CHILDREN AGES 25 TO 34'
   CHAGE9  = 'NUMBER OF CHILDREN AGES 35+'
   CHAGE10 = 'NUMBER OF CHILDREN W/ AGES UNKNOWN OR UN'
   CWEOCC2 = 'KIND OF WORK OF CHIEF WAGE EARNER'
   ROCCUP2 = 'KIND OF WORK OF RESPONDENT'
   BUSINES2= 'BUSINESS OR INDUSTRY OF RESPONDENT'
   CWEBUS2 = 'BUSINESS OR INDUSTRY OF CHIEF WAGE EARNE'
   SNUFREC = 'MOST RECENT TIME USED SMOKELESS TOBACCO'
   ALCREC  = 'MOST RECENT ALCOHOL DRINK'
   SEDREC  = 'MOST RECENT TIME USED SEDATIVE FOR NONME'
   TRANREC = 'MOST RECENT TIME USED TRANQUILIZER NONME'
   STIMREC = 'MOST RECENT TIME USED STIMULANT FOR NONM'
   STNDLREC= 'MOST RECENT TIME USED AMPHETAMINES WITH'
   ANALREC = 'MOST RECENT TIME USED ANALGESIC NONMEDIC'
   MJREC   = 'MOST RECENT TIME USED MARIJUANA/HASH'
   INHREC  = 'MOST RECENT TIME USED INHALANT'
   CRAKREC = 'MOST RECENT TIME USED CRACK'
   COCREC  = 'MOST RECENT TIME USED COCAINE (IN ANY FO'
   CONDLREC= 'MOST RECENT TIME USED COCAINE WITH A NEE'
   PCPREC  = 'MOST RECENT TIME USED PCP'
   HALLREC = 'MOST RECENT TIME USED HALLUCINOGEN'
   HERREC  = 'MOST RECENT TIME USED HEROIN'
   HRNDLREC= 'MOST RECENT TIME USED HEROIN WITH A NEED'
   GNNDLREC= 'MOST RECENT TIME USED ANY DRUG WITH A NE'
   ICEREC  = 'MOST RECENT TIME USED ICE'
   STERREC = 'MOST RECENT TIME YOU USED ANABOLIC STERO'
   ALCSED  = 'SEDATIVES USED W/ALCOHOL PAST 12 MONTHS'
   ALCTRAN = 'TRANQUILIZERS USED W/ALCOHOL PAST 12 MON'
   ALCSTM  = 'STIMULANTS USED W/ALCOHOL PAST 12 MONTHS'
   ALCANAL = 'ANALGESICS USED W/ALCOHOL PAST 12 MONTHS'
   ALCMJ   = 'MARIJUANA USED W/ALCOHOL PAST 12 MONTHS'
   ALCINH  = 'INHALANTS USED W/ALCOHOL PAST 12 MONTHS'
   ALCCOC  = 'COCAINE USED W/ALCOHOL PAST 12 MONTHS'
   ALCHAL  = 'HALLUCINOGENS USED W/ALCOHOL PAST 12 MON'
   ALCOPT  = 'HEROIN USED W/ALCOHOL PAST 12 MONTHS'
   ALCNONE = 'NONE OF LISTED DRUGS USED W/ALCOHOL IN P'
   CIGTRY  = 'AGE WHEN FIRST TRIED A CIGARETTE'
   CIGAGE  = 'AGE WHEN FIRST STARTED SMOKING DAILY'
   CIGYRS  = '# YEARS SMOKED DAILY'
   ALCTRY  = 'AGE WHEN HAD FIRST DRINK OF ALCOHOL'
   ALCAGE  = 'AGE BEGAN DRINKING ALCOHOL MONTHLY OR MO'
   SEDAGE  = 'AGE FIRST TOOK SEDATIVE FOR NONMEDICAL R'
   TRANAGE = 'AGE FIRST TOOK TRANQUILIZER FOR NONMEDIC'
   STIMAGE = 'AGE FIRST TOOK STIMULANT FOR NONMEDICAL'
   ANALAGE = 'AGE FIRST TOOK ANALGESIC FOR NONMEDICAL'
   MJOPP   = 'AGE AT FIRST CHANCE TO TRY MARIJUANA/HAS'
   MJAGE   = 'AGE WHEN FIRST USED MARIJUANA/HASH'
   INHAGE  = 'AGE WHEN FIRST SNIFFED ONE OF THESE INHA'
   COCOPP  = 'AGE AT FIRST CHANCE TO TRY COCAINE'
   COCAGE  = 'AGE WHEN FIRST USED COCAINE'
   HALLOPP = 'AGE AT FIRST CHANCE TO TRY HALLUCINOGEN'
   HALLAGE = 'AGE WHEN FIRST USED LSD/PCP/OTHER HALLUC'
   HEROPP  = 'AGE AT FIRST CHANCE TO TRY HEROIN'
   HERAGE  = 'AGE WHEN FIRST USED HEROIN'
   STEROPP = 'AGE FIRST HAD CHANCE TO USE ANABOLIC STE'
   STERAGE = 'AGE FIRST TIME ACTUALLY TRIED ANABOLIC S'
   OTHTOB  = '# TIMES USED SMOKELESS TOBACCO PAST 12 M'
   ALCPAT  = 'FREQUENCY ALCOHOL CONSUMPTION PAST 12 MO'
   SEDYRFRQ= 'HOW OFTEN TKN SEDATIVES PAST YR FOR NONM'
   TRNYRFRQ= 'FREQ IN PAST YR TKN TRANQUILIZERS FOR NO'
   STMYRFRQ= '# TIMES USED STIMULANTS PAST 12 MONTHS'
   ANLYRFRQ= '# TIMES USED ANALGESIC PAST 12 MONTHS'
   MJYRFREQ= 'FREQUENCY USED MARIJUANA PAST 12 MONTHS'
   INHYRFRQ= 'FREQ IN PAST YR SNIFFED OR INHALED SUBST'
   COCYRFRQ= 'FREQUENCY USED COCAINE PAST 12 MONTHS'
   HALYRFRQ= '# TIMES USED HALLUCINOGEN PAST 12 MONTHS'
   CIG5PK  = 'SMOKED 5 OR MORE PACKS OF CIGARETTES IN'
   PACKS   = '# CIGARETTES SMOKED DAILY'
   AVCIG   = '# CIGARETTES SMOKED PER DAY LAST 30 DAYS'
   CIGTIME = 'NUMBER OF MONTHS SMOKED # CIGARETTES/DAY'
   ALCDAYS = '# OF DAYS DRANK ALCOHOL PAST 30 DAYS'
   NODR30A = 'USUAL # DRINKS PER DAY PAST 30 DAYS'
   DR5DAY  = '# DAYS DRANK 5 OR MORE DRINKS PAST 30 DA'
   MODR30A = 'MOST # DRINKS ON ONE DAY IN PAST 30 DAYS'
   MODR30DY= '# DAYS DRANK AMOUNT IN A-7 PAST 30 DAYS'
   DRUNKYR = '# TIMES DRUNK ON ALCOHOL PAST 12 MONTHS'
   ALCBEER = 'USUAL ALCOHOL BEVERAGE-BEER'
   ALCWINE = 'USUAL ALCOHOL BEVERAGE-WINE'
   ALCLIQR = 'USUAL ALCOHOL BEVERAGE-LIQUOR'
   ALCVARY = 'USUAL ALCOHOL BEVERAGE-IT VARIES'
   NOBOOZYR= 'DID NOT USE BEER, WINE, OR LIQUOR IN PAS'
   ALCAGGR = 'FELT AGRESSIVE OR CROSS WHILE DRINKING P'
   ALCARGUM= 'GOT INTO HEATED ARGUMENT WHILE DRINKING'
   ALCABSNT= 'STAYED OUT OF WORK/SCHOOL DUE TO HANGOVE'
   ALCHIGH = 'HIGH OR LITTLE DRUNK ON JOB OR AT SCHOOL'
   ALCJOB  = 'LOST/NEARLY LOST JOB DUE TO DRINKING PAS'
   ALCMATCD= 'TOLD BY SPOUSE/DATE TO CUT DOWN DRINKING'
   ALCRELCD= 'TOLD BY RELATIVE TO CUT DOWN DRINKING PA'
   ALCFRDCD= 'TOLD BY FRIENDS TO CUT DOWN DRINKING PAS'
   ALCTOSS = 'TOSSED DOWN DRINKS FAST TO GET QUICKER E'
   ALCHOLIC= 'WAS AFRAID MIGHT BE/BECOME AN ALCOHOLIC'
   ALCDRUNK= 'STAYED DRUNK MORE THAN 1 DAY AT A TIME P'
   ALCINTOX= 'COULDN''T STOP DRINKING TILL COMPLETELY'
   ALCREM  = 'COULDN''T REMEM. THINGS DONE WHILE DRINK'
   ALCQUICK= 'HAD QUICK DRINK WHEN NO ONE WAS LOOKING'
   ALCMORN = 'OFTEN HAD A DRINK FIRST THING IN MORNING'
   ALCSHOOK= 'HANDS SHOOK AFTER DRINKING DAY BEFORE IN'
   ALCALONE= 'SOMETIMES GOT HIGH/DRUNK WHILE DRINKING'
   ALCBRKPM= 'KEPT ON DRINKING AFTER PROMISING MYSELF'
   BUTISOL = 'BUTISOL EVER TAKEN FOR NONMEDICAL REASON'
   BUTICAPS= 'BUTICAPS EVER TAKEN FOR NONMEDICAL REASO'
   AMYTAL  = 'AMYTAL EVER TAKEN FOR NONMEDICAL REASONS'
   MEBARAL = 'MEBARAL EVER TAKEN FOR NONMEDICAL REASON'
   PLACIDYL= 'PLACIDYL EVER TAKEN FOR NONMEDICAL REASO'
   DORIDEN = 'DORIDEN EVER TAKEN FOR NONMEDICAL REASON'
   NOLUDAR = 'NOLUDAR EVER TAKEN FOR NONMEDICAL REASON'
   NEMBUTAL= 'NEMBUTAL EVER TAKEN FOR NONMEDICAL REASO'
   SECONAL = 'SECONAL EVER TAKEN FOR NONMEDICAL REASON'
   TUINAL  = 'TUINAL EVER TAKEN FOR NONMEDICAL REASONS'
   DALMANE = 'DALMANE EVER TAKEN FOR NONMEDICAL REASON'
   RESTORIL= 'RESTORIL EVER TAKEN FOR NONMEDICAL REASO'
   HALCION = 'HALCION EVER TAKEN FOR NONMEDICAL REASON'
   AMOBARB = 'AMOBARBITAL EVER TAKEN FOR NONMEDICAL RE'
   PHENOBAR= 'PHENOBARBITAL EVER TAKEN FOR NONMEDICAL'
   METHAQ  = 'METHAQUALONE EVER TAKEN FOR NONMEDICAL R'
   CHHYD   = 'CHLORAL HYDRATE EVER TAKEN FOR NONMEDICA'
   PENTOB  = 'PENTOBARBITAL EVER TAKEN FOR NONMEDICAL'
   SECOB   = 'SECOBARBITAL EVER TAKEN FOR NONMEDICAL R'
   SEDNOSP = 'OTHER SEDATIVE EVER USED (NOT SPECIFIED)'
   SEDNEWA = 'OTHER SEDATIVE EVER USED (FIRST MENTION)'
   SEDNEWB = 'OTHER SEDATIVE EVER USED (SECOND MENTION'
   SEDNEWC = 'OTHER SEDATIVE EVER USED (THIRD MENTION)'
   SEDNEWD = 'OTHER SEDATIVE EVER USED (FOURTH MENTION'
   SEDNEWE = 'OTHER SEDATIVE EVER USED (FIFTH MENTION)'
   SEDDKNAM= 'USED SEDATIVE, DON''T KNOW NAME'
   NOSEDAT = 'HAS NEVER TAKEN SEDATIVES FOR NONMEDICAL'
   SEDTOT  = '# TIMES EVER TOOK SEDATIVE FOR NONMEDICA'
   VALIUM  = 'VALIUM EVER TAKEN FOR NONMEDICAL REASONS'
   LIBRIUM = 'LIBRIUM EVER TAKEN FOR NONMEDICAL REASON'
   LIMBTROL= 'LIMBITROL EVER TAKEN FOR NONMEDICAL REAS'
   MENRIUM = 'MENRIUM EVER TAKEN FOR NONMEDICAL REASON'
   SERAX   = 'SERAX EVER TAKEN FOR NONMEDICAL REASONS'
   TRANXENE= 'TRANXENE EVER TAKEN FOR NONMEDICAL REASO'
   ATIVAN  = 'ATIVAN EVER TAKEN FOR NONMEDICAL REASONS'
   CENTRAX = 'CENTRAX EVER TAKEN FOR NONMEDICAL REASON'
   XANAX   = 'XANAX EVER TAKEN FOR NONMEDICAL REASONS'
   PAXIPAM = 'PAXIPAM EVER TAKEN FOR NONMEDICAL REASON'
   BUSPAR  = 'BUSPAR EVER TAKEN FOR NONMEDICAL REASONS'
   MILTOWN = 'MILTOWN EVER TAKEN FOR NONMEDICAL REASON'
   EQUANIL = 'EQUANIL EVER TAKEN FOR NONMEDICAL REASON'
   DEPROL  = 'DEPROL EVER TAKEN FOR NONMEDICAL REASONS'
   VISTAR  = 'VISTARIL EVER TAKEN FOR NONMEDICAL REASO'
   ATARAX  = 'ATARAX EVER TAKEN FOR NONMEDICAL REASONS'
   DURRAX  = 'DURRAX EVER TAKEN FOR NONMEDICAL REASONS'
   DIAZEPAM= 'DIAZEPAM EVER TAKEN FOR NONMEDICAL REASO'
   SKLY    = 'SK-LYGEN EVER TAKEN FOR NONMEDICAL REASO'
   MEPROB  = 'MEPROBAMATE EVER TAKEN FOR NONMEDICAL RE'
   TRNOSP  = 'OTHER TRANQUILIZER EVER USED (NOT SPECIF'
   TRNEWA  = 'OTHER TRANQUILIZER EVER USED (FIRST MENT'
   TRNEWB  = 'OTHER TRANQUILIZER EVER USED (SECOND MEN'
   TRNEWC  = 'OTHER TRANQUILIZER EVER USED (THIRD MENT'
   TRNEWD  = 'OTHER TRANQUILIZER EVER USED (FOURTH MEN'
   TRNEWE  = 'OTHER TRANQUILIZER EVER USED (FIFTH MENT'
   TRDKNAM = 'USED TRANQUILIZER, DON''T KNOW NAME'
   NOTRANQ = 'HAS NEVER TAKEN TRANQUILIZER FOR NONMED'
   TRANTOT = '# TIMES EVER TOOK TRANQUILIZER NONMEDICA'
   DEXED   = 'DEXEDRINE EVER TAKEN FOR NONMEDICAL REAS'
   DEXAMYL = 'DEXAMYL EVER TAKEN FOR NONMEDICAL REASON'
   ESKAT   = 'ESKATROL EVER TAKEN FOR NONMEDICAL REASO'
   BENZ    = 'BENZEDRINE EVER TAKEN FOR NONMEDICAL REA'
   BIPHET  = 'BIPHETAMINE EVER TAKEN FOR NONMEDICAL RE'
   DESOXYN = 'DESOXYN EVER TAKEN FOR NONMEDICAL REASON'
   TENUATE = 'TENUATE EVER TAKEN FOR NONMEDICAL REASON'
   TEPANIL = 'TEPANIL EVER TAKEN FOR NONMEDICAL REASON'
   DIDREX  = 'DIDREX EVER TAKEN FOR NONMEDICAL REASONS'
   PLEGINE = 'PLEGINE EVER TAKEN FOR NONMEDICAL REASON'
   PRELUDIN= 'PRELUDIN EVER TAKEN FOR NONMEDICAL REASO'
   IONAMIN = 'IONAMIN EVER TAKEN FOR NONMEDICAL REASON'
   FASTIN  = 'FASTIN EVER TAKEN FOR NONMEDICAL REASONS'
   PONDIMIN= 'PONDIMIN EVER TAKEN FOR NONMEDICAL REASO'
   VORANIL = 'VORANIL EVER TAKEN FOR NONMEDICAL REASON'
   SANOREX = 'SANOREX EVER TAKEN FOR NONMEDICAL REASON'
   MAZANOR = 'MAZANOR EVER TAKEN FOR NONMEDICAL REASON'
   RITALIN = 'RITALIN EVER TAKEN FOR NONMEDICAL REASON'
   CYLERT  = 'CYLERT EVER TAKEN FOR NONMEDICAL REASONS'
   DETAMP  = 'DEXTROAMPHETAMINE EVER TAKEN FOR NONMEDI'
   METHI   = 'METHEDRINE EVER TAKEN FOR NONMEDICAL REA'
   METHAMP = 'METHAMPHETAMINE EVER TAKEN FOR NONMEDICA'
   OBLA    = 'OBEDRIN-LA EVER TAKEN FOR NONMEDICAL REA'
   STIMNOSP= 'OTHER STIMULANT EVER USED (NOT SPECIFIED'
   STIMNEWA= 'OTHER STIMULANT EVER USED (FIRST MENTION'
   STIMNEWB= 'OTHER STIMULANT EVER USED (SECOND MENTIO'
   STIMNEWC= 'OTHER STIMULANT EVER USED (THIRD MENTION'
   STIMNEWD= 'OTHER STIMULANT EVER USED (FOURTH MENTIO'
   STIMNEWE= 'OTHER STIMULANT EVER USED (FIFTH MENTION'
   STMDKNAM= 'USED STIMULANT, DON''T KNOW NAME'
   NOSTIMS = 'HAS NEVER TAKEN STIMULANT FOR NONMEDICAL'
   STIMTOT = '# TIMES EVER TOOK STIMULANT FOR NONMEDIC'
   STNEEDLE= 'EVER USED AMPHETAMINES WITH A NEEDLE'
   DARVON  = 'DARVON EVER TAKEN FOR NONMEDICAL REASONS'
   DOLENE  = 'DOLENE EVER TAKEN FOR NONMEDICAL REASONS'
   SK65A   = 'SK-65 EVER TAKEN FOR NONMEDICAL REASONS'
   WYGESIC = 'WYGESIC EVER TAKEN FOR NONMEDICAL REASON'
   LEVODRO = 'LEVO-DROMORAN EVER TAKEN FOR NONMEDICAL'
   PERCODAN= 'PERCODAN EVER TAKEN FOR NONMEDICAL REASO'
   DEMEROL = 'DEMEROL EVER TAKEN FOR NONMEDICAL REASON'
   DILAUD  = 'DILAUDID EVER TAKEN FOR NONMEDICAL REASO'
   TYLCOD  = 'TYLENOL W/CODEINE EVER TAKEN FOR NONMEDI'
   PHENCOD = 'PHENAPHEN W/CODEINE EVER TAKEN FOR NONME'
   TALWIN  = 'TALWIN EVER TAKEN FOR NONMEDICAL REASONS'
   TALWINNX= 'TALWIN NX EVER TAKEN FOR NONMEDICAL REAS'
   TALACEN = 'TALACEN EVER TAKEN FOR NONMEDICAL REASON'
   PROPOXY = 'PROPOXYPHENE EVER TAKEN FOR NONMEDICAL R'
   CODEINE = 'CODEINE EVER TAKEN FOR NONMEDICAL REASON'
   ANILERID= 'ANILERIDINE EVER TAKEN FOR NONMEDICAL RE'
   MORPHINE= 'MORPHINE EVER TAKEN FOR NONMEDICAL REASO'
   METHDON = 'METHADONE EVER TAKEN FOR NONMEDICAL REAS'
   STADOL  = 'STADOL EVER TAKEN FOR NONMEDICAL REASONS'
   ANLNOSP = 'OTHER ANALGESIC EVER USED (NOT SPECIFIED'
   ANALNEWA= 'OTHER ANALGESIC EVER USED (FIRST MENTION'
   ANALNEWB= 'OTHER ANALGESIC EVER USED (SECOND MENTIO'
   ANALNEWC= 'OTHER ANALGESIC EVER USED (THIRD MENTION'
   ANALNEWD= 'OTHER ANALGESIC EVER USED (FOURTH MENTIO'
   ANALNEWE= 'OTHER ANALGESIC EVER USED (FIFTH MENTION'
   ANLDKNAM= 'USED ANALGESIC, DON''T KNOW NAME'
   ANALNONE= 'HAS NEVER TAKEN ANALGESICS FOR NONMEDICA'
   ANALTOT = '# TIMES EVER TOOK ANALGESIC FOR NONMEDIC'
   MJTOT   = '# TIMES USED MARIJUANA/HASH IN LIFE'
   MJDAY30A= '# DAYS USED MARIJUANA/HASH IN PAST 30 DA'
   MJAV30A = '# JOINTS SMOKED PER DAY IN PAST 30 DAYS'
   MJAV30B = '# BONGS SMOKED PER DAY IN PAST 30 DAYS'
   MJAMT30A= 'TOTAL AMOUNT MARIJUANA USED PAST 30 DAYS'
   MJJOINT = 'SMOKED MARIJUANA CIGARETTES OR JOINTS'
   MJPIPE  = 'SMOKED MARIJUANA WITH A PIPE OR BONG IN'
   MJBAKE  = 'ATE MARIJUANA THAT''S BEEN BAKED IN FOOD'
   MJCHEW  = 'CHEWED MARIJUANA LIKE CHEWING TOBACCO IN'
   MJWAY   = 'USED MARIJUANA SOME OTHER WAY IN PAST 12'
   GAS     = 'EVER INHALED GASOLINE OR LIGHTER FLUIDS'
   LGAS    = 'EVER INHALED LIGHTER GASES (BUTANE, PROP'
   SPPAINT = 'EVER INHALED SPRAY PAINTS'
   AEROS   = 'EVER INHALED OTHER AEROSOL SPRAYS'
   GLUE    = 'EVER INHALED SHOESHINE LIQUID/GLUE/TOLUE'
   SOLVENT = 'EVER INHALED LACQUER THINNER/PAINT SOLVE'
   AMYLNIT = 'EVER INHALED AMYL NITRITE/LOCKER RM ODOR'
   ETHER   = 'EVER INHALED HALOTHANE/ETHER/OTHER ANEST'
   NITOXID = 'EVER INHALED NITROUS OXIDE/WHIPPETS'
   CLEFLU  = 'EVER INHALED CORRECTION FLD/DEGREASER/CL'
   INHNOSP = 'EVER INHALED OTHER SUBSTANCES (NOT SPECI'
   INHDKNAM= 'USED INHALANT, DON''T KNOW NAME'
   INHTOT  = '# TIMES USED INHALANT IN LIFETIME'
   GAS30A  = 'INHALED GASOLINE OR LIGHTER FLUID PAST 3'
   LGAS30A = 'INHALED LIGHTER GASES (BUTANE,PROPANE) P'
   SPPAN30A= 'INHALED SPRAY PAINTS PAST 30 DAYS'
   AEROS30A= 'INHALED OTHER AEROSOL SPRAYS PAST 30 DAY'
   GLUE30A = 'INHALED SHOESHINE LIQUID/GLUE/TOLUENE PA'
   SOLVN30A= 'INHALED LACQUER THINNER/PAINT SOLVENTS P'
   AMLNT30A= 'INHALED AMYL NITRITE/LOCKER RM ODORIZER'
   ETHER30A= 'INHALED HALOTHANE/ETHER/OTH ANESTHETICS'
   NOX30A  = 'INHALED NITROUS OXIDE/WHIPPETS PAST 30 D'
   CLFL30A = 'INHALED CORRECTION FLD/DEGREASER/CLN FLD'
   IN30NOSP= 'OTHER INHALANT USED PAST 30 DAYS (NOT SP'
   INH30NO = 'DID NOT USE ANY INHALANT PAST 30 DAYS'
   INHDY30A= '# DAYS USED AN INHALANT IN PAST 30 DAYS'
   INHEFF  = 'USUAL AMOUNT (EFFECTS) OF INHALANTS USED'
   INHPO   = 'EVER PASSED OUT FROM USING INHALANTS'
   INHNEWA = 'OTHER SUBSTANCE EVER INHALED (FIRST MENT'
   INHNEWB = 'OTHER SUBSTANCE EVER INHALED (SECOND MEN'
   INHNEWC = 'OTHER SUBSTANCES INHALED (THIRD MENTION)'
   INHNEWD = 'OTHER SUBSTANCE INHALED (FOURTH MENTION)'
   INHNEWE = 'OTHER SUBSTANCE INHALED (FIFTH MENTION)'
   INNEW30A= 'OTHER INHALANT USED PAST 30 DAYS (FIRST'
   INNEW30B= 'OTHER INHALANT USED PAST 30 DAYS (SECOND'
   INNEW30C= 'OTHER INHALANT USED PAST 30 DAYS (THIRD'
   INNEW30D= 'OTHER INHALANT USED PAST 30 DAYS (FOURTH'
   INNEW30E= 'OTHER INHALANT USED PAST 30 DAYS (FIFTH'
   COCTOT  = '# TIMES USED COCAINE IN LIFE'
   COCUS30A= '# DAYS USED COCAINE PAST 30 DAYS'
   CRKAM30A= '# OF VIALS OF CRACK USED IN PAST 30 DA'
   CRAKBUCK= '$ AMOUNT SPENT ON CRACK USED IN PAST 3'
   COCAM30A= '# OF GRAMS OF COCAINE USED IN PAST 30 DA'
   COCBUCK = '$ AMOUNT SPENT ON COCAINE USED IN PAST 3'
   COCSNIFF= 'SNIFFED/SNORTED COCAINE THRU NOSE IN PAS'
   COCSWAL = 'SWALLOWED/DRANK COCAINE IN PAST 12 MONTH'
   COCIV   = 'INJECTED COCAINE WITH A NEEDLE IN PAST 1'
   FREEBASE= 'SMOKED/FREE-BASED COCAINE IN PAST 12 MON'
   COCWAY  = 'OTHER WAY COCAINE USED PAST 12 MOS (ONLY'
   LSD     = 'EVER USED LSD (ACID, WHITE LIGHTNING'
   PEYOTE  = 'EVER USED PEYOTE'
   MESC    = 'EVER USED MESCALINE'
   PSILCY  = 'EVER USED PSILOCYBIN (MUSHROOMS)'
   PCP     = 'EVER USED PCP (ANGEL DUST, PHENCYCLIDI'
   ECSTASY = 'EVER USED ECSTASY (MDMA)'
   HALNOSP = 'OTHER HALLUCINOGEN EVER USED (NOT SPECIF'
   HALNEWA = 'OTHER HALLUCINOGEN EVER USED (1ST MENTIO'
   HALNEWB = 'OTHER HALLUCINOGEN EVER USED (2ND MENTIO'
   HALNEWC = 'OTHER HALLUCINOGEN EVER USED (THIRD MENT'
   HALNEWD = 'OTHER HALLUCINOGEN EVER USED (FOURTH MEN'
   HALNEWE = 'OTHER HALLUCINOGEN EVER USED (FIFTH MENT'
   HALDKNAM= 'USED A HALLUCINOGEN, DON''T KNOW NAME'
   HALLTOT = '# TIMES USED LSD/PCP/OTHER HALLUCINOGEN'
   HAL30USE= '# DAYS USED HALLUCINOGEN PAST 30 DAYS'
   HERTOT  = '# TIMES USED HEROIN IN LIFE'
   HER30USE= '# DAYS USED HEROIN PAST 30 DAYS'
   HERNEEDL= 'EVER USED HEROIN WITH A NEEDLE'
   CDCIG   = 'TRIED TO CUT DOWN ON USE OF CIGARETTES P'
   CDALC   = 'TRIED TO CUT DOWN ON USE OF ALCOHOL PAST'
   CDSED   = 'TRIED TO CUT DOWN ON USE OF SEDATIVES PA'
   CDTRAN  = 'TRIED TO CUT DOWN ON USE OF TRANQUILIZER'
   CDSTM   = 'TRIED TO CUT DOWN ON USE OF STIMULANTS P'
   CDANAL  = 'TRIED TO CUT DOWN ON USE OF ANALGESICS P'
   CDMJ    = 'TRIED TO CUT DOWN ON USE OF MARIJUANA PA'
   CDINH   = 'TRIED TO CUT DOWN ON USE OF INHALANTS PA'
   CDCOC   = 'TRIED TO CUT DOWN ON USE OF COCAINE PAST'
   CDHALL  = 'TRIED TO CUT DOWN ON USE OF HALLUCINOGEN'
   CDHER   = 'TRIED TO CUT DOWN ON USE OF HEROIN PAST'
   CDOTHOP = 'TRIED TO CUT DOWN ON USE OF OTHER OPIATE'
   CDNONE  = 'DID NOT TRY TO CUT DOWN ON ANY DRUG USED'
   UCDCIG  = 'UNABLE TO CUT DOWN ON CIGARETTES DURING'
   UCDALC  = 'UNABLE TO CUT DOWN ON ALCOHOL IN PAST 12'
   UCDSED  = 'UNABLE TO CUT DOWN ON SEDATIVES DURING P'
   UCDTRAN = 'UNABLE TO CUT DOWN ON TRANQUILIZERS PAST'
   UCDSTM  = 'UNABLE TO CUT DOWN ON STIMULANTS DURING'
   UCDANAL = 'UNABLE TO CUT DOWN ON ANALGESICS DURING'
   UCDMJ   = 'UNABLE TO CUT DOWN ON MARIJUANA DURING P'
   UCDINH  = 'UNABLE TO CUT DOWN ON INHALANTS DURING P'
   UCDCOC  = 'UNABLE TO CUT DOWN ON COCAINE  IN PAST 1'
   UCDHALL = 'UNABLE TO CUT DOWN ON HALLUCINOGENS PAST'
   UCDHER  = 'UNABLE TO CUT DOWN ON HEROIN DURING PAST'
   UCDOTHOP= 'UNABLE TO CUT DOWN ON OPIATES/MORPHINE P'
   UCDNONE = 'DID NOT TRY TO CUT DOWN ON ANY DRUG IN P'
   EFFCIG  = 'NEEDED MORE CIGARETTES TO GET SAME EFFEC'
   EFFALC  = 'NEEDED MORE ALCOHOL TO GET SAME EFFECT P'
   EFFSED  = 'NEEDED MORE SEDATIVES TO GET SAME EFFECT'
   EFFTRAN = 'NEEDED MORE TRANQ. TO GET SAME EFFECT PA'
   EFFSTM  = 'NEEDED MORE STIMULANTS TO GET SAME EFFEC'
   EFFANAL = 'NEEDED MORE ANALGESICS TO GET SAME EFFEC'
   EFFMJ   = 'NEEDED MORE MARIJUANA TO GET SAME EFFECT'
   EFFINH  = 'NEEDED MORE INHALANTS TO GET SAME EFFECT'
   EFFCOC  = 'NEEDED MORE COCAINE TO GET SAME EFFECT P'
   EFFHALL = 'NEEDED MORE HALLUCIN. TO GET SAME EFFECT'
   EFFHER  = 'NEEDED MORE HEROIN TO GET SAME EFFECT PA'
   EFFOTHOP= 'NEEDED MORE OTHER OPIATES TO GET SAME EF'
   EFFNONE = 'DID NOT NEED MORE OF ANY DRUG FOR SAME E'
   UDAYCIG = 'USED CIGARETTES DAILY FOR 2+ WEEKS IN PA'
   UDAYALC = 'USED ALCOHOL DAILY FOR 2+ WEEKS IN PAST'
   UDAYSED = 'USED SEDATIVES DAILY FOR 2+ WEEKS IN PAS'
   UDAYTRAN= 'USED TRANQUILIZERS DAILY FOR 2+ WKS IN P'
   UDAYSTM = 'USED STIMULANTS DAILY FOR 2+ WEEKS IN PA'
   UDAYANAL= 'USED ANALGESICS DAILY FOR 2+ WEEKS IN PA'
   UDAYMJ  = 'USED MARIJUANA DAILY FOR 2+ WEEKS IN PAS'
   UDAYINH = 'USED INHALANTS DAILY FOR 2+ WEEKS IN PAS'
   UDAYCOC = 'USED COCAINE DAILY FOR 2+ WEEKS IN PAST'
   UDAYHALL= 'USED HALLUCINOGENS DAILY FOR 2+ WEEKS IN'
   UDAYHER = 'USED HEROIN DAILY FOR 2+ WEEKS IN PAST Y'
   UDAYOTH = 'USED OTHER OPIATES DAILY FOR 2+ WEEKS IN'
   UDAYNONE= 'DID NOT USE ANY DRUG DAILY FOR 2+ WEEKS'
   DEPCIG  = 'FELT DEPENDENT ON CIGARETTES PAST YEAR'
   DEPALC  = 'FELT DEPENDENT ON ALCOHOL PAST YEAR'
   DEPSED  = 'FELT DEPENDENT ON SEDATIVES PAST YEAR'
   DEPTRAN = 'FELT DEPENDENT ON TRANQUILIZERS PAST YEA'
   DEPSTM  = 'FELT DEPENDENT ON STIMULANTS PAST YEAR'
   DEPANAL = 'FELT DEPENDENT ON ANALGESICS PAST YEAR'
   DEPMJ   = 'FELT DEPENDENT ON MARIJUANA PAST YEAR'
   DEPINH  = 'FELT DEPENDENT ON INHALANTS PAST YEAR'
   DEPCOC  = 'FELT DEPENDENT ON COCAINE PAST YEAR'
   DEPHALL = 'FELT DEPENDENT ON HALLUCINOGENS PAST YEA'
   DEPHER  = 'FELT DEPENDENT ON HEROIN PAST YEAR'
   DEPOTHOP= 'FELT DEPENDENT ON OTHER OPIATES PAST YEA'
   DEPNONE = 'DID NOT FEEL DEPENDENT ON ANY DRUG USED'
   WSCIG   = 'FELT SICK WHEN CUT DOWN ON CIGARETTES PA'
   WSALC   = 'FELT SICK WHEN CUT DOWN ON ALCOHOL PAST'
   WSSED   = 'FELT SICK WHEN CUT DOWN ON SEDATIVES PAS'
   WSTRAN  = 'FELT SICK WHEN CUT DOWN ON TRANQUILIZERS'
   WSSTM   = 'FELT SICK WHEN CUT DOWN ON STIMULANTS PA'
   WSANAL  = 'FELT SICK WHEN CUT DOWN ON ANALGESICS PA'
   WSMJ    = 'FELT SICK WHEN CUT DOWN ON MARIJUANA PAS'
   WSINH   = 'FELT SICK WHEN CUT DOWN ON INHALANTS PAS'
   WSCOC   = 'FELT SICK WHEN CUT DOWN ON COCAINE PAST'
   WSHALL  = 'FELT SICK WHEN CUT DOWN ON HALLUCINOGENS'
   WSHER   = 'FELT SICK WHEN CUT DOWN ON HEROIN PAST Y'
   WSOTHOP = 'FELT SICK WHEN CUT DOWN ON OTHER OPIATES'
   WSNONE  = 'DID NOT HAVE WITHDRAWAL SYMPTOMS PAST YE'
   GNNDLLIF= 'HAVE USED NEEDLE TO INJECT DRUGS'
   GNNDLSED= 'USED SEDATIVE WITH A NEEDLE FOR NONMEDIC'
   GNNDLTRA= 'USED TRANQUILIZER WITH A NEEDLE FOR NONM'
   GNNDLSTM= 'USED STIMULANT WITH A NEEDLE FOR NONMEDI'
   GNNDLANL= 'USED ANALGESIC WITH A NEEDLE FOR NONMEDI'
   GNNDLMJ = 'USED MARIJUANA OR THC W/ A NEEDLE FOR NO'
   GNNDLINH= 'USED INHALANTS WITH NEEDLE FOR NONMEDICA'
   GNNDLCOC= 'USED COCAINE WITH A NEEDLE FOR NONMEDICA'
   GNNDLHAL= 'USED HALLUCINOGEN WITH A NEEDLE FOR NONM'
   GNNDLHER= 'USED HEROIN WITH A NEEDLE FOR NONMEDICAL'
   GNNDLOPT= 'USED OTHER OPIATE WITH A NEEDLE FOR NONM'
   GNNDLNON= 'NEVER USED A NEEDLE TO TAKE ANY DRUG'
   GNNDLSHR= 'EVER SHARED A NEEDLE WITH SOMEONE ELSE'
   DRUGTEST= 'BEEN REQUIRED TO TAKE DRUG TEST IN PAST'
   TESTPOS = 'DRUG TEST INDICATE PRESENCE OF DRUG IN P'
   ICELIFE = 'EVER USED ICE?'
   STERTOT = '# TIMES YOU HAVE USED ANABOLIC STEROIDS'
   BOOKED  = 'BEEN ARRESTED FOR BREAKING THE LAW'
   NOBOOKYR= '# TIMES ARRESTED FOR BREAKING LAW PAST 1'
   BKLARCNY= 'ARRESTED FOR LARCENY OR THEFT IN THE PAS'
   BKBURGL = 'ARRESTED FOR BURGLARY IN THE PAST 12 MON'
   BKAGASLT= 'ARRESTED FOR AGGRAVATED ASSAULT IN PAST'
   BKSMASLT= 'ARRESTED FOR OTHER ASSAULT IN PAST 12 MO'
   BKMVTHFT= 'ARRESTED FOR MOTOR VEHICLE THEFT IN PAST'
   BKROB   = 'ARRESTED FOR ROBBERY IN PAST 12 MONTH'
   BKRAPE  = 'ARRESTED FOR FORCIBLE RAPE IN PAST 12 MO'
   BKMURDER= 'ARRESTED FOR MURDER IN PAST 12 MONTHS'
   BKARSON = 'ARRESTED FOR ARSON IN PAST 12 MONTHS'
   BKDRVINF= 'ARRESTED FOR DUI IN PAST 12 MONTHS'
   BKDRUNK = 'ARRESTED FOR DRUNKENNESS IN PAST 12 MONT'
   BKDRUG  = 'ARRESTED FOR POSSESSION/SALE FRUGS IN PA'
   BKPROS  = 'ARRESTED FOR PROSTITUTION IN PAST 12 MON'
   BKVANDAL= 'ARRESTED FOR OTHER PROPERTY OFFENSES PAS'
   BKOTHOFF= 'ARRESTED FOR OTHER OFFENSES'
   NOTBKED = 'WAS NOT ARRESTED FOR ANY OFFENSE IN PAST'
   PROBATON= 'WERE YOU ON PROBATION IN PAST 12 MONTHS'
   PAROLE  = 'WERE YOU ON PAROLE AT ANY TIME IN PAST 1'
   STRSTEAL= 'TAKEN SOMETHING FROM STORE WITHOUT PAY/P'
   OTHSTEAL= 'TAKEN SOMETHING NOT BELONG TO YOU IN PAS'
   DAMAGE  = 'DAMAGED PROPERTY NOT BELONG TO YOU IN PA'
   CARSTEAL= 'TAKEN A CAR NOT BELONGING TO YOU IN PAST'
   FORCEMON= 'USED FORCE TO GET MONEY FROM A PERSON IN'
   BREAKIN = 'BROKEN INTO A HOUSE IN THE PAST 12 MONTH'
   PHYFIGHT= 'GOTTEN INTO A PHYSICAL FIGHT IN PAST 12'
   HURTBAD = 'HURT SOMEONE ENOUGH TO NEED A DR. PAST 1'
   GUNMONEY= 'USED WEAPON TO GET SOMETHING FROM PRSON'
   DRUNKDRV= 'DRIVEN UNDER INFLUENCE IN PAST 12 MONTHS'
   SOLDDRUG= 'SOLD ILLEGAL DRUGS IN PAST 12 MONTHS'
   OTHDOING= 'ANYTHING TO GET IN TROUBLE W/POLICE PST'
   SPNEWA  = 'USED OTHER DRUGS IN PAST 12 MONTHS (FIRS'
   SPNEWB  = 'USED OTHER DRUGS PAST 12 MONTHS (SECOND'
   SPNEWC  = 'USED OTHER DRUGS IN PAST 12 MONTHS (THIR'
   SPNEWD  = 'USED OTHER DRUGS PAST 12 MONTHS (FOURTH'
   SPNEWE  = 'USED OTHER DRUGS IN PAST 12 MONTHS (FIFT'
   AS13NONE= 'NEVER USED CIGARETTES, ALCOHOL OR DRUGS'
   DRDEPRSS= 'BECAME DEPRESSED/LOST INTEREST DUE TO DR'
   DEPDRG1A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-1S'
   DEPDRG2A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-2N'
   DEPDRG3A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-3R'
   DEPDRG4A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-4T'
   DEPDRG5A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-5T'
   DRARGUM = 'HAD ARGUMNTS W/FAMILY/FRNDS PST YR DUE T'
   ARGDRG1A= 'DRUG CAUSING ARGUMENTS/FIGHTS-1ST MENTIO'
   ARGDRG2A= 'DRUG CAUSING ARGUMENTS/FIGHTS-2ND MENTIO'
   ARGDRG3A= 'DRUG CAUSING ARGUMENTS/FIGHTS-3RD MENTIO'
   ARGDRG4A= 'DRUG CAUSING ARGUMENTS/FIGHTS-4TH MENTIO'
   ARGDRG5A= 'DRUG CAUSING ARGUMENTS/FIGHTS-5TH MENTIO'
   DRALONE = 'FELT ALONE/ISOLATED PAST YEAR DUE TO DRU'
   ALNDRG1A= 'DRUG CAUSING FEELING ALONE/ISOLATED-1ST'
   ALNDRG2A= 'DRUG CAUSING FEELING ALONE/ISOLATED-2ND'
   ALNDRG3A= 'DRUG CAUSING FEELING ALONE/ISOLATED-3RD'
   ALNDRG4A= 'DRUG CAUSING FEELING ALONE/ISOLATED-4TH'
   ALNDRG5A= 'DRUG CAUSING FEELING ALONE/ISOLATED-5TH'
   DRANX   = 'FELT NERVOUS/ANXIOUS PAST YEAR DUE TO DR'
   ANXDRG1A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-1ST'
   ANXDRG2A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-2ND'
   ANXDRG3A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-3RD'
   ANXDRG4A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-4TH'
   ANXDRG5A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-5TH'
   DRHEALTH= 'HAD HEALTH PROBLEMS PAST YEAR DUE TO DRU'
   HLTDRG1A= 'DRUG CAUSING HEALTH PROBLEMS-1ST MENTION'
   HLTDRG2A= 'DRUG CAUSING HEALTH PROBLEMS-2ND MENTION'
   HLTDRG3A= 'DRUG CAUSING HEALTH PROBLEMS-3RD MENTION'
   HLTDRG4A= 'DRUG CAUSING HEALTH PROBLEMS-4TH MENTION'
   HLTDRG5A= 'DRUG CAUSING HEALTH PROBLEMS-5TH MENTION'
   DRNTHINK= 'HAD DIFFCLTY THNKNG CLEARLY PST YR DUE T'
   NTKDRG1A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-1'
   NTKDRG2A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-2'
   NTKDRG3A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-3'
   NTKDRG4A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-4'
   NTKDRG5A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-5'
   DRUPSET = 'FELT IRRITABLE/UPSET PAST YEAR DUE TO DR'
   UPSDRG1A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-1ST'
   UPSDRG2A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-2ND'
   UPSDRG3A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-3RD'
   UPSDRG4A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-4TH'
   UPSDRG5A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-5TH'
   DRLSWORK= 'GOT LESS WRK DONE @ SCH/JOB PST YR DUE T'
   LSWDRG1A= 'DRUG CAUSING LESS WORK GETTING DONE-1ST'
   LSWDRG2A= 'DRUG CAUSING LESS WORK GETTING DONE-2ND'
   LSWDRG3A= 'DRUG CAUSING LESS WORK GETTING DONE-3RD'
   LSWDRG4A= 'DRUG CAUSING LESS WORK GETTING DONE-4TH'
   LSWDRG5A= 'DRUG CAUSING LESS WORK GETTING DONE-5TH'
   DRSUSPIC= 'FELT DISTRUSTFUL/SUSPICIOUS PST YR DUE T'
   SSPDRG1A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-1S'
   SSPDRG2A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-2N'
   SSPDRG3A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-3R'
   SSPDRG4A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-4T'
   SSPDRG5A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-5T'
   DRCOPE  = 'PROBLEMS HARDER TO HANDLE PAST YR DUE TO'
   CPEDRG1A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-1S'
   CPEDRG2A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-2N'
   CPEDRG3A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-3R'
   CPEDRG4A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-4T'
   CPEDRG5A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-5T'
   DREMGMED= 'HAD TO GET EMERG MED HELP PST YR DUE TO'
   EMDRG1A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-1S'
   EMDRG2A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-2N'
   EMDRG3A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-3R'
   EMDRG4A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-4T'
   EMDRG5A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-5T'
   EMPDRUG = 'REFD. TO DRG TRMT THRU EMPLOYEE ASST.PGM'
   CIGHELP = 'GONE TO TRTMNT PROF. TO QUIT SMOKING IN'
   DRNKHELP= 'GOTTEN TREATMENT FOR DRINKING IN PAST 12'
   TRMTHELP= 'RECEIVED TREATMENT FOR DRUG USE IN PAST'
   TRMTEMRG= 'RECEIVED TRTMNT/DRUG USE/EMERGENCY RM PA'
   TRMTHOSP= 'RECEIVED TRTMNT/DRUG USE/HOSP. INPATIENT'
   TRMTDOC = 'RECEIVED TREATMENT/DRUG USE/DR''S OFFICE'
   TRMTTRMT= 'RECEIVED TRTMNT/DRUG USE/DRUG TX-REHAB/P'
   TRMTMHC = 'RECEIVED TRTMNT/DRUG USE/MENTAL HLTH CTR'
   TRMTSHG = 'RECEIVED TRTMNT/DRUG USE/SELF-HELP GROUP'
   TRMTSOP = 'RECEIVED TRTMNT/DRUG USE/SOME OTHR PLACE'
   TRMTSP  = 'OTHER PLACE RECEIVED TREATMENT PAST 12 M'
   RSKPKCIG= 'RISK IF SMOKE 1 OR MORE PACKS CIGARETTES'
   RSKTRYMJ= 'RISK IF TRY MARIJUANA ONCE OR TWICE'
   RSKMJOCC= 'RISK IF SMOKE MARIJUANA OCCASIONALLY'
   RSKMJREG= 'RISK IF SMOKE MARIJUANA REGULARLY'
   RKTRYPCP= 'RISK IF TRY PCP ONCE OR TWICE'
   RKPCPREG= 'RISK IF USE PCP REGULARLY'
   RKTRYHER= 'RISK IF TRY HEROIN ONCE OR TWICE'
   RKHERREG= 'RISK IF USE HEROIN REGULARLY'
   RKTRYCOC= 'RISK IF TRY COCAINE ONCE OR TWICE'
   RKCOCOCC= 'RISK IF USE COCAINE OCCASIONALLY'
   RKCOCREG= 'RISK IF USE COCAINE REGULARLY'
   RKCRKOCC= 'RISK IF USE CRACK OCCASIONALLY'
   RKANSOCC= 'RISK IF USE ANABOLIC STEROIDS OCCASIONAL'
   RKANSREG= 'RISK IF USE ANABOLIC STEROIDS REGULARLY'
   RK2DRINK= 'RISK IF TAKE 1 OR 2 DRINKS NEARLY EVERY'
   RK5DRINK= 'RISK IF TAKE 4 OR 5 DRINKS NEARLY EVERY'
   RSKBINGE= 'RISK IF HAVE 5 OR MORE DRINKS ONCE OR TW'
   RSKDIFMJ= 'DIFFICULTY OF GETTING MARIJUANA IF YOU W'
   RKDIFLSD= 'DIFFICULTY OF GETTING LSD IF YOU WANTED'
   RKDIFPCP= 'DIFFICULTY OF GETTING PCP IF YOU WANTED'
   RKDIFCOC= 'DIFFICULTY OF GETTING COCAINE IF YOU WAN'
   RKDIFHER= 'DIFFICULTY OF GETTING HEROIN IF YOU WANT'
   RESPID  = 'RESPONDENT IDENTIFICATION NUMBER'
   PDEN    = 'POPULATION DENSITY'
   PDEN2   = 'POPULATION DENSITY - FIVE LEVELS'
   POPDEN  = 'POPULATION DENSITY'
   POPDEN2 = 'POPULATION DENSITY - FIVE LEVELS'
   REGION  = 'CENSUS REGION'
   OVESTR  = 'ORIGINAL 1991 VESTR'
   OVEREP  = 'ORIGINAL 1991 VEREP'
   DIVISION= 'CENSUS DIVISION CODE'
   CHICAGO = 'CHICAGO MSA INDICATOR'
   DENVER  = 'DENVER MSA INDICATOR'
   DC      = 'DC MSA INDICATOR'
   LA      = 'LOS ANGELES MSA INDICATOR'
   MIAMI   = 'MIAMI MSA INDICATOR'
   NEWYORK = 'NEW YORK MSA INDICATOR'
   IRAGE   = 'IMPUTATION-REVISED AGE OF RESPONDENT'
   IRRACE  = 'IMPUTATION-REVISED RACE OF RESPONDENT'
   IIRACE  = 'IMPUTATION INDICATOR FOR RACE'
   IRSEX   = 'SEX - IMPUTATION REVISED'
   IISEX   = 'SEX - IMPUTATION INDICATOR'
   EIBDATE = 'EDIT INDICATOR FOR BIRTHDATE'
   IIAGE   = 'IMPUTATION INDICATOR FOR AGE'
   IRHOIND = 'IMPUTATION-REVISED HISPANIC ORIGIN'
   IIHOIND = 'IMPUTATION INDICATOR FOR HISPANIC ORIGIN'
   IRMARIT = 'MARITAL STATUS - IMPUTATION REVISED'
   IIMARIT = 'MARITAL STATUS - IMPUTATION INDICATOR'
   IRPINSUR= 'PRIVATE HEALTH INSURANCE - IMPUTATION RE'
   IIPINSUR= 'PRIVATE HEALTH INSURANCE - IMPUTATION IN'
   IRWORKST= 'WORK STATUS - IMPUTATION REVISED'
   IIWORKST= 'WORK STATUS - IMPUTATION INDICATOR'
   IRHSGRAD= 'HIGH SCHOOL GRADUATE - IMPUTATION REVISE'
   IREDUC  = 'EDUCATION - IMPUTATION REVISED'
   IIEDUC  = 'EDUCATION - IMPUTATION INDICATOR'
   IIHSGRAD= 'HIGH SCHOOL GRADUATE - IMPUTATION INDICA'
   IRHOGRP = 'IMPUTATION-REVISED HISPANIC-ORIGIN GROUP'
   IIHOGRP = 'IMPUTATION INDICATOR FOR HISPANIC-ORIGIN'
   EDUCCAT2= 'EDUCATION RECODE'
   EMPSTAT2= 'EMPLOYMENT STATUS RECODE'
   IRSTMRC = 'STIMULANTS RECENCY - IMPUTATION REVISED'
   IROTBRC = 'SMOKELESS TOBACCO RECENCY - IMPUTATION R'
   IRTRNRC = 'TRANQUILIZERS RECENCY - IMPUTATION REVIS'
   IRSEDRC = 'SEDATIVES RECENCY - IMPUTATION REVISED'
   IRMJRC  = 'MARIJUANA RECENCY - IMPUTATION REVISED'
   IRMJFQ  = 'MARIJUANA FREQUENCY PAST YEAR - IMPUTATI'
   IIMJFQ  = 'MARIJUANA FREQUENCY - IMPUTATION INDICAT'
   IROTBFQ = 'SMOKELESS TOBACCO FREQUENCY - IMPUTATION'
   IIOTBFQ = 'SMOKELESS TOBACCO FREQUENCY - IMPUTATION'
   IRSEDFQ = 'SEDATIVES FREQUENCY - IMPUTATION REVISED'
   IISEDFQ = 'SEDATIVES FREQUENCY - IMPUTATION INDICAT'
   IRSTMFQ = 'STIMULANTS FREQUENCY - IMPUTATION REVISE'
   IISTMFQ = 'STIMULANTS FREQUENCY - IMPUTATION INDICA'
   IRTRNFQ = 'TRANQUILIZERS FREQUENCY - IMPUTATION REV'
   IITRNFQ = 'TRANQUILIZERS FREQUENCY - IMPUTATION IND'
   IRHALRC = 'HALLUCINOGENS RECENCY - IMPUTATION REVIS'
   IRCOCRC = 'COCAINE RECENCY - IMPUTATION REVISED'
   IRINHRC = 'INHALANTS RECENCY - IMPUTATION REVISED'
   IRANLRC = 'ANALGESICS RECENCY - IMPUTATION REVISED'
   IRALCRC = 'ALCOHOL RECENCY - IMPUTATION REVISED'
   IRALCFQ = 'ALCOHOL FREQUENCY PAST  YEAR - IMPUTATIO'
   IIALCFQ = 'ALCOHOL FREQUENCY - IMPUTATION INDICATOR'
   IRANLFQ = 'ANALGESICS FREQUENCY - IMPUTATION REVISE'
   IIANLFQ = 'ANALGESICS FREQUENCY - IMPUTATION INDICT'
   IRCOCFQ = 'COCAINE FREQUENCY PAST YEAR - IMPUTATION'
   IICOCFQ = 'COCAINE RECENCY - IMPUTATION INDICATOR'
   IRHALFQ = 'HALLUCINOGEN FREQUENCY - IMPUTATION REVI'
   IIHALFQ = 'HALLUCINOGENS FREQUENCY - IMPUTATION IND'
   IRINHFQ = 'INHALANTS FREQUENCY - IMPUTATION REVISED'
   IIINHFQ = 'INHALANTS FREQUENCY - IMPUTATION INDICAT'
   IRPCPRC = 'PCP RECENCY - IMPUTATION REVISED'
   IIPCPRC = 'PCP RECENCY - IMPUTATION INDICATOR'
   IRCRKRC = 'CRACK RECENCY - IMPUTATION REVISED'
   IICRKRC = 'CRACK RECENCY - IMPUTATION INDICATOR'
   IRSTRRC = 'ANABOLIC STEROIDS RECENCY - IMPUTATION R'
   IISTRRC = 'ANABOLIC STEROIDS RECENCY - IMPUTATION I'
   IRICERC = 'ICE RECENCY - IMPUTATION REVISED'
   IIICERC = 'ICE RECENCY - IMPUTATION INDICATOR'
   IIINHRC = 'INHALANTS RECENCY - IMPUTATION INDICATOR'
   IIOTBRC = 'SMOKELESS TOBACCO RECENCY - IMPUTATION I'
   IRHERRC = 'HEROIN RECENCY - IMPUTATION REVISED'
   IIHERRC = 'HEROIN RECENCY - IMPUTATION INDICATOR'
   IIHALRC = 'HALLUCINOGENS RECENCY - IMPUTATION INDIC'
   IITRNRC = 'TRANQUILIZERS RECENCY - IMPUTATION INDIC'
   IIANLRC = 'ANALGESICS RECENCY - IMPUTATION INDICATO'
   IISTMRC = 'STIMULANTS RECENCY - IMPUTATION INDICATO'
   IISEDRC = 'SEDATIVES RECENCY - IMPUTATION INDICATOR'
   IICOCRC = 'COCAINE RECENCY - IMPUTATION INDICATOR'
   IIMJRC  = 'MARIJUANA RECENCY - IMPUTATION INDICATOR'
   IIALCRC = 'ALCOHOL RECENCY - IMPUTATION INDICATOR'
   NDL90REC= 'MOST RECENT TIME USED DRUG W/ A NEEDLE ('
   HALFLAG = 'HALLUCINOGENS - EVER USED'
   HALYR   = 'HALLUCINOGENS - PAST YEAR USE'
   HALMON  = 'HALLUCINOGENS - PAST MONTH USE'
   PCPFLAG = 'PCP - EVER USED'
   PCPYR   = 'PCP - PAST YEAR USE'
   PCPMON  = 'PCP - PAST MONTH USE'
   STMFLAG = 'STIMULANTS - EVER USED'
   STMYR   = 'STIMULANTS - PAST YEAR USE'
   STMMON  = 'STIMULANTS - PAST MONTH USE'
   SEDFLAG = 'SEDATIVES - EVER USED'
   SEDYR   = 'SEDATIVES - PAST YEAR USE'
   SEDMON  = 'SEDATIVES - PAST MONTH USE'
   TRQFLAG = 'TRANQUILIZERS - EVER USED'
   TRQYR   = 'TRANQUILIZERS - PAST YEAR USE'
   TRQMON  = 'TRANQUILIZERS - PAST MONTH USE'
   ANLFLAG = 'ANALGESICS - EVER USED'
   ANLYR   = 'ANALGESICS - PAST YEAR USE'
   ANLMON  = 'ANALGESICS - PAST MONTH USE'
   ALCFLAG = 'ALCOHOL - EVER USED'
   ALCYR   = 'ALCOHOL - PAST YEAR USE'
   ALCMON  = 'ALCOHOL - PAST MONTH USE'
   CIGFLAG = 'CIGARETTES - EVER USED'
   CIGYR   = 'CIGARETTES - PAST YEAR USE'
   CIGMON  = 'CIGARETTES - PAST MONTH USE'
   SMKFLAG = 'SMOKELESS TOBACCO - EVER USED'
   SMKYR   = 'SMOKELESS TOBACCO - PAST YEAR USE'
   SMKMON  = 'SMOKELESS TOBACCO - PAST MONTH USE'
   HERFLAG = 'HEROIN - EVER USED'
   HERYR   = 'HEROIN - PAST YEAR USE'
   HERMON  = 'HEROIN - PAST MONTH USE'
   STRFLAG = 'STEROID USE - LIFETIME'
   STRYR   = 'STEROID USE - PAST YEAR'
   STRMON  = 'STEROID USE - PAST MONTH'
   MRJFLAG = 'MARIJUANA - EVER USED'
   MRJYR   = 'MARIJUANA - PAST YEAR USE'
   MRJMON  = 'MARIJUANA - PAST MONTH USE'
   COCFLAG = 'COCAINE - EVER USED'
   COCYR   = 'COCAINE - PAST YEAR USE'
   COCMON  = 'COCAINE - PAST MONTH USE'
   CRKFLAG = 'CRACK - EVER USED'
   CRKYR   = 'CRACK - PAST YEAR USE'
   CRKMON  = 'CRACK - PAST MONTH USE'
   INHFLAG = 'INHALANTS - EVER USED'
   INHYR   = 'INHALANTS - PAST YEAR USE'
   INHMON  = 'INHALANTS - PAST MONTH USE'
   NEDFLAG3= 'NEEDLE USE (ANY DRUG) - EVER USE'
   NEDYR3  = 'NEEDLE USE (ANY DRUG) - PAST YEAR USE'
   COCYRF  = 'COCAINE - ANY USE PAST YEAR'
   COCMONF = 'COCAINE - MONTHLY OR MORE FREQUENT USE P'
   COCWKF  = 'COCAINE - WEEKLY OR MORE FREQUENT USE PA'
   COCOCCF = 'COCAINE OCCASIONAL FLAG'
   COCDLYF = 'COCAINE DAILY/ALMOST FLAG'
   ALCYRF  = 'ALCOHOL - ANY USE PAST YEAR'
   ALCMONF = 'ALCOHOL - MONTHLY OR MORE FREQUENT USE P'
   ALCWKF  = 'ALCOHOL - WEEKLY OR MORE FREQUENT USE PA'
   ALCOCCF = 'ALCOHOL OCCASIONAL FLAG'
   ALCDLYF = 'ALCOHOL DAILY/ALMOST FLAG'
   ANLYRF  = 'ANALGESICS YEAR FLAG'
   ANLMONF = 'ANALGESICS MONTH FLAG'
   ANLWKF  = 'ANALGESICS WEEK FLAG'
   ANLOCCF = 'ANALGESICS OCCASIONAL FLAG'
   ANLDLYF = 'ANALGESICS DAILY/ALMOST DAILY FLAG'
   HALYRF  = 'HALLUCINOGENS YEAR FLAG'
   HALMONF = 'HALLUCINOGENS MONTH FLAG'
   HALWKF  = 'HALLUCINOGENS WEEK FLAG'
   HALOCCF = 'HALLUCINOGENS OCCASIONAL FLAG'
   HALDLYF = 'HALLUCINOGENS DAILY/ALMOST DAILY FLAG'
   INHYRF  = 'INHALANTS YEAR FLAG'
   INHMONF = 'INHALANTS MONTH FLAG'
   INHWKF  = 'INHALANTS WEEK FLAG'
   INHOCCF = 'INHALANTS OCCASIONAL FLAG'
   INHDLYF = 'INHALANTS DAILY/ALMOST FLAG'
   SEDYRF  = 'SEDATIVES YEAR FLAG'
   SEDMONF = 'SEDATIVES MONTH FLAG'
   SEDWKF  = 'SEDATIVES WEEK FLAG'
   SEDOCCF = 'SEDATIVES OCCASIONAL FLAG'
   SEDDLYF = 'SEDATIVES DAILY/ALMOST DAILY FLAG'
   SMKYRF  = 'SMOKELESS TOBACCO YEAR FLAG'
   SMKMONF = 'SMOKELESS TOBACCO MONTH FLAG'
   SMKWKF  = 'SMOKELESS TOBACCO WEEK FLAG'
   SMKOCCF = 'SMOKELESS TOBACCO OCCASIONAL FLAG'
   SMKDLYF = 'SMOKELESS TOBACCO DAILY/ALMOST FLAG'
   STMYRF  = 'STIMULANTS YEAR FLAG'
   STMMONF = 'STIMULANTS MONTH FLAG'
   STMWKF  = 'STIMULANTS WEEK FLAG'
   STMOCCF = 'STIMULANTS OCCASIONAL FLAG'
   STMDLYF = 'STIMULANTS DAILY/ALMOST DAILY FLAG'
   TRQYRF  = 'TRANQUILIZERS YEAR FLAG'
   TRQMONF = 'TRANQUILIZERS MONTH FLAG'
   TRQWKF  = 'TRANQUILIZERS WEEK FLAG'
   TRQOCCF = 'TRANQUILIZERS OCCASIONAL FLAG'
   TRQDLYF = 'TRANQUILIZERS DAILY/ALMOST DAILY FLAG'
   MRJYRF  = 'MARIJUANA - ANY USE PAST YEAR'
   MRJMONF = 'MARIJUANA - MONTHLY OR MORE FREQUENT USE'
   MRJWKF  = 'MARIJUANA - WEEKLY OR MORE FREQUENT USE'
   MRJOCCF = 'MARIJUANA OCCASIONAL FLAG'
   MRJDLYF = 'MARIJUANA DAILY/ALMOST FLAG'
   PSYFLAG2= 'ANY PSYCHOTHERAPEUTICS - EVER USED'
   PSYYR2  = 'ANY PSYCHOTHERAPEUTICS - PAST YEAR USE'
   PSYMON2 = 'ANY PSYCHOTHERAPEUTICS - PAST MONTH USE'
   SUMFLAG = 'ANY ILLICIT DRUG - EVER USED'
   SUMYR   = 'ANY ILLICIT DRUG - PAST YEAR USE'
   SUMMON  = 'ANY ILLICIT DRUG - PAST MONTH USE'
   MJOFLAG = 'MARIJUANA ONLY - EVER USED'
   MJOYR2  = 'MARIJUANA ONLY - PAST YEAR USE'
   MJOMON2 = 'MARIJUANA ONLY - PAST MONTH USE'
   IEMFLAG = 'USED ILLICIT DRUGS EXCEPT MARIJUANA - LI'
   IEMYR   = 'USED ILLICIT DRUGS EXCEPT MARIJUANA - PA'
   IEMMON  = 'USED ILLICIT DRUGS EXCEPT MARIJUANA - PA'
   CATAGE  = 'AGE CATEGORY'
   RACE    = 'RACE/HISPANIC-ORIGIN RECODE'
   IRCIGRC = 'CIGARETTES RECENCY - IMPUTATION REVISED'
   IICIGRC = 'CIGARETTES RECENCY - IMPUTATION INDICATO'
   CATAG2  = 'AGE CATEGORY RECODE'
   AS3READ = 'TRANQUILIZERS - READING PREFERENCE'
   AS4READ = 'STIMULANTS - READING PREFERENCE'
   AS5READ = 'ANALGESICS - READING PREFERENCE'
   AS7READ = 'INHALANTS - READING PREFERENCE'
   INHQNC1 = 'QUESTION 1 NOT CLEAR'
   INHQNC2 = 'QUESTION 2 NOT CLEAR'
   INHQNC3 = 'QUESTION 3 NOT CLEAR'
   INHQNC4 = 'QUESTION 4 NOT CLEAR'
   INHQNC5 = 'QUESTION 5 NOT CLEAR'
   INHQNC6 = 'QUESTION 6 NOT CLEAR'
   INHQNC7 = 'QUESTION 7 NOT CLEAR'
   INHQNC8 = 'QUESTION 8 NOT CLEAR'
   INHQNC9 = 'QUESTION 9 NOT CLEAR'
   INHQNC10= 'ALL QUESTIONS WERE CLEAR'
   INHANSY = 'ANSWER MARKED FOR EACH QUESTION'
   AS9READ = 'HALLUCINOGENS - READING PREFERENCE'
   AS10READ= 'HEROIN - READING PREFERENCE'
   AS11READ= 'DRUGS - READING PREFERENCE'
   AS12READ= 'SPECIAL TOPICS - READING PREFERENCE'
   AS13READ= 'DRINKING EXPERIENCES - READING PREFERENC'
   AS15READ= 'TREATMENT - READING PREFERENCE'
   HIGHBP  = 'EVER DIAGNOSED AS HAVING HIGH BLOOD PRES'
   BPMED   = 'MEDICATION EVER PRESCRIBED FOR HIGH BLOO'
   WALKPAIN= 'EVER HAD PAIN IN CHEST FROM EXERTION'
   TIMEPAIN= 'EVER HAD SEVERE CHEST PAIN LASTING 1/2 H'
   UPSHOR  = 'EVER HAD SHORTNESS OF BREATH FROM EXERTI'
   ASTHMA  = 'EVER DIAGNOSED AS HAVING LUNG/CHEST COND'
   TRPSYCH = 'EVER TREATED FOR PSYCHOLOGICAL/EMOTIONAL'
   HEART   = 'EVER DIAGNOSED AS HAVING HEART CONDITION'
   FLU     = 'GET BAD COLD OR FLU EVERY YEAR'
   ALLERG  = 'HAS HAY FEVER'
   HOSPYR  = 'HOSPITALIZED OVERNIGHT FOR INJURY/ILLNES'
   SOREYR  = 'HAD SORE THROAT LASTING 3 OR MORE DAYS I'
   RUNNYYR = 'HAD RUNNY NOSE LASTING 3 OR MORE DAYS IN'
   COUGHYR = 'HAD COUGH LASTING ABOUT A WK 3/MORE TIME'
   PHLEGMYR= 'HAD COUGH W/PHLEGM LASTING 3 OR MORE WEE'
   HEALTHYR= 'HEALTH FOR PAST 12 MONTHS'
   MARITAL = 'MARITAL STATUS'
   NOMARR  = '# TIMES MARRIED'
   WORKSTAT= 'PRESENT WORK SITUATION'
   PAYMO   = 'MONTH LAST WORKED FOR PAY'
   PAYYR   = 'YEAR (19__) LAST WORKED FOR PAY'
   SECTOR  = 'BUSINESS/INDUSTRY SECTOR OF RESPONDENT'''
   NO5JOB  = '# OF JOBS LAST 5 YEARS'
   WORKDAYS= '# DAYS MISSED WORK DUE TO ILL/INJURY LAS'
   WORKBLAH= '# DAYS SKIPPED WORK LAST 30 DAYS'
   CWE     = 'CHIEF WAGE EARNER IN HOUSEHOLD (RELATION'
   FULLPART= 'WORK STATUS OF CHIEF WAGE EARNER'
   CWESECTR= 'BUSINESS/INDUSTRY SECTOR OF RESPONDENT'''
   EDUC    = 'LAST GRADE COMPLETED IN SCHOOL'
   GRADHS  = 'GRADUATED FROM HIGH SCHOOL'
   DIPLOMA = 'EVIDENCE OF HIGH SCHOOL COMPLETION'
   ENROLLD = 'NOW ENROLLED IN ANY SCHOOL'
   SCHPLANS= 'PLANS FOR FUTURE SCHOOLING'
   STUDENT = 'STUDENT STATUS NOW'
   SCHDAYS = '# OF DAYS MISSED SCHOOL DUE TO ILL/INJUR'
   SKIPPED = '# DAYS SKIPPED SCHOOL LAST MONTH'
   ACCID   = 'HAD MOTOR VEHICLE ACCIDENT IN PAST 12 MO'
   MOVDAWAY= 'ANY RESIDENT FOR 6 MONTHS IN PAST YEAR N'
   DORM    = '# OF FORMER RESIDENTS NOW LIVING AT COLL'
   MILBASE = '# OF FORMER RESIDENTS NOW LIVING ON MILI'
   HOSP    = '# OF FORMR RESDNTS NOW LVNG IN JAIL,HOSP'
   OTHGPH  = '# OF FORMER RESIDENTS NOW LIVING IN OTHE'
   OTHGPHSP= 'RESIDENTS NOW LIVING IN OTHER HOUSING (S'
   SERVICE = 'EVER SERVED IN ARMED FORCES'
   MILSTAT = 'CURRENT MILITARY STATUS'
   TELNO   = '# OF NON-BUSINESS PHONE NUMBERS IN HOUSE'
   MOVES   = '# OF TIMES MOVED PAST 5 YEARS'
   EAP     = 'ENDING TIME OF INTERVIEW - AM/PM INDICAT'
   UNDINT  = 'ESTIMATE RESPONDENT''S UNDERSTANDING OF'
   COOPINT = 'COOPERATION OF RESPONDENT'
   PRIVACY = 'SCALE FOR PRIVACY DURING INTERVIEW'
   PPRES   = 'PARENT(S) PRESENT OR LISTENING TO INTERV'
   SPRES   = 'SPOUSE PRESENT OR LISTENING TO INTERVIEW'
   PARPRES = 'LIVE-IN PARTNR/DATE PRSNT OR LISTENNG TO'
   OARPRES = 'ADULT RELATIVE(S) PRESENT/LISTENING TO I'
   OAPRES  = 'OTHER ADULT(S) PRESENT OR LISTENING TO I'
   CPRES   = 'CHILD(REN) UNDER 15 PRESENT/LISTENING TO'
   OPRESNSP= 'OTHER PERSON(S) PRESENT/LISTENING (NOT S'
   OPRESSPA= 'OTHER PERSON(S) PRESENT/LISTENING (FIRST'
   WHOMARKD= 'WHO MARKED ANSWERS ON ANSWER SHEET'
   MILES   = '# MILES RESPONDENT DRIVES IN A TYPICAL W'
   ETIME   = 'ENDING TIME OF INTERVIEW'
   MOTHER  = 'MOTHER OF RESPONDENT MEMBER OF HOUSEHOLD'
   FATHER  = 'FATHER OF RESPONDENT MEMBER OF HOUSEHOLD'
   STEPMOM = 'STEPMOTHER OF RESPONDENT MEMBER OF HOUSE'
   STEPDAD = 'STEPFATHER OF RESPONDENT MEMBER OF HOUSE'
   SPOUSE  = 'SPOUSE/LIVE-IN PARTNER OF RESP MEMBER OF'
   INLAW   = '# PARENT(S)-IN-LAW OF RESP LIVING IN HOU'
   OWNCHILD= '# BIOLOGICAL CHILDREN OF RESP LIVING IN'
   STEPCHLD= '# ADOPTED/STEPCHILDREN OF RESP LIVING IN'
   BROSIS  = '# BROTHERS/SISTERS OF RESP LIVING IN HOU'
   OTHREL  = '# OTHER RELATIVES OF RESP LIVING IN HOUS'
   FRIENDS = '# FRIENDS/ROOMMATES OF RESP LIVING IN HO'
   OTHERNON= '# OTHER PEOPLE UNRELATD TO RESP LIVING I'
   TOTPEOP = '# OF RESIDENTS IN HOUSEHOLD'
   NOCHILD = '# OF BIOLOGICAL CHILDREN'
   CIGREC  = 'MOST RECENT TIME SMOKED A CIGARETTE'
   BTIME   = 'BEGINNING TIME OF INTERVIEW'
   BAP     = 'BEGINNING TIME OF INTERVIEW - AM/PM INDI'
   LANGVER = 'LANGUAGE VERSION'
   ENCPSU  = 'PRIMARY SAMPLING UNIT (ENCRYPTED)'
   ENCSEG  = 'SEGMENT IDENTIFICATION NUMBER (ENCRYPTED'
   ENCCASE = 'HOUSEHOLD LEVEL IDENTIFICATION NUMBER (E'
   ANALWTC = 'ANAL. WT FOR SUBSAMPLE ASSUMING 1990 FRA'
   ANALWT  = 'ANALYSIS WEIGHT'
   ANALWT2 = 'ANALYSIS WEIGHT IN THOUSANDS OF PERSONS'
   WPNAC   = '1988-90-COMP. NONR.-ADJ. PERSON WEIGHT'
   WO      = 'SCREENING NONRESPONSE ADJUSTED DU WEIGHT'
   A1      = 'SAMPLE PERSON SELECTION COMPONENT'
   A2      = 'SAMPLE PERSON TRUNCATE AND SMOOTH FACTOR'
   A3      = 'ROSTER ADJUSTMENT FACTOR'
   A4      = 'INTERVIEW NONRESPONSE ADJUSTMENT FACTOR'
   W4      = 'THE NR ADJUSTED PERSON WEIGHT(WO*A1*A2*A'
   A5      = 'CPS ADJUSTMENT FACTOR FOR FULL SAMPLE'
   A6      = 'CPS ADJ. FACTOR FOR SUBSAMPLE ASSUMING 1'
   URBARE  = 'URBAN AREA IN THE SIX MSAS'
   CENCTY  = 'CENTRAL CITY IN THE SIX MSAS'
   GQTYP   = 'GROUP QUARTERS INDICATOR'
   IRHOGRP2= 'IMPUTATION-REVISED HISPANIC-ORIGIN GROUP'
   IIHOGRP2= 'IMPUTATION INDICATOR FOR HISPANIC GROUP'
   FAMSKIP = 'OTHER FAMILY MEMBERS IN THE HH INDICATOR'
   WORK    = 'SELF-EMPLOYED OR WORKING FOR EMPLOYER'
   WAG1    = 'PERSONALLY RECEIVED WAGES IN MONTH - REC'
   SOC1    = 'RECEIVED SS OR RR PAYMENTS'
   SSI1    = 'RECEIVED MONEY FROM SSI'
   WEL1    = 'PERSONALLY RECEIVED INCOME FROM WELFARE'
   INT1    = 'HAD MONEY THAT EARNED INTEREST'
   CHD1    = 'RECEIVED ANY CHILD SUPPORT PAYMENTS'
   OTH1    = 'RECEIVED INCOME FROM OTHER SOURCES'
   WAG2    = 'DID MEMBER OF FAMILY RECEIVE INCOME FROM'
   SOC2    = 'DID FAM MEM RECEIVE MONEY FROM SS OR RR'
   SSI2    = 'OTHER FAMILY MEMBER RECIVED MONEY FROM S'
   WEL2    = 'OTHR FAMLY MEM RECVD INCOME FROM WELFARE'
   INT2    = 'OTHER FAMILY MEMBER HAD MONEY THAT EARNE'
   CHD2    = 'OTHER FAM MEMBER RECEIVED CHILD SUPPORT'
   OTH2    = 'OTHER FAMLY MEM RECEIVED INCOME FROM OTH'
   FOOD    = 'ANY FAMILY MEMBER RECEIVED FOOD STAMPS -'
   AWAG1   = 'INCOME RECEIVED FROM ALL JOBS AND SELF E'
   ASOC1   = 'AMOUNT OF INCOME RECEIVED FROM RR OR SS'
   ASSI1   = 'AMOUNT OF INCOME RECEIVED FROM SSI'
   AWEL1   = 'AMOUNT OF INCOME RECEIVED FROM PUB.ASSIT'
   AINT1   = 'AMOUNT OF INCOME FROM INTEREST'
   ACHD1   = 'AMOUNT OF INCOME RECEIVED FROM CHILD SUP'
   AOTH1   = 'AMOUNT OF INCOME RECEIVED FROM OTHER SOU'
   AWAG2   = 'INCOME RECEIVED FROM ALL MEMS OF FAMILY/'
   ASOC2   = 'FAMILY INCOME FROM SS OR RR'
   ASSI2   = 'AMOUNT OF FAMILY INCOME RECEIVED FROM SS'
   AWEL2   = 'AMOUNT FAMLY RECEIVED FROM PUB ASSISTCE'
   AINT2   = 'AMOUNT OF FAMILY INCOME EARNED FROM INTE'
   ACHD2   = 'AMOUNT OF INCOME FAMLY RECEIVED FROM CHI'
   AOTH2   = 'AMOUNT OF INCOME FAMILY RECEIVED FROM OT'
   AFOOD   = 'TOTAL VALUE OF FOOD STAMP ALLOTMENT'
   IRWAG1  = 'RECEIVED WAGES - IMPUTATION REVISED'
   IRSOC1  = 'RECEIVED INCOME FROM SS/RR - IMPUTATION'
   IRSSI1  = 'RECEIVED INCOME FROM SSI - IMPUTATION RE'
   IRWEL1  = 'RECEIVED WELFARE - IMPUTATION REVISED'
   IRINT1  = 'RECEIVED INTEREST - IMPUTATION REVISED'
   IRCHD1  = 'RECEIVED CHILD SUPPORT - IMPUTATION REVI'
   IROTH1  = 'RECEIVED OTHER SOURCES - IMPUTATION REVI'
   IRWAG2  = 'OTHR FAM MEM RECEIVED WAGES - IMPUTATION'
   IRSOC2  = 'OTHR FAM RECVD INCOME FR SS/RR - IMPUT.'
   IRSSI2  = 'OTHR FAM RECVD INCOME FR SSI - IMPUT. RE'
   IRWEL2  = 'OTHR FAM MEM RECEIVED WELFARE - IMPUTATI'
   IRINT2  = 'OTHR FAM RECVD INTEREST - IMPUTATION REV'
   IRCHD2  = 'OTHR FAM RECVED CHILD SUPPORT - IMPUTATI'
   IROTH2  = 'OTHR FAM RECVD OTHR SOURCES - IMPUTATION'
   IRFOOD  = 'ANY FAM MEM RECVD FOOD STAMP - IMPUTATIO'
   IRAWAG1 = 'AMNT RECEIVED FROM WAGES - IMPUTATION RE'
   IRASOC1 = 'AMNT RECEIVED FROM SS OR RR - IMPUTATION'
   IRASSI1 = 'AMNT RECEIVED FROM SSI - IMPUTATION REVI'
   IRAWEL1 = 'AMNT RECEIVED FROM WELFARE - IMPUTATION'
   IRAINT1 = 'AMNT RECEIVED FROM INTEREST - IMPUTATION'
   IRACHD1 = 'AMNT RECEIVED FROM CHILD SUPPORT - IMPUT'
   IRAOTH1 = 'AMNT RECEIVED FROM OTHER SOURCES - IMPUT'
   IRAWAG2 = 'AMNT OTHR FAM RECVD FR WAGES - IMPUTATIO'
   IRASOC2 = 'AMNT OTHR FAM RECVD FROM SS/RR - IMPUT.'
   IRASSI2 = 'AMNT OTHR FAM RECVD FROM SSI - IMPUTATIO'
   IRAWEL2 = 'AMNT OTHR FAM RECVD FR WELFARE - IMPUT.'
   IRAINT2 = 'AMNT FAM RECVD FROM INTEREST - IMPUTATIO'
   IRACHD2 = 'AMNT OTHR FAM RECVD FR CHLD SUPRT - IMPU'
   IRAOTH2 = 'AMNT OTHR FAM RECVD FR OTHR SRCES - IMPU'
   IRAFOOD = 'VALUE OF FOOD STAMP - IMPUTATION REVISED'
   IIWAG1  = 'RECEIVED WAGES - IMPUTATION INDICATOR'
   IISOC1  = 'RECEIVED INCOME FR SS/RR - IMPUTATION IN'
   IISSI1  = 'RECEIVED INCOME FROM SSI - IMPUTATION IN'
   IIWEL1  = 'RECEIVED WELFARE - IMPUTATION INDICATOR'
   IIINT1  = 'RECEIVED INTEREST - IMPUTATION INDICATOR'
   IICHD1  = 'RECEIVED FROM CHILD SUPPORT - IMPUTATION'
   IIOTH1  = 'RECVD INCOME FR OTHR SOURCS - IMPUTATION'
   IIWAG2  = 'OTHR FAM MEM RECVD WAGES - IMPUTATION IN'
   IISOC2  = 'OTHR FAM RECVED INCOME FR SS/RR - IMPUT.'
   IISSI2  = 'OTHR FAM RECVED FROM SSI - IMPUTATION IN'
   IIWEL2  = 'OTHR FAM MEM RECVD WELFARE - IMPUTATION'
   IIINT2  = 'OTHR FAM RECVD INTEREST - IMPUTATION IND'
   IICHD2  = 'OTHR FAM RECVD FR CHILD SUPPORT - IMPUT.'
   IIOTH2  = 'OTHR FAM RECVD OTHR SOURCES - IMPUTATION'
   IIFOOD  = 'ANY FAM MEM RECVD FOOD STMP - IMPUTATION'
   IIAWAG1 = 'AMOUNT RECEIVED FROM WAGES - IMPUTATION'
   IIASOC1 = 'AMT RECEIVED FROM SS/RR - IMPUTATION IND'
   IIASSI1 = 'AMOUNT RECEIVED FROM SSI - IMPUTATION IN'
   IIAWEL1 = 'AMT RECEIVED FROM WELFARE - IMPUTATION I'
   IIAINT1 = 'AMT RECEIVED FROM INTEREST - IMPUTATION'
   IIACHD1 = 'AMT RECVD FR CHILD SUPPORT - IMPUTATION'
   IIAOTH1 = 'AMT RECVD FR OTHR SOURCES - IMPUTATION I'
   IIAWAG2 = 'AMT OTHR FAM RECVD FR WAGES - IMPUTATION'
   IIASOC2 = 'AMT OTHR FAM RECVD FR SS/RR - IMPUTATION'
   IIASSI2 = 'AMT OTHR FAM RECVD FROM SSI - IMPUTATION'
   IIAWEL2 = 'AMT OTHR FAM RECVD FROM WELFARE - IMPUT.'
   IIAINT2 = 'AMT OTHR FAM RECVD FR INTEREST - IMPUT.'
   IIACHD2 = 'AMT OTHR RECVD FR CHILD SUPPORT - IMPUT.'
   IIAOTH2 = 'AMT OTHR FAM RECVD FR OTHR SOURCS - IMPU'
   IIAFOOD = 'AMT FAM RECVD FR FOOD STAMP - IMPUTATION'
   JOB     = 'HAVE A JOB IN (MONTH)'
   HOURS   = 'TOTAL HOURS WORKED IN (MONTH)'
   WEEKS   = '# WEEKS LAST YEAR YOU WORKED'
   PUB1    = 'RECEIVED PUBLIC ASSISTANCE OR WELFARE PA'
   AFDC1   = 'RECEIVED AFDC OR OTHER TYPE OF ASSISTANC'
   PUB2    = 'OTHR FAM MEMBR RECEIVED PUB ASSISTANCE O'
   AFDC2   = 'OTHER FAMILY MEMBER RECEIVED AFDC OR ADC'
   FSTAMP  = 'YOU OR FAMILY LIVING HERE RECEIVED FOOD'
   PEOPFD  = '# PEOPLE COUNTED IN FOOD STAMP ALLOTMENT'
   WELFARE = 'ANY FAMILY MEMBER ON WELFARE PAST MONTH'
   TWOFAM  = 'TWO PEOPLE SAMPLED AND BELONG TO FAM IND'
   INDINC  = 'ANNUAL TOTAL PERSONAL INCOME RECEIVED'
   IIINDINC= 'TOTL PERSONAL INCOME - IMPUTATION INDICA'
   TOTINC  = 'TOTAL FAMILY INCOME FROM IRINC49A - IRIN'
   IITOTINC= 'TOTL FAM INCOME (NOT FD STMP) - IMPUT. I'
   INDCAT  = 'ANNUAL TOTAL PERSONAL INCOME RECODE (13'
   TOTCAT  = 'TOTAL FAMILY INCOME - CATEGORIZED TOTINC'
   PERINC  = 'ANNUAL TOTAL PERSONAL INCOME RECODE (5 C'
   FAMINC  = 'TOTAL FAMILY INCOME RECODE'
   PERINC2 = 'ANNUAL TOTAL PERSONAL INCOME RECODE (7 C'
   FAMINC2 = 'ANNUAL TOTAL FAMILY INCOME RECODE (7 CAT'
   FAMINC3 = 'ANNUAL TOTAL FAMILY INCOME RECODE (8 CAT'
   PERINC3 = 'ANNUAL TOTAL PERSONAL INCOME RECODE (8 C'
   PRVHLTIN= 'COVERED BY PRIVATE HEALTH INSURANCE LFCM'
   PLYFLAGC= 'ILLICIT POLYDRUGS - EVER USED'
   PLYYRC  = 'ILLICIT POLYDRUGS - USED IN PAST YEAR'
   PLYMONC = 'ILLICIT POLYDRUGS - USED IN PAST MONTH'
   WPSTAT  = 'WOMEN''S PARENTAL STATUS'
   OWNOCONC= 'CATEG. % OWNER-OCCUPIED HH''S IN SEGMENT'
   NHBHCONC= 'CATEG. % NONHISP. BLACK HH''S IN SEGMENT'
   NHBPCONC= 'CATEG. % NONHISP. BLACK POP. IN SEGMENT'
   HSPPCONC= 'CATEG. % HISPANIC POP. IN SEGMENT IN 198'
   HSPHCONC= 'CATEG. % HISPANIC HH''S IN SEGMENT IN 19'
   METRO   = 'METROPOLITAN AREA'
   PROXABLE= 'OTHR FMLY MEMBR ABLE TO GIVE INFO ON HLT'
   PROXYREL= 'RELATN TO R OF PERSN ABLE TO GIVE INFO O'
   PROXHOME= 'RELATIVE HERE AT HOME NOW'
   PROXJOIN= 'WOULD YOU ASK RELATIVE TO JOIN US NOW'
   MEDICARE= 'COVERED BY MEDICARE LAST FULL CALENDAR M'
   MEDICAID= 'COVERED BY MEDICAID LAST FULL CALENDAR M'
   CHAMPUS = 'COVERED BY CHAMPUS,CHAMPVA,VA,MIL. HLTH'
   OWNHLTIN= 'PRIVATE PLAN IN OWN NAME OR FAMILY NAME'
   GRPHLTIN= 'PRIVATE PLAN OFFERED BY YOUR/FAMILY EMPL'
   HLTINALC= 'PRIVATE PLAN COVERED ALCOHOL ABUSE LFCM.'
   HLTINDRG= 'PRIVATE PLAN COVERED DRUG ABUSE LFCM.'
   HLTINMNT= 'PRIVATE PLAN COVERED MENTAL DIFFICULTIES'
   WHOANSHI= 'WHO ANSWERED QUESTIONS ABOUT HEALTH INSU'
   WHOANSIN= 'WHO ANSWERED MOST QUESTIONS ABOUT FAMILY'
   NEEDLREC= 'MOST RECENT TIME USED STM,COC OR HER WIT'
   IRINSUR = 'HEALTH INSURANCE - IMPUTATION REVISED'
   IIINSUR = 'HEALTH INSURANCE - IMPUTATION INDICATOR'
   HERREC92= 'MOST RECENT TIME USED HEROIN - 1992 EDIT'
   IRHERC92= 'HEROIN RECENCY - IMPUTATION REVISED - 19'
   IIHERC92= 'HEROIN RECENCY - IMPUTATION INDICATOR -'
   VESTR   = 'STRATUM TO BE USED IN ANALYSIS'
   VEREP   = 'REPLICATE WITHIN ANALYSIS STRATUM'
   BIRMON  = 'BIRTH MONTH'
   BIRYEAR = 'BIRTH YEAR'
   IRALCAGG= 'FELT AGGRESSIVE WHILE DRNKNG PST YR (L.I'
   IRALCARG= 'HEATED ARGUMNTS WHLE DRNKNG PST YR (L.I.'
   IRALCABS= 'ABSNT WRK/SCH FROM HANGOVER PST YR (L.I.'
   IRALCHIG= 'HIGH/LITTLE DRUNK AT WRK/SCH PST YR (L.I'
   IRALCJOB= 'LOST/NRLY LOST JOB FRM DRNKNG PST YR (L.'
   IRALCMAT= 'SPOUS/DATE SAY CUT DWN DRNK PST YR (L.I.'
   IRALCREL= 'RELATIVE SAY CUT DWN DRNKNG PST YR (L.I.'
   IRALCFRD= 'FRNDS SAID CUT DOWN DRINKNG PST YR (L.I.'
   IRALCTOS= 'DRNK FAST FOR QUICKER EFFECT PST YR (L.I'
   IRALCHOL= 'AFRAID MGHT BE/BECME ALCHLC PST YR (L.I.'
   IRALCDRU= 'STAYD DRUNK >1DAY AT A TIME PST YR (L.I.'
   IRALCINT= 'NOT STP DRNKNG TILL INTXCTD PST YR (L.I.'
   IRALCREM= 'NOT REMEMBR THNGS WHLE DRNKNG PST YR (L.'
   IRALCQUI= 'QUICK DRINKS NO ONE LOOKING PST YR (L.I.'
   IRALCMOR= 'OFTEN DRINK 1ST THNG MORNING PST YR (L.I'
   IRALCSHO= 'HNDS SHK AFT DRNK DAY BEFOR PST YR (L.I.'
   IRALCALO= 'GOT DRUNK WHLE DRNKNG ALONE PST YR (L.I.'
   IRALCBRK= 'KPT DRNKNG AFT PROMISNG STP PST YR (L.I.'
   IRNOBOOZ= 'NO USE OF BEER/WINE/LIQUOR PST YR (L.I.'
   ANYALC  = 'ANY PROBS W/ALCOHOL PAST YR'
   THREALC = 'GE 3 PROBS W/ALCOHOL PAST YR'
   DRUNKYR2= '# TIMES DRUNK ON ALC PAST 12 MONTH'
   TRMTHLP2= 'TREATMENT RECEIVED FOR DRUG USE IN PAST'
   DRNKHLP2= 'TREATMENT RECEIVED FOR DRINKING IN PAST'
   DRALHELP= 'TREATMENT RECEIVED FOR DRUGS OR DRINKING'
   ICEFLAG = 'ICE - EVER USED'
   ICEYR   = 'ICE - PAST YEAR USE'
   ICEMON  = 'ICE - PAST MONTH USE'
   MJTOT2  = '# TIMES USED MARIJUANA IN LIFE'
   COCTOT2 = '# TIMES USED COCAINE IN LIFE'
   MJTOT3  = '# TIMES USED MARIJUANA IN LIFE'
   COCTOT3 = '# TIMES USED COCAINE IN LIFE'
   MJDY30A2= '# DAYS USED MARIJUANA IN PAST 30 DAYS'
   ALCDAYS2= '# DAYS DRANK ALCOHOL IN PAST 30 DAYS'
   MRJMON2 = 'MARIJUANA - PAST MONTH USE'
   ALCMON2 = 'ALCOHOL - PAST MONTH USE'
   CIGMON2 = 'CIGARETTES - PAST MONTH USE'
   LSD2    = 'EVER USED LSD'
   PEYOTE2 = 'EVER USED PEYOTE'
   MESC2   = 'EVER USED MESCALINE'
   PSILCY2 = 'EVER USED PSILOCYBIN (MUSHROOMS)'
   ECSTASY2= 'EVER USED ECSTASY'
   GAS2    = 'EVER INHALED GASOLINE OR LIGHTER FLUID'
   LGAS2   = 'EVER INHALED LIGHTER GASES (BUTANE, PROP'
   SPPAINT2= 'EVER INHALED SPRAY PAINTS'
   AEROS2  = 'EVER INHALED OTHER AEROSOL SPRAYS'
   GLUE2   = 'EVER INHALED SHOESHINE LIQUID/GLUE/TOLUE'
   SOLVENT2= 'EVER INHALED LACQUER THINNER/PAINT SOLVE'
   AMYLNIT2= 'EVER INHALED AMYL NITRITE/LOCKER RM ODOR'
   ETHER2  = 'EVER INHALED HALOTHANE/ETHER/OTHER ANEST'
   NITOXID2= 'EVER INHALED NITROUS OXIDE/WHIPPETS RECO'
   CLEFLU2 = 'EVER INHALED CORR. FLD/DEGREASER/CLEAN.'
   COCSNIF2= 'SNIFFED/SNORTED COC. THRU NOSE PAST 12 M'
   FREEBAS2= 'SMOKED/FREE-BASED COCAINE PAST 12 MONTHS'
   COCSWAL2= 'SWALLOWED/DRANK COCAINE PAST 12 MONTHS'
   COCIV2  = 'INJECTED COCAINE WITH NEEDLE PAST 12 MON'
   MJDY30A3= '# DAYS USED MARIJUANA IN PAST 30'
   ALCDAYS3= '# DAYS DRANK ALCOHOL IN PAST 30 DAYS'
   DRINKER2= 'DRANK ALCOHOL - PAST 30 DAYS'
   HVYDRK2 = 'DRANK ALCOHOL HEAVILY - PAST 30 DAYS'
   AVCIG2  = '# CIG. SMOKED PER DAY LAST 30'
   RACESEX = 'RACE AND SEX COMBINED'
   NOTMARJ = 'DRUG USE OTHER THAN MARIJUANA - PAST MON'
   RACESEX2= 'RACE AND SEX COMBINED'
   ALCONLYL= 'ONLY ALCOHOL - EVER USED'
   ALCONLYY= 'ONLY ALCOHOL - PAST YEAR USE'
   ALCONLYM= 'ONLY ALCOHOL - PAST MONTH USE'
   ILLONLYL= 'ONLY ILLICIT DRUGS - EVER USED'
   ILLONLYY= 'ONLY ILLICIT DRUGS - PAST YEAR USE'
   ILLONLYM= 'ONLY ILLICIT DRUGS - PAST MONTH USE'
   MRJONLYL= 'ONLY MARIJUANA - EVER USED'
   MRJONLYY= 'ONLY MARIJUANA - PAST YEAR USE'
   MRJONLYM= 'ONLY MARIJUANA - PAST MONTH USE'
   PSYONLYL= 'ONLY PSYCHOTHERAPEUTICS - EVER USED'
   PSYONLYY= 'ONLY PSYCHOTHERAPEUTICS - PAST YEAR USE'
   PSYONLYM= 'ONLY PSYCHOTHERAPEUTICS - PAST MONTH USE'
   OTHONLYL= 'ONLY OTHER DRUGS AND DRUG COMB. - EVER U'
   OTHONLYY= 'ONLY OTHER DRUGS AND DRUG COMB. - PAST Y'
   OTHONLYM= 'ONLY OTHER DRUGS AND DRUG COMB. - PAST M'
   ALCILLL = 'ALCOHOL & ILLICIT DRUGS - EVER USED'
   ALCILLY = 'ALCOHOL & ILLICIT DRUGS - PAST YEAR USE'
   ALCILLM = 'ALCOHOL & ILLICIT DRUGS - PAST MONTH USE'
   ALCMRJL = 'ALCOHOL & MARIJUANA - EVER USED'
   ALCMRJY = 'ALCOHOL & MARIJUANA - PAST YEAR USE'
   ALCMRJM = 'ALCOHOL & MARIJUANA - PAST MONTH USE'
   ALCPSYL = 'ALCOHOL & PSYCHOTHERAPEUTICS - EVER USED'
   ALCPSYY = 'ALCOHOL & PSYCHOTHERAPEUTICS - PAST YEAR'
   ALCPSYM = 'ALCOHOL & PSYCHOTHERAPEUTICS - PAST MONT'
   ALCOTHL = 'ALCOHOL & OTHER DRUGS & DRUG COMB.- EVER'
   ALCOTHY = 'ALCOHOL & OTHER DRUGS & DRUG COMB.- PAST'
   ALCOTHM = 'ALCOHOL & OTHER DRUGS & DRUG COMB.- PAST'
   SUB1LIF = 'USED ONLY 1 SUBSTANCE - EVER'
   SUB2LIF = 'USED ONLY 2 SUBSTANCES - EVER'
   SUB3LIF = 'USED 3 OR MORE SUBSTANCES - EVER'
   SUB1YR  = 'USED ONLY 1 SUBSTANCE - PAST YEAR'
   SUB2YR  = 'USED ONLY 2 SUBSTANCES - PAST YEAR'
   SUB3YR  = 'USED 3 OR MORE SUBSTANCES - PAST YEAR'
   SUB1MON = 'USED ONLY 1 SUBSTANCE - PAST MONTH'
   SUB2MON = 'USED ONLY 2 SUBSTANCES - PAST MONTH'
   SUB3MON = 'USED 3 OR MORE SUBSTANCES - PAST MONTH'
   IRDEP   = 'DEPRESSION PST YR DUE TO DRUGS (L.I. DRD'
   IRARG   = 'ARGUMENTS PST YR DUE TO DRUGS (L.I. DRAR'
   IRALN   = 'FELT ALONE PST YR DUE TO DRUGS (L.I. DRA'
   IRANX   = 'FELT ANXIOUS PST YR DUE TO DRUGS (L.I. D'
   IRHLT   = 'HEALTH PROBS PST YR DUE TO DRUGS (L.I. D'
   IRNTK   = 'DFF THNKNG CLR PST YR DUE TO DRUGS (L.I.'
   IRUPS   = 'FELT UPSET PST YR DUE TO DRUGS (L.I. DRU'
   IRLSW   = 'DID LESS WORK PST YR DUE TO DRUGS (L.I.'
   IRSSP   = 'FLT SUSPICIOUS PST YR DUE TO DRUGS (L.I.'
   IRCPE   = 'PRB HARD TO HNDL PST YR DUE TO DRUGS (L.'
   IREMG   = 'EMERG MED HELP PST YR DUE TO DRUGS (L.I.'
   IRDEP1  = '1ST DRUG CAUSING DEPRESSION (L.I. DEPDRG'
   IRDEP2  = '2ND DRUG CAUSING DEPRESSION (L.I. DEPDRG'
   IRDEP3  = '3RD DRUG CAUSING DEPRESSION (L.I. DEPDRG'
   IRDEP4  = '4TH DRUG CAUSING DEPRESSION (L.I. DEPDRG'
   IRDEP5  = '5TH DRUG CAUSING DEPRESSION (L.I. DEPDRG'
   IRARG1  = '1ST DRUG CAUSING ARGUMENTS (L.I. ARGDRG1'
   IRARG2  = '2ND DRUG CAUSING ARGUMENTS (L.I. ARGDRG2'
   IRARG3  = '3RD DRUG CAUSING ARGUMENTS (L.I. ARGDRG3'
   IRARG4  = '4TH DRUG CAUSING ARGUMENTS (L.I. ARGDRG4'
   IRARG5  = '5TH DRUG CAUSING ARGUMENTS (L.I. ARGDRG5'
   IRALN1  = '1ST DRUG CAUSING FEELING ALONE (L.I. ALN'
   IRALN2  = '2ND DRUG CAUSING FEELING ALONE (L.I. ALN'
   IRALN3  = '3RD DRUG CAUSING FEELING ALONE (L.I. ALN'
   IRALN4  = '4TH DRUG CAUSING FEELING ALONE (L.I. ALN'
   IRALN5  = '5TH DRUG CAUSING FEELING ALONE (L.I. ALN'
   IRANX1  = '1ST DRUG CAUSING FEELING ANXIOUS (L.I. A'
   IRANX2  = '2ND DRUG CAUSING FEELING ANXIOUS (L.I. A'
   IRANX3  = '3RD DRUG CAUSING FEELING ANXIOUS (L.I. A'
   IRANX4  = '4TH DRUG CAUSING FEELING ANXIOUS (L.I. A'
   IRANX5  = '5TH DRUG CAUSING FEELING ANXIOUS (L.I. A'
   IRHLT1  = '1ST DRUG CAUSING HEALTH PROBLEMS (L.I. H'
   IRHLT2  = '2ND DRUG CAUSING HEALTH PROBLEMS (L.I. H'
   IRHLT3  = '3RD DRUG CAUSING HEALTH PROBLEMS (L.I. H'
   IRHLT4  = '4TH DRUG CAUSING HEALTH PROBLEMS (L.I. H'
   IRHLT5  = '5TH DRUG CAUSING HEALTH PROBLEMS (L.I. H'
   IRNTK1  = '1ST DRUG CAUSNG DFFCLTY THNKNG CLR (L.I.'
   IRNTK2  = '2ND DRUG CAUSNG DFFCLTY THNKNG CLR (L.I.'
   IRNTK3  = '3RD DRUG CAUSNG DFFCLTY THNKNG CLR (L.I.'
   IRNTK4  = '4TH DRUG CAUSNG DFFCLTY THNKNG CLR (L.I.'
   IRNTK5  = '5TH DRUG CAUSNG DFFCLTY THNKNG CLR (L.I.'
   IRUPS1  = '1ST DRUG CAUSING FEELING UPSET (L.I. UPS'
   IRUPS2  = '2ND DRUG CAUSING FEELING UPSET (L.I. UPS'
   IRUPS3  = '3RD DRUG CAUSING FEELING UPSET (L.I. UPS'
   IRUPS4  = '4TH DRUG CAUSING FEELING UPSET (L.I. UPS'
   IRUPS5  = '5TH DRUG CAUSING FEELING UPSET (L.I. UPS'
   IRLSW1  = '1ST DRUG CAUSING LESS WORK DONE (L.I. LS'
   IRLSW2  = '2ND DRUG CAUSING LESS WORK DONE (L.I. LS'
   IRLSW3  = '3RD DRUG CAUSING LESS WORK DONE (L.I. LS'
   IRLSW4  = '4TH DRUG CAUSING LESS WORK DONE (L.I. LS'
   IRLSW5  = '5TH DRUG CAUSING LESS WORK DONE (L.I. LS'
   IRSSP1  = '1ST DRUG CAUSING FEELNG SUSPICIOUS (L.I.'
   IRSSP2  = '2ND DRUG CAUSING FEELNG SUSPICIOUS (L.I.'
   IRSSP3  = '3RD DRUG CAUSING FEELNG SUSPICIOUS (L.I.'
   IRSSP4  = '4TH DRUG CAUSING FEELNG SUSPICIOUS (L.I.'
   IRSSP5  = '5TH DRUG CAUSING FEELNG SUSPICIOUS (L.I.'
   IRCPE1  = '1ST DRUG CAUSING PRB HARDER HANDLE (L.I.'
   IRCPE2  = '2ND DRUG CAUSING PRB HARDER HANDLE (L.I.'
   IRCPE3  = '3RD DRUG CAUSING PRB HARDER HANDLE (L.I.'
   IRCPE4  = '4TH DRUG CAUSING PRB HARDER HANDLE (L.I.'
   IRCPE5  = '5TH DRUG CAUSING PRB HARDER HANDLE (L.I.'
   IREMG1  = '1ST DRUG CAUSING NEED OF EMG MD HLP (L.I'
   IREMG2  = '2ND DRUG CAUSING NEED OF EMG MD HLP (L.I'
   IREMG3  = '3RD DRUG CAUSING NEED OF EMG MD HLP (L.I'
   IREMG4  = '4TH DRUG CAUSING NEED OF EMG MD HLP (L.I'
   IREMG5  = '5TH DRUG CAUSING NEED OF EMG MD HLP (L.I'
   IRAS13  = 'NEVER USED ANY LISTED SUBSTANCES (L.I. A'
   ANYPROB = 'ANY OF THE 11 PROBS ON DRUG SHEET #14'
   TWOPROB = 'TWO OR MORE OF THE 11 PROBS ON DRUG SHEE'
   THREPROB= 'THREE OR MORE OF THE 11 PROBS ON DRUG SH'
   DEPCIG2 = 'BECAME DEPRESSED PAST YEAR DUE TO CIG'
   DEPALC2 = 'BECAME DEPRESSED PAST YEAR DUE TO ALC'
   DEPMRJ2 = 'BECAME DEPRESSED PAST YEAR DUE TO MRJ'
   DEPCOC2 = 'BECAME DEPRESSED PAST YEAR DUE TO COC'
   ARGCIG2 = 'HAD ARGUMNTS PAST YEAR DUE TO CIG'
   ARGALC2 = 'HAD ARGUMNTS PAST YEAR DUE TO ALC'
   ARGMRJ2 = 'HAD ARGUMNTS PAST YEAR DUE TO MRJ'
   ARGCOC2 = 'HAD ARGUMNTS PAST YEAR DUE TO COC'
   ALNCIG2 = 'FELT ALONE PAST YEAR DUE TO CIG'
   ALNALC2 = 'FELT ALONE PAST YEAR DUE TO ALC'
   ALNMRJ2 = 'FELT ALONE PAST YEAR DUE TO MRJ'
   ALNCOC2 = 'FELT ALONE PAST YEAR DUE TO COC'
   ANXCIG2 = 'FELT NERVOUS PAST YEAR DUE TO CIG'
   ANXALC2 = 'FELT NERVOUS PAST YEAR DUE TO ALC'
   ANXMRJ2 = 'FELT NERVOUS PAST YEAR DUE TO MRJ'
   ANXCOC2 = 'FELT NERVOUS PAST YEAR DUE TO COC'
   HLTCIG2 = 'HEALTH PROBS PAST YEAR DUE TO CIG'
   HLTALC2 = 'HEALTH PROBS PAST YEAR DUE TO ALC'
   HLTMRJ2 = 'HEALTH PROBS PAST YEAR DUE TO MRJ'
   HLTCOC2 = 'HEALTH PROBS PAST YEAR DUE TO COC'
   NTKCIG2 = 'DIFF THNKNG CLEARLY PST YR DUE TO CIG'
   NTKALC2 = 'DIFF THNKNG CLEARLY PST YR DUE TO ALC'
   NTKMRJ2 = 'DIFF THNKNG CLEARLY PST YR DUE TO MRJ'
   NTKCOC2 = 'DIFF THNKNG CLEARLY PST YR DUE TO COC'
   UPSCIG2 = 'FELT UPSET PAST YEAR DUE TO CIG'
   UPSALC2 = 'FELT UPSET PAST YEAR DUE TO ALC'
   UPSMRJ2 = 'FELT UPSET PAST YEAR DUE TO MRJ'
   UPSCOC2 = 'FELT UPSET PAST YEAR DUE TO COC'
   LSWCIG2 = 'LESS WRK SCH/JOB PST YR DUE TO CIG'
   LSWALC2 = 'LESS WRK SCH/JOB PST YR DUE TO ALC'
   LSWMRJ2 = 'LESS WRK SCH/JOB PST YR DUE TO MRJ'
   LSWCOC2 = 'LESS WRK SCH/JOB PST YR DUE TO COC'
   SSPCIG2 = 'FELT SUSPICIOUS PST YR DUE TO CIG'
   SSPALC2 = 'FELT SUSPICIOUS PST YR DUE TO ALC'
   SSPMRJ2 = 'FELT SUSPICIOUS PST YR DUE TO MRJ'
   SSPCOC2 = 'FELT SUSPICIOUS PST YR DUE TO COC'
   CPECIG2 = 'PROB HARD TO HANDLE DUE TO CIG'
   CPEALC2 = 'PROB HARD TO HANDLE DUE TO ALC'
   CPEMRJ2 = 'PROB HARD TO HANDLE DUE TO MRJ'
   CPECOC2 = 'PROB HARD TO HANDLE DUE TO COC'
   EMCIG2  = 'EMERG MED HELP PST YR DUE TO CIG'
   EMALC2  = 'EMERG MED HELP PST YR DUE TO ALC'
   EMMRJ2  = 'EMERG MED HELP PST YR DUE TO MRJ'
   EMCOC2  = 'EMERG MED HELP PST YR DUE TO COC'
   PRB1CIG = 'CIG USER WITH 1 OR MORE PROBS DUE TO CIG'
   PRB1ALC = 'ALC USER WITH 1 OR MORE PROBS DUE TO ALC'
   PRB1MRJ = 'MRJ USER WITH 1 OR MORE PROBS DUE TO MRJ'
   PRB1COC = 'COC USER WITH 1 OR MORE PROBS DUE TO COC'
   PRB2CIG = 'CIG USER WITH 2 OR MORE PROBS DUE TO CIG'
   PRB2ALC = 'ALC USER WITH 2 OR MORE PROBS DUE TO ALC'
   PRB2MRJ = 'MRJ USER WITH 2 OR MORE PROBS DUE TO MRJ'
   PRB2COC = 'COC USER WITH 2 OR MORE PROBS DUE TO COC'
   PRB3CIG = 'CIG USER WITH 3 OR MORE PROBS DUE TO CIG'
   PRB3ALC = 'ALC USER WITH 3 OR MORE PROBS DUE TO ALC'
   PRB3MRJ = 'MRJ USER WITH 3 OR MORE PROBS DUE TO MRJ'
   PRB3COC = 'COC USER WITH 3 OR MORE PROBS DUE TO COC'
   IRCDCIG = 'TRIED TO CUT DOWN CIG USE PST YR (L.I. C'
   IRCDALC = 'TRIED TO CUT DOWN ALC USE PST YR (L.I. C'
   IRCDMJ  = 'TRIED TO CUT DOWN MRJ USE PST YR (L.I. C'
   IRCDCOC = 'TRIED TO CUT DOWN COC USE PST YR (L.I. C'
   IREFCIG = 'NEED MORE CIG SAME EFFECT PST YR (L.I. E'
   IREFALC = 'NEED MORE ALC SAME EFFECT PST YR (L.I. E'
   IREFMJ  = 'NEED MORE MRJ SAME EFFECT PST YR (L.I. E'
   IREFCOC = 'NEED MORE COC SAME EFFECT PST YR (L.I. E'
   IRUDCIG = 'USED CIG DAILY 2+ WEEKS PST YR (L.I. UDA'
   IRUDALC = 'USED ALC DAILY 2+ WEEKS PST YR (L.I. UDA'
   IRUDMJ  = 'USED MRJ DAILY 2+ WEEKS PST YR (L.I. UDA'
   IRUDCOC = 'USED COC DAILY 2+ WEEKS PST YR (L.I. UDA'
   IRDPCIG = 'FELT DEPENDENT ON CIG PST YR (L.I. DEPCI'
   IRDPALC = 'FELT DEPENDENT ON ALC PST YR (L.I. DEPAL'
   IRDPMJ  = 'FELT DEPENDENT ON MRJ PST YR (L.I. DEPMJ'
   IRDPCOC = 'FELT DEPENDENT ON COC PST YR (L.I. DEPCO'
   IRWSCIG = 'FELT SICK WHEN CUT DOWN CIG PST YR (L.I.'
   IRWSALC = 'FELT SICK WHEN CUT DOWN ALC PST YR (L.I.'
   IRWSMJ  = 'FELT SICK WHEN CUT DOWN MRJ PST YR (L.I.'
   IRWSCOC = 'FELT SICK WHEN CUT DOWN COC PST YR (L.I.'
   AVCIG3  = '# CIG. SMOKED PER DAY LAST 30'
   ALCPROBS= 'ANY PROBS DUE TO ALCOHOL'
   MJPROBS = 'ANY PROBS DUE TO MARIJUANA'
   COCPROBS= 'ANY PROBS DUE TO COCAINE'
   CIGPROBS= 'ANY PROBS DUE TO CIGARETTES'
   INTMONTH= 'INTERVIEW MONTH'
   QC06    = 'MOST RECENT TIME SMOKED A CIGARETTE (UNE'
   QC09    = 'MOST RECENT TIME USED SMOKELESS TOBACCO'
   AL02    = 'MOST RECENT ALCOHOL DRINK (UNEDITED)'
   SE04    = 'MOST RECENT USE OF SEDATIVE-NONMED REASN'
   TR04    = 'MOST RECENT USE OF TRANQ-NONMED REASON ('
   ST04    = 'MOST RECENT USE OF STIMULANT-NONMED REAS'
   ST07    = 'MOST RECENT AMPHETAMINE USE W/NEEDLE (UN'
   AN04    = 'MOST RECENT ANALGESIC USE-NONMED REASON'
   MJ04    = 'MOST RECENT TIME USED MARIJUANA/HASH (UN'
   IN04    = 'MOST RECENT TIME USED INHALANT (UNEDITED'
   CC04    = 'MOST RECENT TIME USED COCAINE (ANY FORM)'
   CC10    = 'MOST RECENT USE COCAINE W/NEEDLE PAST YR'
   CC11    = 'MOST RECENT TIME USED CRACK (UNEDITED)'
   LS05    = 'MOST RECENT TIME USED HALLUCINOGEN (UNED'
   LS08    = 'MOST RECENT TIME USED PCP (UNEDITED)'
   HE04    = 'MOST RECENT TIME USED HEROIN (UNEDITED)'
   HE07    = 'MOST RECENT TIME USED HEROIN W/NEEDLE (U'
   DR08    = 'MOST RECENT TIME USED DRUG-NONMED REASON'
   SP04    = 'MOST RECENT TIME USED ICE (UNEDITED)'
   SP08    = 'MOST RECENT TIME USED ANABOLIC STEROIDS'
   OTHDOSP1= 'TROUBLE W/POLICE PAST 12 MOS.-1ST OTHER'
   OTHDOSP2= 'TROUBLE W/POLICE PAST 12 MOS.-2ND OTHER'
   COCWAY2 = 'OTHER WAY COCAINE USED PAST 12 MONTHS'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CWEOCC2 >= 994) THEN CWEOCC2 = .;
   IF (ROCCUP2 >= 994) THEN ROCCUP2 = .;
   IF (BUSINES2 >= 990) THEN BUSINES2 = .;
   IF (CWEBUS2 >= 990) THEN CWEBUS2 = .;
   IF (SNUFREC >= 81) THEN SNUFREC = .;
   IF (ALCREC >= 81) THEN ALCREC = .;
   IF (SEDREC >= 81) THEN SEDREC = .;
   IF (TRANREC >= 81) THEN TRANREC = .;
   IF (STIMREC >= 81) THEN STIMREC = .;
   IF (STNDLREC >= 81) THEN STNDLREC = .;
   IF (ANALREC >= 81) THEN ANALREC = .;
   IF (MJREC >= 81) THEN MJREC = .;
   IF (INHREC >= 81) THEN INHREC = .;
   IF (CRAKREC >= 81) THEN CRAKREC = .;
   IF (COCREC >= 81) THEN COCREC = .;
   IF (CONDLREC >= 81) THEN CONDLREC = .;
   IF (PCPREC >= 81) THEN PCPREC = .;
   IF (HALLREC >= 81) THEN HALLREC = .;
   IF (HERREC >= 81) THEN HERREC = .;
   IF (HRNDLREC >= 81) THEN HRNDLREC = .;
   IF (GNNDLREC >= 81) THEN GNNDLREC = .;
   IF (ICEREC >= 81) THEN ICEREC = .;
   IF (STERREC >= 81) THEN STERREC = .;
   IF (ALCSED >= 81) THEN ALCSED = .;
   IF (ALCTRAN >= 81) THEN ALCTRAN = .;
   IF (ALCSTM >= 81) THEN ALCSTM = .;
   IF (ALCANAL >= 81) THEN ALCANAL = .;
   IF (ALCMJ >= 81) THEN ALCMJ = .;
   IF (ALCINH >= 81) THEN ALCINH = .;
   IF (ALCCOC >= 81) THEN ALCCOC = .;
   IF (ALCHAL >= 81) THEN ALCHAL = .;
   IF (ALCOPT >= 81) THEN ALCOPT = .;
   IF (ALCNONE >= 81) THEN ALCNONE = .;
   IF (CIGTRY >= 185) THEN CIGTRY = .;
   IF (CIGAGE >= 181) THEN CIGAGE = .;
   IF (CIGYRS >= 181) THEN CIGYRS = .;
   IF (ALCTRY >= 181) THEN ALCTRY = .;
   IF (ALCAGE >= 181) THEN ALCAGE = .;
   IF (SEDAGE >= 181) THEN SEDAGE = .;
   IF (TRANAGE >= 181) THEN TRANAGE = .;
   IF (STIMAGE >= 181) THEN STIMAGE = .;
   IF (ANALAGE >= 181) THEN ANALAGE = .;
   IF (MJOPP >= 181) THEN MJOPP = .;
   IF (MJAGE >= 181) THEN MJAGE = .;
   IF (INHAGE >= 181) THEN INHAGE = .;
   IF (COCOPP >= 181) THEN COCOPP = .;
   IF (COCAGE >= 181) THEN COCAGE = .;
   IF (HALLOPP >= 181) THEN HALLOPP = .;
   IF (HALLAGE >= 181) THEN HALLAGE = .;
   IF (HEROPP >= 181) THEN HEROPP = .;
   IF (HERAGE >= 181) THEN HERAGE = .;
   IF (STEROPP >= 181) THEN STEROPP = .;
   IF (STERAGE >= 181) THEN STERAGE = .;
   IF (OTHTOB >= 81) THEN OTHTOB = .;
   IF (ALCPAT >= 81) THEN ALCPAT = .;
   IF (SEDYRFRQ >= 81) THEN SEDYRFRQ = .;
   IF (TRNYRFRQ >= 81) THEN TRNYRFRQ = .;
   IF (STMYRFRQ >= 81) THEN STMYRFRQ = .;
   IF (ANLYRFRQ >= 81) THEN ANLYRFRQ = .;
   IF (MJYRFREQ >= 81) THEN MJYRFREQ = .;
   IF (INHYRFRQ >= 81) THEN INHYRFRQ = .;
   IF (COCYRFRQ >= 81) THEN COCYRFRQ = .;
   IF (HALYRFRQ >= 81) THEN HALYRFRQ = .;
   IF (CIG5PK >= 81) THEN CIG5PK = .;
   IF (PACKS >= 81) THEN PACKS = .;
   IF (AVCIG >= 81) THEN AVCIG = .;
   IF (CIGTIME >= 9981) THEN CIGTIME = .;
   IF (ALCDAYS >= 81) THEN ALCDAYS = .;
   IF (NODR30A >= 81) THEN NODR30A = .;
   IF (DR5DAY >= 81) THEN DR5DAY = .;
   IF (MODR30A >= 81) THEN MODR30A = .;
   IF (MODR30DY >= 81) THEN MODR30DY = .;
   IF (DRUNKYR >= 81) THEN DRUNKYR = .;
   IF (ALCBEER >= 81) THEN ALCBEER = .;
   IF (ALCWINE >= 81) THEN ALCWINE = .;
   IF (ALCLIQR >= 81) THEN ALCLIQR = .;
   IF (ALCVARY >= 81) THEN ALCVARY = .;
   IF (NOBOOZYR >= 81) THEN NOBOOZYR = .;
   IF (ALCAGGR >= 81) THEN ALCAGGR = .;
   IF (ALCARGUM >= 81) THEN ALCARGUM = .;
   IF (ALCABSNT >= 81) THEN ALCABSNT = .;
   IF (ALCHIGH >= 81) THEN ALCHIGH = .;
   IF (ALCJOB >= 81) THEN ALCJOB = .;
   IF (ALCMATCD >= 81) THEN ALCMATCD = .;
   IF (ALCRELCD >= 81) THEN ALCRELCD = .;
   IF (ALCFRDCD >= 81) THEN ALCFRDCD = .;
   IF (ALCTOSS >= 81) THEN ALCTOSS = .;
   IF (ALCHOLIC >= 81) THEN ALCHOLIC = .;
   IF (ALCDRUNK >= 81) THEN ALCDRUNK = .;
   IF (ALCINTOX >= 81) THEN ALCINTOX = .;
   IF (ALCREM >= 81) THEN ALCREM = .;
   IF (ALCQUICK >= 81) THEN ALCQUICK = .;
   IF (ALCMORN >= 81) THEN ALCMORN = .;
   IF (ALCSHOOK >= 81) THEN ALCSHOOK = .;
   IF (ALCALONE >= 81) THEN ALCALONE = .;
   IF (ALCBRKPM >= 81) THEN ALCBRKPM = .;
   IF (BUTISOL >= 81) THEN BUTISOL = .;
   IF (BUTICAPS >= 81) THEN BUTICAPS = .;
   IF (AMYTAL >= 81) THEN AMYTAL = .;
   IF (MEBARAL >= 81) THEN MEBARAL = .;
   IF (PLACIDYL >= 81) THEN PLACIDYL = .;
   IF (DORIDEN >= 81) THEN DORIDEN = .;
   IF (NOLUDAR >= 81) THEN NOLUDAR = .;
   IF (NEMBUTAL >= 81) THEN NEMBUTAL = .;
   IF (SECONAL >= 81) THEN SECONAL = .;
   IF (TUINAL >= 81) THEN TUINAL = .;
   IF (DALMANE >= 81) THEN DALMANE = .;
   IF (RESTORIL >= 81) THEN RESTORIL = .;
   IF (HALCION >= 81) THEN HALCION = .;
   IF (AMOBARB >= 81) THEN AMOBARB = .;
   IF (PHENOBAR >= 81) THEN PHENOBAR = .;
   IF (METHAQ >= 81) THEN METHAQ = .;
   IF (CHHYD >= 81) THEN CHHYD = .;
   IF (PENTOB >= 81) THEN PENTOB = .;
   IF (SECOB >= 81) THEN SECOB = .;
   IF (SEDNOSP >= 81) THEN SEDNOSP = .;
   IF (SEDNEWA >= 981) THEN SEDNEWA = .;
   IF (SEDNEWB >= 981) THEN SEDNEWB = .;
   IF (SEDNEWC >= 991) THEN SEDNEWC = .;
   IF (SEDNEWD >= 991) THEN SEDNEWD = .;
   IF (SEDNEWE >= 181) THEN SEDNEWE = .;
   IF (SEDDKNAM >= 81) THEN SEDDKNAM = .;
   IF (NOSEDAT >= 81) THEN NOSEDAT = .;
   IF (SEDTOT >= 81) THEN SEDTOT = .;
   IF (VALIUM >= 81) THEN VALIUM = .;
   IF (LIBRIUM >= 81) THEN LIBRIUM = .;
   IF (LIMBTROL >= 81) THEN LIMBTROL = .;
   IF (MENRIUM >= 81) THEN MENRIUM = .;
   IF (SERAX >= 81) THEN SERAX = .;
   IF (TRANXENE >= 81) THEN TRANXENE = .;
   IF (ATIVAN >= 81) THEN ATIVAN = .;
   IF (CENTRAX >= 81) THEN CENTRAX = .;
   IF (XANAX >= 81) THEN XANAX = .;
   IF (PAXIPAM >= 81) THEN PAXIPAM = .;
   IF (BUSPAR >= 81) THEN BUSPAR = .;
   IF (MILTOWN >= 81) THEN MILTOWN = .;
   IF (EQUANIL >= 81) THEN EQUANIL = .;
   IF (DEPROL >= 81) THEN DEPROL = .;
   IF (VISTAR >= 81) THEN VISTAR = .;
   IF (ATARAX >= 81) THEN ATARAX = .;
   IF (DURRAX >= 81) THEN DURRAX = .;
   IF (DIAZEPAM >= 81) THEN DIAZEPAM = .;
   IF (SKLY >= 81) THEN SKLY = .;
   IF (MEPROB >= 81) THEN MEPROB = .;
   IF (TRNOSP >= 81) THEN TRNOSP = .;
   IF (TRNEWA >= 991) THEN TRNEWA = .;
   IF (TRNEWB >= 181) THEN TRNEWB = .;
   IF (TRNEWC >= 181) THEN TRNEWC = .;
   IF (TRNEWD >= 181) THEN TRNEWD = .;
   IF (TRNEWE >= 181) THEN TRNEWE = .;
   IF (TRDKNAM >= 81) THEN TRDKNAM = .;
   IF (NOTRANQ >= 81) THEN NOTRANQ = .;
   IF (TRANTOT >= 81) THEN TRANTOT = .;
   IF (DEXED >= 81) THEN DEXED = .;
   IF (DEXAMYL >= 81) THEN DEXAMYL = .;
   IF (ESKAT >= 81) THEN ESKAT = .;
   IF (BENZ >= 81) THEN BENZ = .;
   IF (BIPHET >= 81) THEN BIPHET = .;
   IF (DESOXYN >= 81) THEN DESOXYN = .;
   IF (TENUATE >= 81) THEN TENUATE = .;
   IF (TEPANIL >= 81) THEN TEPANIL = .;
   IF (DIDREX >= 81) THEN DIDREX = .;
   IF (PLEGINE >= 81) THEN PLEGINE = .;
   IF (PRELUDIN >= 81) THEN PRELUDIN = .;
   IF (IONAMIN >= 81) THEN IONAMIN = .;
   IF (FASTIN >= 81) THEN FASTIN = .;
   IF (PONDIMIN >= 81) THEN PONDIMIN = .;
   IF (VORANIL >= 81) THEN VORANIL = .;
   IF (SANOREX >= 81) THEN SANOREX = .;
   IF (MAZANOR >= 81) THEN MAZANOR = .;
   IF (RITALIN >= 81) THEN RITALIN = .;
   IF (CYLERT >= 81) THEN CYLERT = .;
   IF (DETAMP >= 81) THEN DETAMP = .;
   IF (METHI >= 81) THEN METHI = .;
   IF (METHAMP >= 81) THEN METHAMP = .;
   IF (OBLA >= 81) THEN OBLA = .;
   IF (STIMNOSP >= 81) THEN STIMNOSP = .;
   IF (STIMNEWA >= 981) THEN STIMNEWA = .;
   IF (STIMNEWB >= 991) THEN STIMNEWB = .;
   IF (STIMNEWC >= 991) THEN STIMNEWC = .;
   IF (STIMNEWD >= 181) THEN STIMNEWD = .;
   IF (STIMNEWE >= 181) THEN STIMNEWE = .;
   IF (STMDKNAM >= 81) THEN STMDKNAM = .;
   IF (NOSTIMS >= 81) THEN NOSTIMS = .;
   IF (STIMTOT >= 81) THEN STIMTOT = .;
   IF (STNEEDLE >= 81) THEN STNEEDLE = .;
   IF (DARVON >= 81) THEN DARVON = .;
   IF (DOLENE >= 81) THEN DOLENE = .;
   IF (SK65A >= 81) THEN SK65A = .;
   IF (WYGESIC >= 81) THEN WYGESIC = .;
   IF (LEVODRO >= 81) THEN LEVODRO = .;
   IF (PERCODAN >= 81) THEN PERCODAN = .;
   IF (DEMEROL >= 81) THEN DEMEROL = .;
   IF (DILAUD >= 81) THEN DILAUD = .;
   IF (TYLCOD >= 81) THEN TYLCOD = .;
   IF (PHENCOD >= 81) THEN PHENCOD = .;
   IF (TALWIN >= 81) THEN TALWIN = .;
   IF (TALWINNX >= 81) THEN TALWINNX = .;
   IF (TALACEN >= 81) THEN TALACEN = .;
   IF (PROPOXY >= 81) THEN PROPOXY = .;
   IF (CODEINE >= 81) THEN CODEINE = .;
   IF (ANILERID >= 81) THEN ANILERID = .;
   IF (MORPHINE >= 81) THEN MORPHINE = .;
   IF (METHDON >= 81) THEN METHDON = .;
   IF (STADOL >= 81) THEN STADOL = .;
   IF (ANLNOSP >= 81) THEN ANLNOSP = .;
   IF (ANALNEWA >= 981) THEN ANALNEWA = .;
   IF (ANALNEWB >= 991) THEN ANALNEWB = .;
   IF (ANALNEWC >= 181) THEN ANALNEWC = .;
   IF (ANALNEWD >= 181) THEN ANALNEWD = .;
   IF (ANALNEWE >= 181) THEN ANALNEWE = .;
   IF (ANLDKNAM >= 81) THEN ANLDKNAM = .;
   IF (ANALNONE >= 81) THEN ANALNONE = .;
   IF (ANALTOT >= 81) THEN ANALTOT = .;
   IF (MJTOT >= 81) THEN MJTOT = .;
   IF (MJDAY30A >= 81) THEN MJDAY30A = .;
   IF (MJAV30A >= 81) THEN MJAV30A = .;
   IF (MJAV30B >= 81) THEN MJAV30B = .;
   IF (MJAMT30A >= 81) THEN MJAMT30A = .;
   IF (MJJOINT >= 81) THEN MJJOINT = .;
   IF (MJPIPE >= 81) THEN MJPIPE = .;
   IF (MJBAKE >= 81) THEN MJBAKE = .;
   IF (MJCHEW >= 81) THEN MJCHEW = .;
   IF (MJWAY >= 81) THEN MJWAY = .;
   IF (GAS >= 81) THEN GAS = .;
   IF (LGAS >= 81) THEN LGAS = .;
   IF (SPPAINT >= 81) THEN SPPAINT = .;
   IF (AEROS >= 81) THEN AEROS = .;
   IF (GLUE >= 81) THEN GLUE = .;
   IF (SOLVENT >= 81) THEN SOLVENT = .;
   IF (AMYLNIT >= 81) THEN AMYLNIT = .;
   IF (ETHER >= 81) THEN ETHER = .;
   IF (NITOXID >= 81) THEN NITOXID = .;
   IF (CLEFLU >= 81) THEN CLEFLU = .;
   IF (INHNOSP >= 81) THEN INHNOSP = .;
   IF (INHDKNAM >= 81) THEN INHDKNAM = .;
   IF (INHTOT >= 81) THEN INHTOT = .;
   IF (GAS30A >= 81) THEN GAS30A = .;
   IF (LGAS30A >= 81) THEN LGAS30A = .;
   IF (SPPAN30A >= 81) THEN SPPAN30A = .;
   IF (AEROS30A >= 81) THEN AEROS30A = .;
   IF (GLUE30A >= 81) THEN GLUE30A = .;
   IF (SOLVN30A >= 81) THEN SOLVN30A = .;
   IF (AMLNT30A >= 81) THEN AMLNT30A = .;
   IF (ETHER30A >= 81) THEN ETHER30A = .;
   IF (NOX30A >= 81) THEN NOX30A = .;
   IF (CLFL30A >= 81) THEN CLFL30A = .;
   IF (IN30NOSP >= 81) THEN IN30NOSP = .;
   IF (INH30NO >= 81) THEN INH30NO = .;
   IF (INHDY30A >= 81) THEN INHDY30A = .;
   IF (INHEFF >= 81) THEN INHEFF = .;
   IF (INHPO >= 81) THEN INHPO = .;
   IF (INHNEWA >= 981) THEN INHNEWA = .;
   IF (INHNEWB >= 981) THEN INHNEWB = .;
   IF (INHNEWC >= 181) THEN INHNEWC = .;
   IF (INHNEWD >= 181) THEN INHNEWD = .;
   IF (INHNEWE >= 181) THEN INHNEWE = .;
   IF (INNEW30A >= 981) THEN INNEW30A = .;
   IF (INNEW30B >= 981) THEN INNEW30B = .;
   IF (INNEW30C >= 181) THEN INNEW30C = .;
   IF (INNEW30D >= 181) THEN INNEW30D = .;
   IF (INNEW30E >= 181) THEN INNEW30E = .;
   IF (COCTOT >= 81) THEN COCTOT = .;
   IF (COCUS30A >= 81) THEN COCUS30A = .;
   IF (CRKAM30A >= 181) THEN CRKAM30A = .;
   IF (CRAKBUCK >= 9981) THEN CRAKBUCK = .;
   IF (COCAM30A >= 81) THEN COCAM30A = .;
   IF (COCBUCK >= 9981) THEN COCBUCK = .;
   IF (COCSNIFF >= 81) THEN COCSNIFF = .;
   IF (COCSWAL >= 81) THEN COCSWAL = .;
   IF (COCIV >= 81) THEN COCIV = .;
   IF (FREEBASE >= 81) THEN FREEBASE = .;
   IF (COCWAY >= 81) THEN COCWAY = .;
   IF (LSD >= 81) THEN LSD = .;
   IF (PEYOTE >= 81) THEN PEYOTE = .;
   IF (MESC >= 81) THEN MESC = .;
   IF (PSILCY >= 81) THEN PSILCY = .;
   IF (PCP >= 81) THEN PCP = .;
   IF (ECSTASY >= 81) THEN ECSTASY = .;
   IF (HALNOSP >= 81) THEN HALNOSP = .;
   IF (HALNEWA >= 981) THEN HALNEWA = .;
   IF (HALNEWB >= 981) THEN HALNEWB = .;
   IF (HALNEWC >= 181) THEN HALNEWC = .;
   IF (HALNEWD >= 181) THEN HALNEWD = .;
   IF (HALNEWE >= 181) THEN HALNEWE = .;
   IF (HALDKNAM >= 81) THEN HALDKNAM = .;
   IF (HALLTOT >= 81) THEN HALLTOT = .;
   IF (HAL30USE >= 81) THEN HAL30USE = .;
   IF (HERTOT >= 81) THEN HERTOT = .;
   IF (HER30USE >= 81) THEN HER30USE = .;
   IF (HERNEEDL >= 81) THEN HERNEEDL = .;
   IF (CDCIG >= 81) THEN CDCIG = .;
   IF (CDALC >= 81) THEN CDALC = .;
   IF (CDSED >= 81) THEN CDSED = .;
   IF (CDTRAN >= 81) THEN CDTRAN = .;
   IF (CDSTM >= 81) THEN CDSTM = .;
   IF (CDANAL >= 81) THEN CDANAL = .;
   IF (CDMJ >= 81) THEN CDMJ = .;
   IF (CDINH >= 81) THEN CDINH = .;
   IF (CDCOC >= 81) THEN CDCOC = .;
   IF (CDHALL >= 81) THEN CDHALL = .;
   IF (CDHER >= 81) THEN CDHER = .;
   IF (CDOTHOP >= 81) THEN CDOTHOP = .;
   IF (CDNONE >= 81) THEN CDNONE = .;
   IF (UCDCIG >= 81) THEN UCDCIG = .;
   IF (UCDALC >= 81) THEN UCDALC = .;
   IF (UCDSED >= 81) THEN UCDSED = .;
   IF (UCDTRAN >= 81) THEN UCDTRAN = .;
   IF (UCDSTM >= 81) THEN UCDSTM = .;
   IF (UCDANAL >= 81) THEN UCDANAL = .;
   IF (UCDMJ >= 81) THEN UCDMJ = .;
   IF (UCDINH >= 81) THEN UCDINH = .;
   IF (UCDCOC >= 81) THEN UCDCOC = .;
   IF (UCDHALL >= 81) THEN UCDHALL = .;
   IF (UCDHER >= 81) THEN UCDHER = .;
   IF (UCDOTHOP >= 81) THEN UCDOTHOP = .;
   IF (UCDNONE >= 81) THEN UCDNONE = .;
   IF (EFFCIG >= 81) THEN EFFCIG = .;
   IF (EFFALC >= 81) THEN EFFALC = .;
   IF (EFFSED >= 81) THEN EFFSED = .;
   IF (EFFTRAN >= 81) THEN EFFTRAN = .;
   IF (EFFSTM >= 81) THEN EFFSTM = .;
   IF (EFFANAL >= 81) THEN EFFANAL = .;
   IF (EFFMJ >= 81) THEN EFFMJ = .;
   IF (EFFINH >= 81) THEN EFFINH = .;
   IF (EFFCOC >= 81) THEN EFFCOC = .;
   IF (EFFHALL >= 81) THEN EFFHALL = .;
   IF (EFFHER >= 81) THEN EFFHER = .;
   IF (EFFOTHOP >= 81) THEN EFFOTHOP = .;
   IF (EFFNONE >= 81) THEN EFFNONE = .;
   IF (UDAYCIG >= 81) THEN UDAYCIG = .;
   IF (UDAYALC >= 81) THEN UDAYALC = .;
   IF (UDAYSED >= 81) THEN UDAYSED = .;
   IF (UDAYTRAN >= 81) THEN UDAYTRAN = .;
   IF (UDAYSTM >= 81) THEN UDAYSTM = .;
   IF (UDAYANAL >= 81) THEN UDAYANAL = .;
   IF (UDAYMJ >= 81) THEN UDAYMJ = .;
   IF (UDAYINH >= 81) THEN UDAYINH = .;
   IF (UDAYCOC >= 81) THEN UDAYCOC = .;
   IF (UDAYHALL >= 81) THEN UDAYHALL = .;
   IF (UDAYHER >= 81) THEN UDAYHER = .;
   IF (UDAYOTH >= 81) THEN UDAYOTH = .;
   IF (UDAYNONE >= 81) THEN UDAYNONE = .;
   IF (DEPCIG >= 81) THEN DEPCIG = .;
   IF (DEPALC >= 81) THEN DEPALC = .;
   IF (DEPSED >= 81) THEN DEPSED = .;
   IF (DEPTRAN >= 81) THEN DEPTRAN = .;
   IF (DEPSTM >= 81) THEN DEPSTM = .;
   IF (DEPANAL >= 81) THEN DEPANAL = .;
   IF (DEPMJ >= 81) THEN DEPMJ = .;
   IF (DEPINH >= 81) THEN DEPINH = .;
   IF (DEPCOC >= 81) THEN DEPCOC = .;
   IF (DEPHALL >= 81) THEN DEPHALL = .;
   IF (DEPHER >= 81) THEN DEPHER = .;
   IF (DEPOTHOP >= 81) THEN DEPOTHOP = .;
   IF (DEPNONE >= 81) THEN DEPNONE = .;
   IF (WSCIG >= 81) THEN WSCIG = .;
   IF (WSALC >= 81) THEN WSALC = .;
   IF (WSSED >= 81) THEN WSSED = .;
   IF (WSTRAN >= 81) THEN WSTRAN = .;
   IF (WSSTM >= 81) THEN WSSTM = .;
   IF (WSANAL >= 81) THEN WSANAL = .;
   IF (WSMJ >= 81) THEN WSMJ = .;
   IF (WSINH >= 81) THEN WSINH = .;
   IF (WSCOC >= 81) THEN WSCOC = .;
   IF (WSHALL >= 13) THEN WSHALL = .;
   IF (WSHER >= 81) THEN WSHER = .;
   IF (WSOTHOP >= 81) THEN WSOTHOP = .;
   IF (WSNONE >= 81) THEN WSNONE = .;
   IF (GNNDLLIF >= 81) THEN GNNDLLIF = .;
   IF (GNNDLSED >= 81) THEN GNNDLSED = .;
   IF (GNNDLTRA >= 81) THEN GNNDLTRA = .;
   IF (GNNDLSTM >= 81) THEN GNNDLSTM = .;
   IF (GNNDLANL >= 81) THEN GNNDLANL = .;
   IF (GNNDLMJ >= 81) THEN GNNDLMJ = .;
   IF (GNNDLINH >= 81) THEN GNNDLINH = .;
   IF (GNNDLCOC >= 81) THEN GNNDLCOC = .;
   IF (GNNDLHAL >= 81) THEN GNNDLHAL = .;
   IF (GNNDLHER >= 81) THEN GNNDLHER = .;
   IF (GNNDLOPT >= 81) THEN GNNDLOPT = .;
   IF (GNNDLNON >= 81) THEN GNNDLNON = .;
   IF (GNNDLSHR >= 81) THEN GNNDLSHR = .;
   IF (DRUGTEST >= 81) THEN DRUGTEST = .;
   IF (TESTPOS >= 81) THEN TESTPOS = .;
   IF (ICELIFE >= 81) THEN ICELIFE = .;
   IF (STERTOT >= 81) THEN STERTOT = .;
   IF (BOOKED >= 81) THEN BOOKED = .;
   IF (NOBOOKYR >= 181) THEN NOBOOKYR = .;
   IF (BKLARCNY >= 81) THEN BKLARCNY = .;
   IF (BKBURGL >= 81) THEN BKBURGL = .;
   IF (BKAGASLT >= 81) THEN BKAGASLT = .;
   IF (BKSMASLT >= 81) THEN BKSMASLT = .;
   IF (BKMVTHFT >= 81) THEN BKMVTHFT = .;
   IF (BKROB >= 81) THEN BKROB = .;
   IF (BKRAPE >= 81) THEN BKRAPE = .;
   IF (BKMURDER >= 81) THEN BKMURDER = .;
   IF (BKARSON >= 81) THEN BKARSON = .;
   IF (BKDRVINF >= 81) THEN BKDRVINF = .;
   IF (BKDRUNK >= 81) THEN BKDRUNK = .;
   IF (BKDRUG >= 81) THEN BKDRUG = .;
   IF (BKPROS >= 81) THEN BKPROS = .;
   IF (BKVANDAL >= 81) THEN BKVANDAL = .;
   IF (BKOTHOFF >= 81) THEN BKOTHOFF = .;
   IF (NOTBKED >= 81) THEN NOTBKED = .;
   IF (PROBATON >= 81) THEN PROBATON = .;
   IF (PAROLE >= 81) THEN PAROLE = .;
   IF (STRSTEAL >= 81) THEN STRSTEAL = .;
   IF (OTHSTEAL >= 81) THEN OTHSTEAL = .;
   IF (DAMAGE >= 81) THEN DAMAGE = .;
   IF (CARSTEAL >= 81) THEN CARSTEAL = .;
   IF (FORCEMON >= 81) THEN FORCEMON = .;
   IF (BREAKIN >= 81) THEN BREAKIN = .;
   IF (PHYFIGHT >= 81) THEN PHYFIGHT = .;
   IF (HURTBAD >= 81) THEN HURTBAD = .;
   IF (GUNMONEY >= 81) THEN GUNMONEY = .;
   IF (DRUNKDRV >= 81) THEN DRUNKDRV = .;
   IF (SOLDDRUG >= 81) THEN SOLDDRUG = .;
   IF (OTHDOING >= 81) THEN OTHDOING = .;
   IF (SPNEWA >= 985) THEN SPNEWA = .;
   IF (SPNEWB >= 997) THEN SPNEWB = .;
   IF (SPNEWC >= 997) THEN SPNEWC = .;
   IF (SPNEWD >= 997) THEN SPNEWD = .;
   IF (SPNEWE >= 181) THEN SPNEWE = .;
   IF (AS13NONE >= 81) THEN AS13NONE = .;
   IF (DRDEPRSS >= 81) THEN DRDEPRSS = .;
   IF (DEPDRG1A >= 989) THEN DEPDRG1A = .;
   IF (DEPDRG2A >= 994) THEN DEPDRG2A = .;
   IF (DEPDRG3A >= 994) THEN DEPDRG3A = .;
   IF (DEPDRG4A >= 994) THEN DEPDRG4A = .;
   IF (DEPDRG5A >= 181) THEN DEPDRG5A = .;
   IF (DRARGUM >= 81) THEN DRARGUM = .;
   IF (ARGDRG1A >= 989) THEN ARGDRG1A = .;
   IF (ARGDRG2A >= 985) THEN ARGDRG2A = .;
   IF (ARGDRG3A >= 994) THEN ARGDRG3A = .;
   IF (ARGDRG4A >= 994) THEN ARGDRG4A = .;
   IF (ARGDRG5A >= 994) THEN ARGDRG5A = .;
   IF (DRALONE >= 81) THEN DRALONE = .;
   IF (ALNDRG1A >= 989) THEN ALNDRG1A = .;
   IF (ALNDRG2A >= 994) THEN ALNDRG2A = .;
   IF (ALNDRG3A >= 994) THEN ALNDRG3A = .;
   IF (ALNDRG4A >= 994) THEN ALNDRG4A = .;
   IF (ALNDRG5A >= 994) THEN ALNDRG5A = .;
   IF (DRANX >= 81) THEN DRANX = .;
   IF (ANXDRG1A >= 989) THEN ANXDRG1A = .;
   IF (ANXDRG2A >= 994) THEN ANXDRG2A = .;
   IF (ANXDRG3A >= 994) THEN ANXDRG3A = .;
   IF (ANXDRG4A >= 994) THEN ANXDRG4A = .;
   IF (ANXDRG5A >= 994) THEN ANXDRG5A = .;
   IF (DRHEALTH >= 81) THEN DRHEALTH = .;
   IF (HLTDRG1A >= 989) THEN HLTDRG1A = .;
   IF (HLTDRG2A >= 994) THEN HLTDRG2A = .;
   IF (HLTDRG3A >= 994) THEN HLTDRG3A = .;
   IF (HLTDRG4A >= 994) THEN HLTDRG4A = .;
   IF (HLTDRG5A >= 994) THEN HLTDRG5A = .;
   IF (DRNTHINK >= 81) THEN DRNTHINK = .;
   IF (NTKDRG1A >= 989) THEN NTKDRG1A = .;
   IF (NTKDRG2A >= 994) THEN NTKDRG2A = .;
   IF (NTKDRG3A >= 994) THEN NTKDRG3A = .;
   IF (NTKDRG4A >= 994) THEN NTKDRG4A = .;
   IF (NTKDRG5A >= 994) THEN NTKDRG5A = .;
   IF (DRUPSET >= 81) THEN DRUPSET = .;
   IF (UPSDRG1A >= 989) THEN UPSDRG1A = .;
   IF (UPSDRG2A >= 994) THEN UPSDRG2A = .;
   IF (UPSDRG3A >= 994) THEN UPSDRG3A = .;
   IF (UPSDRG4A >= 994) THEN UPSDRG4A = .;
   IF (UPSDRG5A >= 994) THEN UPSDRG5A = .;
   IF (DRLSWORK >= 81) THEN DRLSWORK = .;
   IF (LSWDRG1A >= 989) THEN LSWDRG1A = .;
   IF (LSWDRG2A >= 994) THEN LSWDRG2A = .;
   IF (LSWDRG3A >= 994) THEN LSWDRG3A = .;
   IF (LSWDRG4A >= 994) THEN LSWDRG4A = .;
   IF (LSWDRG5A >= 994) THEN LSWDRG5A = .;
   IF (DRSUSPIC >= 81) THEN DRSUSPIC = .;
   IF (SSPDRG1A >= 989) THEN SSPDRG1A = .;
   IF (SSPDRG2A >= 994) THEN SSPDRG2A = .;
   IF (SSPDRG3A >= 994) THEN SSPDRG3A = .;
   IF (SSPDRG4A >= 994) THEN SSPDRG4A = .;
   IF (SSPDRG5A >= 994) THEN SSPDRG5A = .;
   IF (DRCOPE >= 81) THEN DRCOPE = .;
   IF (CPEDRG1A >= 989) THEN CPEDRG1A = .;
   IF (CPEDRG2A >= 994) THEN CPEDRG2A = .;
   IF (CPEDRG3A >= 994) THEN CPEDRG3A = .;
   IF (CPEDRG4A >= 994) THEN CPEDRG4A = .;
   IF (CPEDRG5A >= 994) THEN CPEDRG5A = .;
   IF (DREMGMED >= 81) THEN DREMGMED = .;
   IF (EMDRG1A >= 989) THEN EMDRG1A = .;
   IF (EMDRG2A >= 994) THEN EMDRG2A = .;
   IF (EMDRG3A >= 994) THEN EMDRG3A = .;
   IF (EMDRG4A >= 994) THEN EMDRG4A = .;
   IF (EMDRG5A >= 994) THEN EMDRG5A = .;
   IF (EMPDRUG >= 81) THEN EMPDRUG = .;
   IF (CIGHELP >= 81) THEN CIGHELP = .;
   IF (DRNKHELP >= 81) THEN DRNKHELP = .;
   IF (TRMTHELP >= 81) THEN TRMTHELP = .;
   IF (TRMTEMRG >= 81) THEN TRMTEMRG = .;
   IF (TRMTHOSP >= 81) THEN TRMTHOSP = .;
   IF (TRMTDOC >= 81) THEN TRMTDOC = .;
   IF (TRMTTRMT >= 81) THEN TRMTTRMT = .;
   IF (TRMTMHC >= 81) THEN TRMTMHC = .;
   IF (TRMTSHG >= 81) THEN TRMTSHG = .;
   IF (TRMTSOP >= 81) THEN TRMTSOP = .;
   IF (TRMTSP >= 81) THEN TRMTSP = .;
   IF (RSKPKCIG >= 81) THEN RSKPKCIG = .;
   IF (RSKTRYMJ >= 81) THEN RSKTRYMJ = .;
   IF (RSKMJOCC >= 81) THEN RSKMJOCC = .;
   IF (RSKMJREG >= 81) THEN RSKMJREG = .;
   IF (RKTRYPCP >= 81) THEN RKTRYPCP = .;
   IF (RKPCPREG >= 81) THEN RKPCPREG = .;
   IF (RKTRYHER >= 81) THEN RKTRYHER = .;
   IF (RKHERREG >= 81) THEN RKHERREG = .;
   IF (RKTRYCOC >= 81) THEN RKTRYCOC = .;
   IF (RKCOCOCC >= 81) THEN RKCOCOCC = .;
   IF (RKCOCREG >= 81) THEN RKCOCREG = .;
   IF (RKCRKOCC >= 81) THEN RKCRKOCC = .;
   IF (RKANSOCC >= 81) THEN RKANSOCC = .;
   IF (RKANSREG >= 81) THEN RKANSREG = .;
   IF (RK2DRINK >= 81) THEN RK2DRINK = .;
   IF (RK5DRINK >= 81) THEN RK5DRINK = .;
   IF (RSKBINGE >= 81) THEN RSKBINGE = .;
   IF (RSKDIFMJ >= 81) THEN RSKDIFMJ = .;
   IF (RKDIFLSD >= 81) THEN RKDIFLSD = .;
   IF (RKDIFPCP >= 81) THEN RKDIFPCP = .;
   IF (RKDIFCOC >= 81) THEN RKDIFCOC = .;
   IF (RKDIFHER >= 81) THEN RKDIFHER = .;
   IF (OVESTR >= 9981) THEN OVESTR = .;
   IF (CHICAGO >= 9) THEN CHICAGO = .;
   IF (DENVER >= 9) THEN DENVER = .;
   IF (DC >= 9) THEN DC = .;
   IF (LA >= 9) THEN LA = .;
   IF (MIAMI >= 9) THEN MIAMI = .;
   IF (NEWYORK >= 9) THEN NEWYORK = .;
   IF (IRAGE >= 181) THEN IRAGE = .;
   IF (IRMARIT >= 81) THEN IRMARIT = .;
   IF (IIMARIT >= 9) THEN IIMARIT = .;
   IF (IRWORKST >= 81) THEN IRWORKST = .;
   IF (IREDUC >= 81) THEN IREDUC = .;
   IF (IRHOGRP >= 81) THEN IRHOGRP = .;
   IF (IIHOGRP >= 9) THEN IIHOGRP = .;
   IF (IRSTMRC >= 9) THEN IRSTMRC = .;
   IF (IROTBRC >= 9) THEN IROTBRC = .;
   IF (IRTRNRC >= 9) THEN IRTRNRC = .;
   IF (IRSEDRC >= 9) THEN IRSEDRC = .;
   IF (IRMJRC >= 9) THEN IRMJRC = .;
   IF (IRMJFQ >= 10) THEN IRMJFQ = .;
   IF (IROTBFQ >= 9) THEN IROTBFQ = .;
   IF (IRSEDFQ >= 9) THEN IRSEDFQ = .;
   IF (IRSTMFQ >= 9) THEN IRSTMFQ = .;
   IF (IRTRNFQ >= 9) THEN IRTRNFQ = .;
   IF (IRHALRC >= 9) THEN IRHALRC = .;
   IF (IRCOCRC >= 9) THEN IRCOCRC = .;
   IF (IRINHRC >= 9) THEN IRINHRC = .;
   IF (IRANLRC >= 9) THEN IRANLRC = .;
   IF (IRALCRC >= 9) THEN IRALCRC = .;
   IF (IRALCFQ >= 9) THEN IRALCFQ = .;
   IF (IRANLFQ >= 9) THEN IRANLFQ = .;
   IF (IRCOCFQ >= 9) THEN IRCOCFQ = .;
   IF (IRHALFQ >= 9) THEN IRHALFQ = .;
   IF (IRINHFQ >= 9) THEN IRINHFQ = .;
   IF (IRPCPRC >= 9) THEN IRPCPRC = .;
   IF (IRCRKRC >= 9) THEN IRCRKRC = .;
   IF (IRSTRRC >= 9) THEN IRSTRRC = .;
   IF (IRICERC >= 9) THEN IRICERC = .;
   IF (IRHERRC >= 9) THEN IRHERRC = .;
   IF (NDL90REC >= 81) THEN NDL90REC = .;
   IF (IRCIGRC >= 9) THEN IRCIGRC = .;
   IF (AS3READ >= 81) THEN AS3READ = .;
   IF (AS4READ >= 81) THEN AS4READ = .;
   IF (AS5READ >= 81) THEN AS5READ = .;
   IF (AS7READ >= 81) THEN AS7READ = .;
   IF (INHQNC1 >= 81) THEN INHQNC1 = .;
   IF (INHQNC2 >= 81) THEN INHQNC2 = .;
   IF (INHQNC3 >= 81) THEN INHQNC3 = .;
   IF (INHQNC4 >= 81) THEN INHQNC4 = .;
   IF (INHQNC5 >= 81) THEN INHQNC5 = .;
   IF (INHQNC6 >= 81) THEN INHQNC6 = .;
   IF (INHQNC7 >= 81) THEN INHQNC7 = .;
   IF (INHQNC8 >= 81) THEN INHQNC8 = .;
   IF (INHQNC9 >= 81) THEN INHQNC9 = .;
   IF (INHQNC10 >= 81) THEN INHQNC10 = .;
   IF (INHANSY >= 81) THEN INHANSY = .;
   IF (AS9READ >= 81) THEN AS9READ = .;
   IF (AS10READ >= 81) THEN AS10READ = .;
   IF (AS11READ >= 81) THEN AS11READ = .;
   IF (AS12READ >= 81) THEN AS12READ = .;
   IF (AS13READ >= 81) THEN AS13READ = .;
   IF (AS15READ >= 81) THEN AS15READ = .;
   IF (HIGHBP >= 81) THEN HIGHBP = .;
   IF (BPMED >= 81) THEN BPMED = .;
   IF (WALKPAIN >= 81) THEN WALKPAIN = .;
   IF (TIMEPAIN >= 81) THEN TIMEPAIN = .;
   IF (UPSHOR >= 81) THEN UPSHOR = .;
   IF (ASTHMA >= 81) THEN ASTHMA = .;
   IF (TRPSYCH >= 81) THEN TRPSYCH = .;
   IF (HEART >= 81) THEN HEART = .;
   IF (FLU >= 81) THEN FLU = .;
   IF (ALLERG >= 81) THEN ALLERG = .;
   IF (HOSPYR >= 81) THEN HOSPYR = .;
   IF (SOREYR >= 81) THEN SOREYR = .;
   IF (RUNNYYR >= 81) THEN RUNNYYR = .;
   IF (COUGHYR >= 81) THEN COUGHYR = .;
   IF (PHLEGMYR >= 81) THEN PHLEGMYR = .;
   IF (HEALTHYR >= 81) THEN HEALTHYR = .;
   IF (MARITAL >= 81) THEN MARITAL = .;
   IF (NOMARR >= 81) THEN NOMARR = .;
   IF (WORKSTAT >= 81) THEN WORKSTAT = .;
   IF (PAYMO >= 81) THEN PAYMO = .;
   IF (PAYYR >= 181) THEN PAYYR = .;
   IF (SECTOR >= 17) THEN SECTOR = .;
   IF (NO5JOB >= 81) THEN NO5JOB = .;
   IF (WORKDAYS >= 81) THEN WORKDAYS = .;
   IF (WORKBLAH >= 81) THEN WORKBLAH = .;
   IF (CWE >= 85) THEN CWE = .;
   IF (FULLPART >= 81) THEN FULLPART = .;
   IF (CWESECTR >= 17) THEN CWESECTR = .;
   IF (EDUC >= 81) THEN EDUC = .;
   IF (GRADHS >= 81) THEN GRADHS = .;
   IF (DIPLOMA >= 81) THEN DIPLOMA = .;
   IF (ENROLLD >= 81) THEN ENROLLD = .;
   IF (SCHPLANS >= 81) THEN SCHPLANS = .;
   IF (STUDENT >= 81) THEN STUDENT = .;
   IF (SCHDAYS >= 81) THEN SCHDAYS = .;
   IF (SKIPPED >= 81) THEN SKIPPED = .;
   IF (ACCID >= 81) THEN ACCID = .;
   IF (MOVDAWAY >= 81) THEN MOVDAWAY = .;
   IF (DORM >= 81) THEN DORM = .;
   IF (MILBASE >= 81) THEN MILBASE = .;
   IF (HOSP >= 81) THEN HOSP = .;
   IF (OTHGPH >= 81) THEN OTHGPH = .;
   IF (OTHGPHSP >= 81) THEN OTHGPHSP = .;
   IF (SERVICE >= 81) THEN SERVICE = .;
   IF (MILSTAT >= 81) THEN MILSTAT = .;
   IF (TELNO >= 81) THEN TELNO = .;
   IF (MOVES >= 81) THEN MOVES = .;
   IF (EAP >= 81) THEN EAP = .;
   IF (UNDINT >= 81) THEN UNDINT = .;
   IF (COOPINT >= 81) THEN COOPINT = .;
   IF (PRIVACY >= 81) THEN PRIVACY = .;
   IF (PPRES >= 81) THEN PPRES = .;
   IF (SPRES >= 81) THEN SPRES = .;
   IF (PARPRES >= 81) THEN PARPRES = .;
   IF (OARPRES >= 81) THEN OARPRES = .;
   IF (OAPRES >= 81) THEN OAPRES = .;
   IF (CPRES >= 81) THEN CPRES = .;
   IF (OPRESNSP >= 81) THEN OPRESNSP = .;
   IF (OPRESSPA >= 81) THEN OPRESSPA = .;
   IF (WHOMARKD >= 81) THEN WHOMARKD = .;
   IF (ETIME >= 9900) THEN ETIME = .;
   IF (MOTHER >= 81) THEN MOTHER = .;
   IF (FATHER >= 81) THEN FATHER = .;
   IF (STEPMOM >= 81) THEN STEPMOM = .;
   IF (STEPDAD >= 81) THEN STEPDAD = .;
   IF (SPOUSE >= 81) THEN SPOUSE = .;
   IF (INLAW >= 81) THEN INLAW = .;
   IF (OWNCHILD >= 81) THEN OWNCHILD = .;
   IF (STEPCHLD >= 81) THEN STEPCHLD = .;
   IF (BROSIS >= 81) THEN BROSIS = .;
   IF (OTHREL >= 81) THEN OTHREL = .;
   IF (FRIENDS >= 81) THEN FRIENDS = .;
   IF (OTHERNON >= 81) THEN OTHERNON = .;
   IF (TOTPEOP >= 81) THEN TOTPEOP = .;
   IF (NOCHILD >= 81) THEN NOCHILD = .;
   IF (CIGREC >= 81) THEN CIGREC = .;
   IF (BTIME >= 9981) THEN BTIME = .;
   IF (BAP >= 81) THEN BAP = .;
   IF (LANGVER >= 81) THEN LANGVER = .;
   IF (ENCPSU >= 181) THEN ENCPSU = .;
   IF (ENCSEG >= 9981) THEN ENCSEG = .;
   IF (IRHOGRP2 >= 81) THEN IRHOGRP2 = .;
   IF (WORK >= 81) THEN WORK = .;
   IF (WAG1 >= 81) THEN WAG1 = .;
   IF (SOC1 >= 81) THEN SOC1 = .;
   IF (SSI1 >= 81) THEN SSI1 = .;
   IF (WEL1 >= 81) THEN WEL1 = .;
   IF (INT1 >= 81) THEN INT1 = .;
   IF (CHD1 >= 81) THEN CHD1 = .;
   IF (OTH1 >= 81) THEN OTH1 = .;
   IF (WAG2 >= 81) THEN WAG2 = .;
   IF (SOC2 >= 81) THEN SOC2 = .;
   IF (SSI2 >= 81) THEN SSI2 = .;
   IF (WEL2 >= 81) THEN WEL2 = .;
   IF (INT2 >= 81) THEN INT2 = .;
   IF (CHD2 >= 81) THEN CHD2 = .;
   IF (OTH2 >= 81) THEN OTH2 = .;
   IF (FOOD >= 81) THEN FOOD = .;
   IF (IRASOC1 >= 9981) THEN IRASOC1 = .;
   IF (IRASSI1 >= 9981) THEN IRASSI1 = .;
   IF (IRAWEL1 >= 9981) THEN IRAWEL1 = .;
   IF (IRAINT1 >= 9981) THEN IRAINT1 = .;
   IF (IRACHD1 >= 9981) THEN IRACHD1 = .;
   IF (IRAOTH1 >= 9981) THEN IRAOTH1 = .;
   IF (IRASOC2 >= 9981) THEN IRASOC2 = .;
   IF (IRASSI2 >= 9981) THEN IRASSI2 = .;
   IF (IRAWEL2 >= 9981) THEN IRAWEL2 = .;
   IF (IRAINT2 >= 9981) THEN IRAINT2 = .;
   IF (IRACHD2 >= 9981) THEN IRACHD2 = .;
   IF (JOB >= 81) THEN JOB = .;
   IF (HOURS >= 985) THEN HOURS = .;
   IF (WEEKS >= 81) THEN WEEKS = .;
   IF (PUB1 >= 81) THEN PUB1 = .;
   IF (AFDC1 >= 81) THEN AFDC1 = .;
   IF (PUB2 >= 81) THEN PUB2 = .;
   IF (AFDC2 >= 81) THEN AFDC2 = .;
   IF (FSTAMP >= 81) THEN FSTAMP = .;
   IF (PEOPFD >= 81) THEN PEOPFD = .;
   IF (INDCAT >= 81) THEN INDCAT = .;
   IF (TOTCAT >= 81) THEN TOTCAT = .;
   IF (PRVHLTIN >= 81) THEN PRVHLTIN = .;
   IF (METRO >= 9) THEN METRO = .;
   IF (PROXABLE >= 81) THEN PROXABLE = .;
   IF (PROXYREL >= 81) THEN PROXYREL = .;
   IF (PROXHOME >= 81) THEN PROXHOME = .;
   IF (PROXJOIN >= 81) THEN PROXJOIN = .;
   IF (MEDICARE >= 81) THEN MEDICARE = .;
   IF (MEDICAID >= 81) THEN MEDICAID = .;
   IF (CHAMPUS >= 81) THEN CHAMPUS = .;
   IF (OWNHLTIN >= 81) THEN OWNHLTIN = .;
   IF (GRPHLTIN >= 81) THEN GRPHLTIN = .;
   IF (HLTINALC >= 81) THEN HLTINALC = .;
   IF (HLTINDRG >= 81) THEN HLTINDRG = .;
   IF (HLTINMNT >= 81) THEN HLTINMNT = .;
   IF (WHOANSHI >= 81) THEN WHOANSHI = .;
   IF (WHOANSIN >= 81) THEN WHOANSIN = .;
   IF (NEEDLREC >= 81) THEN NEEDLREC = .;
   IF (HERREC92 >= 81) THEN HERREC92 = .;
   IF (IRHERC92 >= 9) THEN IRHERC92 = .;
   IF (VESTR >= 9981) THEN VESTR = .;
   IF (BIRMON >= 81) THEN BIRMON = .;
   IF (BIRYEAR >= 9981) THEN BIRYEAR = .;
   IF (IRALCAGG >= 81) THEN IRALCAGG = .;
   IF (IRALCARG >= 81) THEN IRALCARG = .;
   IF (IRALCABS >= 81) THEN IRALCABS = .;
   IF (IRALCHIG >= 81) THEN IRALCHIG = .;
   IF (IRALCJOB >= 81) THEN IRALCJOB = .;
   IF (IRALCMAT >= 81) THEN IRALCMAT = .;
   IF (IRALCREL >= 81) THEN IRALCREL = .;
   IF (IRALCFRD >= 81) THEN IRALCFRD = .;
   IF (IRALCTOS >= 81) THEN IRALCTOS = .;
   IF (IRALCHOL >= 81) THEN IRALCHOL = .;
   IF (IRALCDRU >= 81) THEN IRALCDRU = .;
   IF (IRALCINT >= 81) THEN IRALCINT = .;
   IF (IRALCREM >= 81) THEN IRALCREM = .;
   IF (IRALCQUI >= 81) THEN IRALCQUI = .;
   IF (IRALCMOR >= 81) THEN IRALCMOR = .;
   IF (IRALCSHO >= 81) THEN IRALCSHO = .;
   IF (IRALCALO >= 81) THEN IRALCALO = .;
   IF (IRALCBRK >= 81) THEN IRALCBRK = .;
   IF (IRDEP >= 81) THEN IRDEP = .;
   IF (IRARG >= 81) THEN IRARG = .;
   IF (IRALN >= 81) THEN IRALN = .;
   IF (IRANX >= 81) THEN IRANX = .;
   IF (IRHLT >= 81) THEN IRHLT = .;
   IF (IRNTK >= 81) THEN IRNTK = .;
   IF (IRUPS >= 81) THEN IRUPS = .;
   IF (IRLSW >= 81) THEN IRLSW = .;
   IF (IRSSP >= 81) THEN IRSSP = .;
   IF (IRCPE >= 81) THEN IRCPE = .;
   IF (IREMG >= 81) THEN IREMG = .;
   IF (IRDEP1 >= 998) THEN IRDEP1 = .;
   IF (IRDEP2 >= 999) THEN IRDEP2 = .;
   IF (IRDEP3 >= 99) THEN IRDEP3 = .;
   IF (IRDEP4 >= 999) THEN IRDEP4 = .;
   IF (IRDEP5 >= 999) THEN IRDEP5 = .;
   IF (IRARG1 >= 998) THEN IRARG1 = .;
   IF (IRARG2 >= 998) THEN IRARG2 = .;
   IF (IRARG3 >= 998) THEN IRARG3 = .;
   IF (IRARG4 >= 999) THEN IRARG4 = .;
   IF (IRARG5 >= 998) THEN IRARG5 = .;
   IF (IRALN1 >= 998) THEN IRALN1 = .;
   IF (IRALN2 >= 998) THEN IRALN2 = .;
   IF (IRALN3 >= 998) THEN IRALN3 = .;
   IF (IRALN4 >= 998) THEN IRALN4 = .;
   IF (IRALN5 >= 999) THEN IRALN5 = .;
   IF (IRANX1 >= 998) THEN IRANX1 = .;
   IF (IRANX2 >= 999) THEN IRANX2 = .;
   IF (IRANX3 >= 999) THEN IRANX3 = .;
   IF (IRANX4 >= 999) THEN IRANX4 = .;
   IF (IRANX5 >= 999) THEN IRANX5 = .;
   IF (IRHLT1 >= 998) THEN IRHLT1 = .;
   IF (IRHLT2 >= 998) THEN IRHLT2 = .;
   IF (IRHLT3 >= 999) THEN IRHLT3 = .;
   IF (IRHLT4 >= 999) THEN IRHLT4 = .;
   IF (IRHLT5 >= 998) THEN IRHLT5 = .;
   IF (IRNTK1 >= 998) THEN IRNTK1 = .;
   IF (IRNTK2 >= 998) THEN IRNTK2 = .;
   IF (IRNTK3 >= 998) THEN IRNTK3 = .;
   IF (IRNTK4 >= 998) THEN IRNTK4 = .;
   IF (IRNTK5 >= 998) THEN IRNTK5 = .;
   IF (IRUPS1 >= 998) THEN IRUPS1 = .;
   IF (IRUPS2 >= 998) THEN IRUPS2 = .;
   IF (IRUPS3 >= 998) THEN IRUPS3 = .;
   IF (IRUPS4 >= 998) THEN IRUPS4 = .;
   IF (IRUPS5 >= 181) THEN IRUPS5 = .;
   IF (IRLSW1 >= 998) THEN IRLSW1 = .;
   IF (IRLSW2 >= 998) THEN IRLSW2 = .;
   IF (IRLSW3 >= 998) THEN IRLSW3 = .;
   IF (IRLSW4 >= 998) THEN IRLSW4 = .;
   IF (IRLSW5 >= 998) THEN IRLSW5 = .;
   IF (IRSSP1 >= 998) THEN IRSSP1 = .;
   IF (IRSSP2 >= 998) THEN IRSSP2 = .;
   IF (IRSSP3 >= 999) THEN IRSSP3 = .;
   IF (IRSSP4 >= 998) THEN IRSSP4 = .;
   IF (IRSSP5 >= 181) THEN IRSSP5 = .;
   IF (IRCPE1 >= 998) THEN IRCPE1 = .;
   IF (IRCPE2 >= 998) THEN IRCPE2 = .;
   IF (IRCPE3 >= 999) THEN IRCPE3 = .;
   IF (IRCPE4 >= 999) THEN IRCPE4 = .;
   IF (IRCPE5 >= 998) THEN IRCPE5 = .;
   IF (IREMG1 >= 998) THEN IREMG1 = .;
   IF (IREMG2 >= 998) THEN IREMG2 = .;
   IF (IREMG3 >= 998) THEN IREMG3 = .;
   IF (IREMG4 >= 998) THEN IREMG4 = .;
   IF (IREMG5 >= 998) THEN IREMG5 = .;
   IF (IRCDCIG >= 81) THEN IRCDCIG = .;
   IF (IRCDALC >= 81) THEN IRCDALC = .;
   IF (IRCDMJ >= 81) THEN IRCDMJ = .;
   IF (IRCDCOC >= 81) THEN IRCDCOC = .;
   IF (IREFCIG >= 81) THEN IREFCIG = .;
   IF (IREFALC >= 81) THEN IREFALC = .;
   IF (IREFMJ >= 81) THEN IREFMJ = .;
   IF (IREFCOC >= 81) THEN IREFCOC = .;
   IF (IRUDCIG >= 81) THEN IRUDCIG = .;
   IF (IRUDALC >= 81) THEN IRUDALC = .;
   IF (IRUDMJ >= 81) THEN IRUDMJ = .;
   IF (IRUDCOC >= 81) THEN IRUDCOC = .;
   IF (IRDPCIG >= 81) THEN IRDPCIG = .;
   IF (IRDPALC >= 81) THEN IRDPALC = .;
   IF (IRDPMJ >= 81) THEN IRDPMJ = .;
   IF (IRDPCOC >= 81) THEN IRDPCOC = .;
   IF (IRWSCIG >= 81) THEN IRWSCIG = .;
   IF (IRWSALC >= 81) THEN IRWSALC = .;
   IF (IRWSMJ >= 81) THEN IRWSMJ = .;
   IF (IRWSCOC >= 81) THEN IRWSCOC = .;
   IF (INTMONTH >= 81) THEN INTMONTH = .;
   IF (QC06 >= 81) THEN QC06 = .;
   IF (QC09 >= 81) THEN QC09 = .;
   IF (AL02 >= 81) THEN AL02 = .;
   IF (SE04 >= 81) THEN SE04 = .;
   IF (TR04 >= 81) THEN TR04 = .;
   IF (ST04 >= 81) THEN ST04 = .;
   IF (ST07 >= 81) THEN ST07 = .;
   IF (AN04 >= 81) THEN AN04 = .;
   IF (MJ04 >= 81) THEN MJ04 = .;
   IF (IN04 >= 81) THEN IN04 = .;
   IF (CC04 >= 81) THEN CC04 = .;
   IF (CC10 >= 81) THEN CC10 = .;
   IF (CC11 >= 81) THEN CC11 = .;
   IF (LS05 >= 81) THEN LS05 = .;
   IF (LS08 >= 81) THEN LS08 = .;
   IF (HE04 >= 81) THEN HE04 = .;
   IF (HE07 >= 81) THEN HE07 = .;
   IF (DR08 >= 81) THEN DR08 = .;
   IF (SP04 >= 81) THEN SP04 = .;
   IF (SP08 >= 81) THEN SP08 = .;
   IF (OTHDOSP1 >= 81) THEN OTHDOSP1 = .;
   IF (OTHDOSP2 >= 81) THEN OTHDOSP2 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT CWEOCC2 cweocc2f. ROCCUP2 roccup2f. BUSINES2 businesf.
         CWEBUS2 cwebus2f. SNUFREC snufrec. ALCREC alcrec.
         SEDREC sedrec. TRANREC tranrec. STIMREC stimrec.
         STNDLREC stndlrec. ANALREC analrec. MJREC mjrec.
         INHREC inhrec. CRAKREC crakrec. COCREC cocrec.
         CONDLREC condlrec. PCPREC pcprec. HALLREC hallrec.
         HERREC herrec. HRNDLREC hrndlrec. GNNDLREC gnndlrec.
         ICEREC icerec. STERREC sterrec. ALCSED alcsed.
         ALCTRAN alctran. ALCSTM alcstm. ALCANAL alcanal.
         ALCMJ alcmj. ALCINH alcinh. ALCCOC alccoc.
         ALCHAL alchal. ALCOPT alcopt. ALCNONE alcnone.
         CIGTRY cigtry. CIGAGE cigage. CIGYRS cigyrs.
         ALCTRY alctry. ALCAGE alcage. SEDAGE sedage.
         TRANAGE tranage. STIMAGE stimage. ANALAGE analage.
         MJOPP mjopp. MJAGE mjage. INHAGE inhage.
         COCOPP cocopp. COCAGE cocage. HALLOPP hallopp.
         HALLAGE hallage. HEROPP heropp. HERAGE herage.
         STEROPP steropp. STERAGE sterage. OTHTOB othtob.
         ALCPAT alcpat. SEDYRFRQ sedyrfrq. TRNYRFRQ trnyrfrq.
         STMYRFRQ stmyrfrq. ANLYRFRQ anlyrfrq. MJYRFREQ mjyrfreq.
         INHYRFRQ inhyrfrq. COCYRFRQ cocyrfrq. HALYRFRQ halyrfrq.
         CIG5PK cig5pk. PACKS packs. AVCIG avcig.
         CIGTIME cigtime. ALCDAYS alcdays. NODR30A nodr30a.
         DR5DAY dr5day. MODR30A modr30a. MODR30DY modr30dy.
         DRUNKYR drunkyr. ALCBEER alcbeer. ALCWINE alcwine.
         ALCLIQR alcliqr. ALCVARY alcvary. NOBOOZYR noboozyr.
         ALCAGGR alcaggr. ALCARGUM alcargum. ALCABSNT alcabsnt.
         ALCHIGH alchigh. ALCJOB alcjob. ALCMATCD alcmatcd.
         ALCRELCD alcrelcd. ALCFRDCD alcfrdcd. ALCTOSS alctoss.
         ALCHOLIC alcholic. ALCDRUNK alcdrunk. ALCINTOX alcintox.
         ALCREM alcrem. ALCQUICK alcquick. ALCMORN alcmorn.
         ALCSHOOK alcshook. ALCALONE alcalone. ALCBRKPM alcbrkpm.
         BUTISOL butisol. BUTICAPS buticaps. AMYTAL amytal.
         MEBARAL mebaral. PLACIDYL placidyl. DORIDEN doriden.
         NOLUDAR noludar. NEMBUTAL nembutal. SECONAL seconal.
         TUINAL tuinal. DALMANE dalmane. RESTORIL restoril.
         HALCION halcion. AMOBARB amobarb. PHENOBAR phenobar.
         METHAQ methaq. CHHYD chhyd. PENTOB pentob.
         SECOB secob. SEDNOSP sednosp. SEDNEWA sednewa.
         SEDNEWB sednewb. SEDNEWC sednewc. SEDNEWD sednewd.
         SEDNEWE sednewe. SEDDKNAM seddknam. NOSEDAT nosedat.
         SEDTOT sedtot. VALIUM valium. LIBRIUM librium.
         LIMBTROL limbtrol. MENRIUM menrium. SERAX serax.
         TRANXENE tranxene. ATIVAN ativan. CENTRAX centrax.
         XANAX xanax. PAXIPAM paxipam. BUSPAR buspar.
         MILTOWN miltown. EQUANIL equanil. DEPROL deprol.
         VISTAR vistar. ATARAX atarax. DURRAX durrax.
         DIAZEPAM diazepam. SKLY skly. MEPROB meprob.
         TRNOSP trnosp. TRNEWA trnewa. TRNEWB trnewb.
         TRNEWC trnewc. TRNEWD trnewd. TRNEWE trnewe.
         TRDKNAM trdknam. NOTRANQ notranq. TRANTOT trantot.
         DEXED dexed. DEXAMYL dexamyl. ESKAT eskat.
         BENZ benz. BIPHET biphet. DESOXYN desoxyn.
         TENUATE tenuate. TEPANIL tepanil. DIDREX didrex.
         PLEGINE plegine. PRELUDIN preludin. IONAMIN ionamin.
         FASTIN fastin. PONDIMIN pondimin. VORANIL voranil.
         SANOREX sanorex. MAZANOR mazanor. RITALIN ritalin.
         CYLERT cylert. DETAMP detamp. METHI methi.
         METHAMP methamp. OBLA obla. STIMNOSP stimnosp.
         STIMNEWA stimnewa. STIMNEWB stimnewb. STIMNEWC stimnewc.
         STIMNEWD stimnewd. STIMNEWE stimnewe. STMDKNAM stmdknam.
         NOSTIMS nostims. STIMTOT stimtot. STNEEDLE stneedle.
         DARVON darvon. DOLENE dolene. SK65A sk65a.
         WYGESIC wygesic. LEVODRO levodro. PERCODAN percodan.
         DEMEROL demerol. DILAUD dilaud. TYLCOD tylcod.
         PHENCOD phencod. TALWIN talwin. TALWINNX talwinnx.
         TALACEN talacen. PROPOXY propoxy. CODEINE codeine.
         ANILERID anilerid. MORPHINE morphine. METHDON methdon.
         STADOL stadol. ANLNOSP anlnosp. ANALNEWA analnewa.
         ANALNEWB analnewb. ANALNEWC analnewc. ANALNEWD analnewd.
         ANALNEWE analnewe. ANLDKNAM anldknam. ANALNONE analnone.
         ANALTOT analtot. MJTOT mjtot. MJDAY30A mjday30a.
         MJAV30A mjav30a. MJAV30B mjav30b. MJAMT30A mjamt30a.
         MJJOINT mjjoint. MJPIPE mjpipe. MJBAKE mjbake.
         MJCHEW mjchew. MJWAY mjway. GAS gas.
         LGAS lgas. SPPAINT sppaint. AEROS aeros.
         GLUE glue. SOLVENT solvent. AMYLNIT amylnit.
         ETHER ether. NITOXID nitoxid. CLEFLU cleflu.
         INHNOSP inhnosp. INHDKNAM inhdknam. INHTOT inhtot.
         GAS30A gas30a. LGAS30A lgas30a. SPPAN30A sppan30a.
         AEROS30A aeros30a. GLUE30A glue30a. SOLVN30A solvn30a.
         AMLNT30A amlnt30a. ETHER30A ether30a. NOX30A nox30a.
         CLFL30A clfl30a. IN30NOSP in30nosp. INH30NO inh30no.
         INHDY30A inhdy30a. INHEFF inheff. INHPO inhpo.
         INHNEWA inhnewa. INHNEWB inhnewb. INHNEWC inhnewc.
         INHNEWD inhnewd. INHNEWE inhnewe. INNEW30A innew30a.
         INNEW30B innew30b. INNEW30C innew30c. INNEW30D innew30d.
         INNEW30E innew30e. COCTOT coctot. COCUS30A cocus30a.
         CRKAM30A crkam30a. CRAKBUCK crakbuck. COCAM30A cocam30a.
         COCBUCK cocbuck. COCSNIFF cocsniff. COCSWAL cocswal.
         COCIV cociv. FREEBASE freebase. COCWAY cocway.
         LSD lsd. PEYOTE peyote. MESC mesc.
         PSILCY psilcy. PCP pcp. ECSTASY ecstasy.
         HALNOSP halnosp. HALNEWA halnewa. HALNEWB halnewb.
         HALNEWC halnewc. HALNEWD halnewd. HALNEWE halnewe.
         HALDKNAM haldknam. HALLTOT halltot. HAL30USE hal30use.
         HERTOT hertot. HER30USE her30use. HERNEEDL herneedl.
         CDCIG cdcig. CDALC cdalc. CDSED cdsed.
         CDTRAN cdtran. CDSTM cdstm. CDANAL cdanal.
         CDMJ cdmj. CDINH cdinh. CDCOC cdcoc.
         CDHALL cdhall. CDHER cdher. CDOTHOP cdothop.
         CDNONE cdnone. UCDCIG ucdcig. UCDALC ucdalc.
         UCDSED ucdsed. UCDTRAN ucdtran. UCDSTM ucdstm.
         UCDANAL ucdanal. UCDMJ ucdmj. UCDINH ucdinh.
         UCDCOC ucdcoc. UCDHALL ucdhall. UCDHER ucdher.
         UCDOTHOP ucdothop. UCDNONE ucdnone. EFFCIG effcig.
         EFFALC effalc. EFFSED effsed. EFFTRAN efftran.
         EFFSTM effstm. EFFANAL effanal. EFFMJ effmj.
         EFFINH effinh. EFFCOC effcoc. EFFHALL effhall.
         EFFHER effher. EFFOTHOP effothop. EFFNONE effnone.
         UDAYCIG udaycig. UDAYALC udayalc. UDAYSED udaysed.
         UDAYTRAN udaytran. UDAYSTM udaystm. UDAYANAL udayanal.
         UDAYMJ udaymj. UDAYINH udayinh. UDAYCOC udaycoc.
         UDAYHALL udayhall. UDAYHER udayher. UDAYOTH udayoth.
         UDAYNONE udaynone. DEPCIG depcig. DEPALC depalc.
         DEPSED depsed. DEPTRAN deptran. DEPSTM depstm.
         DEPANAL depanal. DEPMJ depmj. DEPINH depinh.
         DEPCOC depcoc. DEPHALL dephall. DEPHER depher.
         DEPOTHOP depothop. DEPNONE depnone. WSCIG wscig.
         WSALC wsalc. WSSED wssed. WSTRAN wstran.
         WSSTM wsstm. WSANAL wsanal. WSMJ wsmj.
         WSINH wsinh. WSCOC wscoc. WSHALL wshall.
         WSHER wsher. WSOTHOP wsothop. WSNONE wsnone.
         GNNDLLIF gnndllif. GNNDLSED gnndlsed. GNNDLTRA gnndltra.
         GNNDLSTM gnndlstm. GNNDLANL gnndlanl. GNNDLMJ gnndlmj.
         GNNDLINH gnndlinh. GNNDLCOC gnndlcoc. GNNDLHAL gnndlhal.
         GNNDLHER gnndlher. GNNDLOPT gnndlopt. GNNDLNON gnndlnon.
         GNNDLSHR gnndlshr. DRUGTEST drugtest. TESTPOS testpos.
         ICELIFE icelife. STERTOT stertot. BOOKED booked.
         NOBOOKYR nobookyr. BKLARCNY bklarcny. BKBURGL bkburgl.
         BKAGASLT bkagaslt. BKSMASLT bksmaslt. BKMVTHFT bkmvthft.
         BKROB bkrob. BKRAPE bkrape. BKMURDER bkmurder.
         BKARSON bkarson. BKDRVINF bkdrvinf. BKDRUNK bkdrunk.
         BKDRUG bkdrug. BKPROS bkpros. BKVANDAL bkvandal.
         BKOTHOFF bkothoff. NOTBKED notbked. PROBATON probaton.
         PAROLE parole. STRSTEAL strsteal. OTHSTEAL othsteal.
         DAMAGE damage. CARSTEAL carsteal. FORCEMON forcemon.
         BREAKIN breakin. PHYFIGHT phyfight. HURTBAD hurtbad.
         GUNMONEY gunmoney. DRUNKDRV drunkdrv. SOLDDRUG solddrug.
         OTHDOING othdoing. SPNEWA spnewa. SPNEWB spnewb.
         SPNEWC spnewc. SPNEWD spnewd. SPNEWE spnewe.
         AS13NONE as13none. DRDEPRSS drdeprss. DEPDRG1A depdrg1a.
         DEPDRG2A depdrg2a. DEPDRG3A depdrg3a. DEPDRG4A depdrg4a.
         DEPDRG5A depdrg5a. DRARGUM drargum. ARGDRG1A argdrg1a.
         ARGDRG2A argdrg2a. ARGDRG3A argdrg3a. ARGDRG4A argdrg4a.
         ARGDRG5A argdrg5a. DRALONE dralone. ALNDRG1A alndrg1a.
         ALNDRG2A alndrg2a. ALNDRG3A alndrg3a. ALNDRG4A alndrg4a.
         ALNDRG5A alndrg5a. DRANX dranx. ANXDRG1A anxdrg1a.
         ANXDRG2A anxdrg2a. ANXDRG3A anxdrg3a. ANXDRG4A anxdrg4a.
         ANXDRG5A anxdrg5a. DRHEALTH drhealth. HLTDRG1A hltdrg1a.
         HLTDRG2A hltdrg2a. HLTDRG3A hltdrg3a. HLTDRG4A hltdrg4a.
         HLTDRG5A hltdrg5a. DRNTHINK drnthink. NTKDRG1A ntkdrg1a.
         NTKDRG2A ntkdrg2a. NTKDRG3A ntkdrg3a. NTKDRG4A ntkdrg4a.
         NTKDRG5A ntkdrg5a. DRUPSET drupset. UPSDRG1A upsdrg1a.
         UPSDRG2A upsdrg2a. UPSDRG3A upsdrg3a. UPSDRG4A upsdrg4a.
         UPSDRG5A upsdrg5a. DRLSWORK drlswork. LSWDRG1A lswdrg1a.
         LSWDRG2A lswdrg2a. LSWDRG3A lswdrg3a. LSWDRG4A lswdrg4a.
         LSWDRG5A lswdrg5a. DRSUSPIC drsuspic. SSPDRG1A sspdrg1a.
         SSPDRG2A sspdrg2a. SSPDRG3A sspdrg3a. SSPDRG4A sspdrg4a.
         SSPDRG5A sspdrg5a. DRCOPE drcope. CPEDRG1A cpedrg1a.
         CPEDRG2A cpedrg2a. CPEDRG3A cpedrg3a. CPEDRG4A cpedrg4a.
         CPEDRG5A cpedrg5a. DREMGMED dremgmed. EMDRG1A emdrg1a.
         EMDRG2A emdrg2a. EMDRG3A emdrg3a. EMDRG4A emdrg4a.
         EMDRG5A emdrg5a. EMPDRUG empdrug. CIGHELP cighelp.
         DRNKHELP drnkhelp. TRMTHELP trmthelp. TRMTEMRG trmtemrg.
         TRMTHOSP trmthosp. TRMTDOC trmtdoc. TRMTTRMT trmttrmt.
         TRMTMHC trmtmhc. TRMTSHG trmtshg. TRMTSOP trmtsop.
         TRMTSP trmtsp. RSKPKCIG rskpkcig. RSKTRYMJ rsktrymj.
         RSKMJOCC rskmjocc. RSKMJREG rskmjreg. RKTRYPCP rktrypcp.
         RKPCPREG rkpcpreg. RKTRYHER rktryher. RKHERREG rkherreg.
         RKTRYCOC rktrycoc. RKCOCOCC rkcococc. RKCOCREG rkcocreg.
         RKCRKOCC rkcrkocc. RKANSOCC rkansocc. RKANSREG rkansreg.
         RK2DRINK rk2drink. RK5DRINK rk5drink. RSKBINGE rskbinge.
         RSKDIFMJ rskdifmj. RKDIFLSD rkdiflsd. RKDIFPCP rkdifpcp.
         RKDIFCOC rkdifcoc. RKDIFHER rkdifher. PDEN pden.
         PDEN2 pden2fff. POPDEN popden. POPDEN2 popden2f.
         REGION region. DIVISION division. CHICAGO chicago.
         DENVER denver. DC dc. LA la.
         MIAMI miami. NEWYORK newyork. IRRACE irrace.
         IIRACE iirace. IRSEX irsex. IISEX iisex.
         IIAGE iiage. IRHOIND irhoind. IIHOIND iihoind.
         IRMARIT irmarit. IIMARIT iimarit. IRPINSUR irpinsur.
         IIPINSUR iipinsur. IRWORKST irworkst. IIWORKST iiworkst.
         IRHSGRAD irhsgrad. IREDUC ireduc. IIEDUC iieduc.
         IIHSGRAD iihsgrad. IRHOGRP irhogrp. IIHOGRP iihogrp.
         EDUCCAT2 educcatf. EMPSTAT2 empstatf. IRSTMRC irstmrc.
         IROTBRC irotbrc. IRTRNRC irtrnrc. IRSEDRC irsedrc.
         IRMJRC irmjrc. IRMJFQ irmjfq. IIMJFQ iimjfq.
         IROTBFQ irotbfq. IIOTBFQ iiotbfq. IRSEDFQ irsedfq.
         IISEDFQ iisedfq. IRSTMFQ irstmfq. IISTMFQ iistmfq.
         IRTRNFQ irtrnfq. IITRNFQ iitrnfq. IRHALRC irhalrc.
         IRCOCRC ircocrc. IRINHRC irinhrc. IRANLRC iranlrc.
         IRALCRC iralcrc. IRALCFQ iralcfq. IIALCFQ iialcfq.
         IRANLFQ iranlfq. IIANLFQ iianlfq. IRCOCFQ ircocfq.
         IICOCFQ iicocfq. IRHALFQ irhalfq. IIHALFQ iihalfq.
         IRINHFQ irinhfq. IIINHFQ iiinhfq. IRPCPRC irpcprc.
         IIPCPRC iipcprc. IRCRKRC ircrkrc. IICRKRC iicrkrc.
         IRSTRRC irstrrc. IISTRRC iistrrc. IRICERC iricerc.
         IIICERC iiicerc. IIINHRC iiinhrc. IIOTBRC iiotbrc.
         IRHERRC irherrc. IIHERRC iiherrc. IIHALRC iihalrc.
         IITRNRC iitrnrc. IIANLRC iianlrc. IISTMRC iistmrc.
         IISEDRC iisedrc. IICOCRC iicocrc. IIMJRC iimjrc.
         IIALCRC iialcrc. NDL90REC ndl90rec. HALFLAG halflag.
         HALYR halyr. HALMON halmon. PCPFLAG pcpflag.
         PCPYR pcpyr. PCPMON pcpmon. STMFLAG stmflag.
         STMYR stmyr. STMMON stmmon. SEDFLAG sedflag.
         SEDYR sedyr. SEDMON sedmon. TRQFLAG trqflag.
         TRQYR trqyr. TRQMON trqmon. ANLFLAG anlflag.
         ANLYR anlyr. ANLMON anlmon. ALCFLAG alcflag.
         ALCYR alcyr. ALCMON alcmon. CIGFLAG cigflag.
         CIGYR cigyr. CIGMON cigmon. SMKFLAG smkflag.
         SMKYR smkyr. SMKMON smkmon. HERFLAG herflag.
         HERYR heryr. HERMON hermon. STRFLAG strflag.
         STRYR stryr. STRMON strmon. MRJFLAG mrjflag.
         MRJYR mrjyr. MRJMON mrjmon. COCFLAG cocflag.
         COCYR cocyr. COCMON cocmon. CRKFLAG crkflag.
         CRKYR crkyr. CRKMON crkmon. INHFLAG inhflag.
         INHYR inhyr. INHMON inhmon. NEDFLAG3 nedflagf.
         NEDYR3 nedyr3ff. COCYRF cocyrf. COCMONF cocmonf.
         COCWKF cocwkf. COCOCCF cococcf. COCDLYF cocdlyf.
         ALCYRF alcyrf. ALCMONF alcmonf. ALCWKF alcwkf.
         ALCOCCF alcoccf. ALCDLYF alcdlyf. ANLYRF anlyrf.
         ANLMONF anlmonf. ANLWKF anlwkf. ANLOCCF anloccf.
         ANLDLYF anldlyf. HALYRF halyrf. HALMONF halmonf.
         HALWKF halwkf. HALOCCF haloccf. HALDLYF haldlyf.
         INHYRF inhyrf. INHMONF inhmonf. INHWKF inhwkf.
         INHOCCF inhoccf. INHDLYF inhdlyf. SEDYRF sedyrf.
         SEDMONF sedmonf. SEDWKF sedwkf. SEDOCCF sedoccf.
         SEDDLYF seddlyf. SMKYRF smkyrf. SMKMONF smkmonf.
         SMKWKF smkwkf. SMKOCCF smkoccf. SMKDLYF smkdlyf.
         STMYRF stmyrf. STMMONF stmmonf. STMWKF stmwkf.
         STMOCCF stmoccf. STMDLYF stmdlyf. TRQYRF trqyrf.
         TRQMONF trqmonf. TRQWKF trqwkf. TRQOCCF trqoccf.
         TRQDLYF trqdlyf. MRJYRF mrjyrf. MRJMONF mrjmonf.
         MRJWKF mrjwkf. MRJOCCF mrjoccf. MRJDLYF mrjdlyf.
         PSYFLAG2 psyflagf. PSYYR2 psyyr2ff. PSYMON2 psymon2f.
         SUMFLAG sumflag. SUMYR sumyr. SUMMON summon.
         MJOFLAG mjoflag. MJOYR2 mjoyr2ff. MJOMON2 mjomon2f.
         IEMFLAG iemflag. IEMYR iemyr. IEMMON iemmon.
         CATAGE catage. RACE race. IRCIGRC ircigrc.
         IICIGRC iicigrc. CATAG2 catag2ff. AS3READ as3read.
         AS4READ as4read. AS5READ as5read. AS7READ as7read.
         INHQNC1 inhqnc1f. INHQNC2 inhqnc2f. INHQNC3 inhqnc3f.
         INHQNC4 inhqnc4f. INHQNC5 inhqnc5f. INHQNC6 inhqnc6f.
         INHQNC7 inhqnc7f. INHQNC8 inhqnc8f. INHQNC9 inhqnc9f.
         INHQNC10 inhqnc0f. INHANSY inhansy. AS9READ as9read.
         AS10READ as10read. AS11READ as11read. AS12READ as12read.
         AS13READ as13read. AS15READ as15read. HIGHBP highbp.
         BPMED bpmed. WALKPAIN walkpain. TIMEPAIN timepain.
         UPSHOR upshor. ASTHMA asthma. TRPSYCH trpsych.
         HEART heart. FLU flu. ALLERG allerg.
         HOSPYR hospyr. SOREYR soreyr. RUNNYYR runnyyr.
         COUGHYR coughyr. PHLEGMYR phlegmyr. HEALTHYR healthyr.
         MARITAL marital. NOMARR nomarr. WORKSTAT workstat.
         PAYMO paymo. PAYYR payyr. SECTOR sector.
         NO5JOB no5job. WORKDAYS workdays. WORKBLAH workblah.
         CWE cwe. FULLPART fullpart. CWESECTR cwesectr.
         EDUC educ. GRADHS gradhs. DIPLOMA diploma.
         ENROLLD enrolld. SCHPLANS schplans. STUDENT student.
         SCHDAYS schdays. SKIPPED skipped. ACCID accid.
         MOVDAWAY movdaway. DORM dorm. MILBASE milbase.
         HOSP hosp. OTHGPH othgph. OTHGPHSP othgphsp.
         SERVICE service. MILSTAT milstat. TELNO telno.
         MOVES moves. EAP eap. UNDINT undint.
         COOPINT coopint. PRIVACY privacy. PPRES ppres.
         SPRES spres. PARPRES parpres. OARPRES oarpres.
         OAPRES oapres. CPRES cpres. OPRESNSP opresnsp.
         OPRESSPA opresspa. WHOMARKD whomarkd. MILES miles.
         MOTHER mother. FATHER father. STEPMOM stepmom.
         STEPDAD stepdad. SPOUSE spouse. INLAW inlaw.
         OWNCHILD ownchild. STEPCHLD stepchld. BROSIS brosis.
         OTHREL othrel. FRIENDS friends. OTHERNON othernon.
         TOTPEOP totpeop. NOCHILD nochild. CIGREC cigrec.
         BAP bap. LANGVER langver. URBARE urbare.
         CENCTY cencty. GQTYP gqtyp. IRHOGRP2 irhogrpf.
         IIHOGRP2 iihogrpf. FAMSKIP famskip. WORK work.
         WAG1 wag1ffff. SOC1 soc1ffff. SSI1 ssi1ffff.
         WEL1 wel1ffff. INT1 int1ffff. CHD1 chd1ffff.
         OTH1 oth1ffff. WAG2 wag2ffff. SOC2 soc2ffff.
         SSI2 ssi2ffff. WEL2 wel2ffff. INT2 int2ffff.
         CHD2 chd2ffff. OTH2 oth2ffff. FOOD food.
         AWAG1 awag1fff. ASOC1 asoc1fff. ASSI1 assi1fff.
         AWEL1 awel1fff. AINT1 aint1fff. ACHD1 achd1fff.
         AOTH1 aoth1fff. AWAG2 awag2fff. ASOC2 asoc2fff.
         ASSI2 assi2fff. AWEL2 awel2fff. AINT2 aint2fff.
         ACHD2 achd2fff. AOTH2 aoth2fff. AFOOD afood.
         IRWAG1 irwag1ff. IRSOC1 irsoc1ff. IRSSI1 irssi1ff.
         IRWEL1 irwel1ff. IRINT1 irint1ff. IRCHD1 irchd1ff.
         IROTH1 iroth1ff. IRWAG2 irwag2ff. IRSOC2 irsoc2ff.
         IRSSI2 irssi2ff. IRWEL2 irwel2ff. IRINT2 irint2ff.
         IRCHD2 irchd2ff. IROTH2 iroth2ff. IRFOOD irfood.
         IRAWAG1 irawag1f. IRASOC1 irasoc1f. IRASSI1 irassi1f.
         IRAWEL1 irawel1f. IRAINT1 iraint1f. IRACHD1 irachd1f.
         IRAOTH1 iraoth1f. IRAWAG2 irawag2f. IRASOC2 irasoc2f.
         IRASSI2 irassi2f. IRAWEL2 irawel2f. IRAINT2 iraint2f.
         IRACHD2 irachd2f. IRAOTH2 iraoth2f. IRAFOOD irafood.
         IIWAG1 iiwag1ff. IISOC1 iisoc1ff. IISSI1 iissi1ff.
         IIWEL1 iiwel1ff. IIINT1 iiint1ff. IICHD1 iichd1ff.
         IIOTH1 iioth1ff. IIWAG2 iiwag2ff. IISOC2 iisoc2ff.
         IISSI2 iissi2ff. IIWEL2 iiwel2ff. IIINT2 iiint2ff.
         IICHD2 iichd2ff. IIOTH2 iioth2ff. IIFOOD iifood.
         IIAWAG1 iiawag1f. IIASOC1 iiasoc1f. IIASSI1 iiassi1f.
         IIAWEL1 iiawel1f. IIAINT1 iiaint1f. IIACHD1 iiachd1f.
         IIAOTH1 iiaoth1f. IIAWAG2 iiawag2f. IIASOC2 iiasoc2f.
         IIASSI2 iiassi2f. IIAWEL2 iiawel2f. IIAINT2 iiaint2f.
         IIACHD2 iiachd2f. IIAOTH2 iiaoth2f. IIAFOOD iiafood.
         JOB job. HOURS hours. WEEKS weeks.
         PUB1 pub1ffff. AFDC1 afdc1fff. PUB2 pub2ffff.
         AFDC2 afdc2fff. FSTAMP fstamp. PEOPFD peopfd.
         WELFARE welfare. TWOFAM twofam. INDINC indinc.
         IIINDINC iiindinc. TOTINC totinc. IITOTINC iitotinc.
         INDCAT indcat. TOTCAT totcat. PERINC perinc.
         FAMINC faminc. PERINC2 perinc2f. FAMINC2 faminc2f.
         FAMINC3 faminc3f. PERINC3 perinc3f. PRVHLTIN prvhltin.
         PLYFLAGC plyflagc. PLYYRC plyyrc. PLYMONC plymonc.
         WPSTAT wpstat. OWNOCONC ownoconc. NHBHCONC nhbhconc.
         NHBPCONC nhbpconc. HSPPCONC hsppconc. HSPHCONC hsphconc.
         METRO metro. PROXABLE proxable. PROXYREL proxyrel.
         PROXHOME proxhome. PROXJOIN proxjoin. MEDICARE medicare.
         MEDICAID medicaid. CHAMPUS champus. OWNHLTIN ownhltin.
         GRPHLTIN grphltin. HLTINALC hltinalc. HLTINDRG hltindrg.
         HLTINMNT hltinmnt. WHOANSHI whoanshi. WHOANSIN whoansin.
         NEEDLREC needlrec. IRINSUR irinsur. IIINSUR iiinsur.
         HERREC92 herrec9f. IRHERC92 irherc9f. IIHERC92 iiherc9f.
         IRALCAGG iralcagg. IRALCARG iralcarg. IRALCABS iralcabs.
         IRALCHIG iralchig. IRALCJOB iralcjob. IRALCMAT iralcmat.
         IRALCREL iralcrel. IRALCFRD iralcfrd. IRALCTOS iralctos.
         IRALCHOL iralchol. IRALCDRU iralcdru. IRALCINT iralcint.
         IRALCREM iralcrem. IRALCQUI iralcqui. IRALCMOR iralcmor.
         IRALCSHO iralcsho. IRALCALO iralcalo. IRALCBRK iralcbrk.
         IRNOBOOZ irnobooz. ANYALC anyalc. THREALC threalc.
         DRUNKYR2 drunkyrf. TRMTHLP2 trmthlpf. DRNKHLP2 drnkhlpf.
         DRALHELP dralhelp. ICEFLAG iceflag. ICEYR iceyr.
         ICEMON icemon. MJTOT2 mjtot2ff. COCTOT2 coctot2f.
         MJTOT3 mjtot3ff. COCTOT3 coctot3f. MJDY30A2 mjdy30af.
         ALCDAYS2 alcdaysf. MRJMON2 mrjmon2f. ALCMON2 alcmon2f.
         CIGMON2 cigmon2f. LSD2 lsd2ffff. PEYOTE2 peyote2f.
         MESC2 mesc2fff. PSILCY2 psilcy2f. ECSTASY2 ecstasyf.
         GAS2 gas2ffff. LGAS2 lgas2fff. SPPAINT2 sppaintf.
         AEROS2 aeros2ff. GLUE2 glue2fff. SOLVENT2 solventf.
         AMYLNIT2 amylnitf. ETHER2 ether2ff. NITOXID2 nitoxidf.
         CLEFLU2 cleflu2f. COCSNIF2 cocsni0f. FREEBAS2 freebasf.
         COCSWAL2 cocswalf. COCIV2 cociv2ff. MJDY30A3 mjdy300f.
         ALCDAYS3 alcday0f. DRINKER2 drinkerf. HVYDRK2 hvydrk2f.
         AVCIG2 avcig2ff. RACESEX racesex. NOTMARJ notmarj.
         RACESEX2 racesexf. ALCONLYL alconlyl. ALCONLYY alconlyy.
         ALCONLYM alconlym. ILLONLYL illonlyl. ILLONLYY illonlyy.
         ILLONLYM illonlym. MRJONLYL mrjonlyl. MRJONLYY mrjonlyy.
         MRJONLYM mrjonlym. PSYONLYL psyonlyl. PSYONLYY psyonlyy.
         PSYONLYM psyonlym. OTHONLYL othonlyl. OTHONLYY othonlyy.
         OTHONLYM othonlym. ALCILLL alcilll. ALCILLY alcilly.
         ALCILLM alcillm. ALCMRJL alcmrjl. ALCMRJY alcmrjy.
         ALCMRJM alcmrjm. ALCPSYL alcpsyl. ALCPSYY alcpsyy.
         ALCPSYM alcpsym. ALCOTHL alcothl. ALCOTHY alcothy.
         ALCOTHM alcothm. SUB1LIF sub1lif. SUB2LIF sub2lif.
         SUB3LIF sub3lif. SUB1YR sub1yr. SUB2YR sub2yr.
         SUB3YR sub3yr. SUB1MON sub1mon. SUB2MON sub2mon.
         SUB3MON sub3mon. IRDEP irdep. IRARG irarg.
         IRALN iraln. IRANX iranx. IRHLT irhlt.
         IRNTK irntk. IRUPS irups. IRLSW irlsw.
         IRSSP irssp. IRCPE ircpe. IREMG iremg.
         IRDEP1 irdep1ff. IRDEP2 irdep2ff. IRDEP3 irdep3ff.
         IRDEP4 irdep4ff. IRDEP5 irdep5ff. IRARG1 irarg1ff.
         IRARG2 irarg2ff. IRARG3 irarg3ff. IRARG4 irarg4ff.
         IRARG5 irarg5ff. IRALN1 iraln1ff. IRALN2 iraln2ff.
         IRALN3 iraln3ff. IRALN4 iraln4ff. IRALN5 iraln5ff.
         IRANX1 iranx1ff. IRANX2 iranx2ff. IRANX3 iranx3ff.
         IRANX4 iranx4ff. IRANX5 iranx5ff. IRHLT1 irhlt1ff.
         IRHLT2 irhlt2ff. IRHLT3 irhlt3ff. IRHLT4 irhlt4ff.
         IRHLT5 irhlt5ff. IRNTK1 irntk1ff. IRNTK2 irntk2ff.
         IRNTK3 irntk3ff. IRNTK4 irntk4ff. IRNTK5 irntk5ff.
         IRUPS1 irups1ff. IRUPS2 irups2ff. IRUPS3 irups3ff.
         IRUPS4 irups4ff. IRUPS5 irups5ff. IRLSW1 irlsw1ff.
         IRLSW2 irlsw2ff. IRLSW3 irlsw3ff. IRLSW4 irlsw4ff.
         IRLSW5 irlsw5ff. IRSSP1 irssp1ff. IRSSP2 irssp2ff.
         IRSSP3 irssp3ff. IRSSP4 irssp4ff. IRSSP5 irssp5ff.
         IRCPE1 ircpe1ff. IRCPE2 ircpe2ff. IRCPE3 ircpe3ff.
         IRCPE4 ircpe4ff. IRCPE5 ircpe5ff. IREMG1 iremg1ff.
         IREMG2 iremg2ff. IREMG3 iremg3ff. IREMG4 iremg4ff.
         IREMG5 iremg5ff. IRAS13 iras13ff. ANYPROB anyprob.
         TWOPROB twoprob. THREPROB threprob. DEPCIG2 depcig2f.
         DEPALC2 depalc2f. DEPMRJ2 depmrj2f. DEPCOC2 depcoc2f.
         ARGCIG2 argcig2f. ARGALC2 argalc2f. ARGMRJ2 argmrj2f.
         ARGCOC2 argcoc2f. ALNCIG2 alncig2f. ALNALC2 alnalc2f.
         ALNMRJ2 alnmrj2f. ALNCOC2 alncoc2f. ANXCIG2 anxcig2f.
         ANXALC2 anxalc2f. ANXMRJ2 anxmrj2f. ANXCOC2 anxcoc2f.
         HLTCIG2 hltcig2f. HLTALC2 hltalc2f. HLTMRJ2 hltmrj2f.
         HLTCOC2 hltcoc2f. NTKCIG2 ntkcig2f. NTKALC2 ntkalc2f.
         NTKMRJ2 ntkmrj2f. NTKCOC2 ntkcoc2f. UPSCIG2 upscig2f.
         UPSALC2 upsalc2f. UPSMRJ2 upsmrj2f. UPSCOC2 upscoc2f.
         LSWCIG2 lswcig2f. LSWALC2 lswalc2f. LSWMRJ2 lswmrj2f.
         LSWCOC2 lswcoc2f. SSPCIG2 sspcig2f. SSPALC2 sspalc2f.
         SSPMRJ2 sspmrj2f. SSPCOC2 sspcoc2f. CPECIG2 cpecig2f.
         CPEALC2 cpealc2f. CPEMRJ2 cpemrj2f. CPECOC2 cpecoc2f.
         EMCIG2 emcig2ff. EMALC2 emalc2ff. EMMRJ2 emmrj2ff.
         EMCOC2 emcoc2ff. PRB1CIG prb1cig. PRB1ALC prb1alc.
         PRB1MRJ prb1mrj. PRB1COC prb1coc. PRB2CIG prb2cig.
         PRB2ALC prb2alc. PRB2MRJ prb2mrj. PRB2COC prb2coc.
         PRB3CIG prb3cig. PRB3ALC prb3alc. PRB3MRJ prb3mrj.
         PRB3COC prb3coc. IRCDCIG ircdcig. IRCDALC ircdalc.
         IRCDMJ ircdmj. IRCDCOC ircdcoc. IREFCIG irefcig.
         IREFALC irefalc. IREFMJ irefmj. IREFCOC irefcoc.
         IRUDCIG irudcig. IRUDALC irudalc. IRUDMJ irudmj.
         IRUDCOC irudcoc. IRDPCIG irdpcig. IRDPALC irdpalc.
         IRDPMJ irdpmj. IRDPCOC irdpcoc. IRWSCIG irwscig.
         IRWSALC irwsalc. IRWSMJ irwsmj. IRWSCOC irwscoc.
         AVCIG3 avcig3ff. ALCPROBS alcprobs. MJPROBS mjprobs.
         COCPROBS cocprobs. CIGPROBS cigprobs. QC06 qc06ffff.
         QC09 qc09ffff. AL02 al02ffff. SE04 se04ffff.
         TR04 tr04ffff. ST04 st04ffff. ST07 st07ffff.
         AN04 an04ffff. MJ04 mj04ffff. IN04 in04ffff.
         CC04 cc04ffff. CC10 cc10ffff. CC11 cc11ffff.
         LS05 ls05ffff. LS08 ls08ffff. HE04 he04ffff.
         HE07 he07ffff. DR08 dr08ffff. SP04 sp04ffff.
         SP08 sp08ffff. OTHDOSP1 othdospf. OTHDOSP2 othdos0f.
         COCWAY2 cocway2f.  ;
*/

RUN ;
